# Auto-generated by scripts/scaffold_roots.py for Gana 8
from . import registry


@registry.register("8.1", root="तनु", meaning="विस्तारे", gana="Tanadi")
def root_8_1():
    """
    8.1 तनु विस्तारे 
    """
    return "तनु"


@registry.register("8.2", root="षणु", meaning="दाने", gana="Tanadi")
def root_8_2():
    """
    8.2 षणु दाने 
    """
    return "षणु"


@registry.register("8.3", root="क्षणु", meaning="हिंसायाम्", gana="Tanadi")
def root_8_3():
    """
    8.3 क्षणु हिंसायाम् 
    """
    return "क्षणु"


@registry.register("8.4", root="क्षिणु", meaning="च", gana="Tanadi")
def root_8_4():
    """
    8.4 क्षिणु च 
    """
    return "क्षिणु"


@registry.register("8.5", root="ऋणु", meaning="गतौ", gana="Tanadi")
def root_8_5():
    """
    8.5 ऋणु गतौ 
    """
    return "ऋणु"


@registry.register("8.6", root="तृणु", meaning="अदने", gana="Tanadi")
def root_8_6():
    """
    8.6 तृणु अदने 
    """
    return "तृणु"


@registry.register("8.7", root="घृणु", meaning="दीप्तौ", gana="Tanadi")
def root_8_7():
    """
    8.7 घृणु दीप्तौ 
    """
    return "घृणु"


@registry.register("8.8", root="वनु", meaning="वनु याचने", gana="Tanadi")
def root_8_8():
    """
    8.8 वनु वनु याचने 
    """
    return "वनु"


@registry.register("8.9", root="मनु", meaning="अवबोधने", gana="Tanadi")
def root_8_9():
    """
    8.9 मनु अवबोधने 
    """
    return "मनु"


@registry.register("8.10", root="डुकृञ्", meaning="करणे", gana="Tanadi")
def root_8_10():
    """
    8.10 डुकृञ् करणे 
    """
    return "डुकृञ्"
