# Auto-generated by scripts/scaffold_roots.py for Gana 9
from . import registry


@registry.register("9.1", root="डुक्रीञ्", meaning="द्रव्यविनिमये", gana="Kryadi")
def root_9_1():
    """
    9.1 डुक्रीञ् द्रव्यविनिमये 
    """
    return "डुक्रीञ्"


@registry.register("9.2", root="प्रीञ्", meaning="तर्पने कान्तौ च", gana="Kryadi")
def root_9_2():
    """
    9.2 प्रीञ् तर्पने कान्तौ च 
    """
    return "प्रीञ्"


@registry.register("9.3", root="श्रीञ्", meaning="पाके", gana="Kryadi")
def root_9_3():
    """
    9.3 श्रीञ् पाके 
    """
    return "श्रीञ्"


@registry.register("9.4", root="मीञ्", meaning="हिंसायाम् बन्धने माने", gana="Kryadi")
def root_9_4():
    """
    9.4 मीञ् हिंसायाम् बन्धने माने 
    """
    return "मीञ्"


@registry.register("9.5", root="षिञ्", meaning="बन्धने", gana="Kryadi")
def root_9_5():
    """
    9.5 षिञ् बन्धने 
    """
    return "षिञ्"


@registry.register("9.6", root="स्कुञ्", meaning="आप्रवने", gana="Kryadi")
def root_9_6():
    """
    9.6 स्कुञ् आप्रवने 
    """
    return "स्कुञ्"


@registry.register("9.10", root="स्कुम्भु", meaning="रोधन इत्येके", gana="Kryadi")
def root_9_10():
    """
    9.10 स्कुम्भु रोधन इत्येके 
    """
    return "स्कुम्भु"


@registry.register("9.11", root="युञ्", meaning="बन्धने", gana="Kryadi")
def root_9_11():
    """
    9.11 युञ् बन्धने 
    """
    return "युञ्"


@registry.register("9.12", root="क्नूञ्", meaning="शब्दे", gana="Kryadi")
def root_9_12():
    """
    9.12 क्नूञ् शब्दे 
    """
    return "क्नूञ्"


@registry.register("9.13", root="द्रूञ्", meaning="हिंसायाम्", gana="Kryadi")
def root_9_13():
    """
    9.13 द्रूञ् हिंसायाम् 
    """
    return "द्रूञ्"


@registry.register("9.14", root="पूञ्", meaning="पवने", gana="Kryadi")
def root_9_14():
    """
    9.14 पूञ् पवने 
    """
    return "पूञ्"


@registry.register("9.15", root="मूञ्", meaning="बन्धने", gana="Kryadi")
def root_9_15():
    """
    9.15 मूञ् बन्धने 
    """
    return "मूञ्"


@registry.register("9.16", root="लूञ्", meaning="छेदने", gana="Kryadi")
def root_9_16():
    """
    9.16 लूञ् छेदने 
    """
    return "लूञ्"


@registry.register("9.17", root="स्तृईञ्", meaning="आच्छादने", gana="Kryadi")
def root_9_17():
    """
    9.17 स्तृईञ् आच्छादने 
    """
    return "स्तृईञ्"


@registry.register("9.18", root="कृईञ्", meaning="हिंसायाम्", gana="Kryadi")
def root_9_18():
    """
    9.18 कृईञ् हिंसायाम् 
    """
    return "कृईञ्"


@registry.register("9.19", root="वृईञ्", meaning="वरणे", gana="Kryadi")
def root_9_19():
    """
    9.19 वृईञ् वरणे 
    """
    return "वृईञ्"


@registry.register("9.20", root="धूञ्", meaning="कम्पने", gana="Kryadi")
def root_9_20():
    """
    9.20 धूञ् कम्पने 
    """
    return "धूञ्"


@registry.register("9.21", root="श‍ृई", meaning="हिंसायाम्", gana="Kryadi")
def root_9_21():
    """
    9.21 श‍ृई हिंसायाम् 
    """
    return "श‍ृई"


@registry.register("9.22", root="पृई", meaning="पालनपूरणयोः", gana="Kryadi")
def root_9_22():
    """
    9.22 पृई पालनपूरणयोः
    """
    return "पृई"


@registry.register("9.23", root="वृई", meaning="वरणे", gana="Kryadi")
def root_9_23():
    """
    9.23 वृई वरणे 
    """
    return "वृई"


@registry.register("9.24", root="भृई", meaning="भर्त्सने", gana="Kryadi")
def root_9_24():
    """
    9.24 भृई भर्त्सने 
    """
    return "भृई"


@registry.register("9.25", root="मृई", meaning="हिंसायाम्", gana="Kryadi")
def root_9_25():
    """
    9.25 मृई हिंसायाम् 
    """
    return "मृई"


@registry.register("9.26", root="दृई", meaning="विदारणे", gana="Kryadi")
def root_9_26():
    """
    9.26 दृई विदारणे 
    """
    return "दृई"


@registry.register("9.27", root="जृई", meaning="वयोहानौ", gana="Kryadi")
def root_9_27():
    """
    9.27 जृई वयोहानौ 
    """
    return "जृई"


@registry.register("9.28", root="झृई", meaning="इत्येके", gana="Kryadi")
def root_9_28():
    """
    9.28 झृई इत्येके 
    """
    return "झृई"


@registry.register("9.29", root="धृई", meaning="इत्यन्ये", gana="Kryadi")
def root_9_29():
    """
    9.29 धृई इत्यन्ये 
    """
    return "धृई"


@registry.register("9.30", root="नृई", meaning="नये", gana="Kryadi")
def root_9_30():
    """
    9.30 नृई नये 
    """
    return "नृई"


@registry.register("9.31", root="कृई", meaning="हिंसायाम्", gana="Kryadi")
def root_9_31():
    """
    9.31 कृई हिंसायाम् 
    """
    return "कृई"


@registry.register("9.32", root="ऋई", meaning="गतौ", gana="Kryadi")
def root_9_32():
    """
    9.32 ऋई गतौ 
    """
    return "ऋई"


@registry.register("9.33", root="गृई", meaning="शब्दे", gana="Kryadi")
def root_9_33():
    """
    9.33 गृई शब्दे 
    """
    return "गृई"


@registry.register("9.34", root="ज्या", meaning="वयोहानौ", gana="Kryadi")
def root_9_34():
    """
    9.34 ज्या वयोहानौ 
    """
    return "ज्या"


@registry.register("9.35", root="री", meaning="गतिरेषणयोः", gana="Kryadi")
def root_9_35():
    """
    9.35 री गतिरेषणयोः 
    """
    return "री"


@registry.register("9.36", root="ली", meaning="श्लेषणे", gana="Kryadi")
def root_9_36():
    """
    9.36 ली श्लेषणे 
    """
    return "ली"


@registry.register("9.37", root="व्ली", meaning="वरणे", gana="Kryadi")
def root_9_37():
    """
    9.37 व्ली वरणे 
    """
    return "व्ली"


@registry.register("9.38", root="ब्ली", meaning="इत्येके", gana="Kryadi")
def root_9_38():
    """
    9.38 ब्ली इत्येके 
    """
    return "ब्ली"


@registry.register("9.39", root="प्ली", meaning="गतौ", gana="Kryadi")
def root_9_39():
    """
    9.39 प्ली गतौ 
    """
    return "प्ली"


@registry.register("9.40", root="व्री", meaning="वरणे", gana="Kryadi")
def root_9_40():
    """
    9.40 व्री वरणे 
    """
    return "व्री"


@registry.register("9.41", root="भ्री", meaning="भये", gana="Kryadi")
def root_9_41():
    """
    9.41 भ्री भये 
    """
    return "भ्री"


@registry.register("9.42", root="क्षीष्", meaning="हिंसायाम्", gana="Kryadi")
def root_9_42():
    """
    9.42 क्षीष् हिंसायाम् 
    """
    return "क्षीष्"


@registry.register("9.43", root="ज्ञा", meaning="अवबोधने", gana="Kryadi")
def root_9_43():
    """
    9.43 ज्ञा अवबोधने 
    """
    return "ज्ञा"


@registry.register("9.44", root="बन्ध", meaning="बन्धने", gana="Kryadi")
def root_9_44():
    """
    9.44 बन्ध बन्धने 
    """
    return "बन्ध"


@registry.register("9.45", root="वृङ्", meaning="सम्भक्तौ", gana="Kryadi")
def root_9_45():
    """
    9.45 वृङ् सम्भक्तौ 
    """
    return "वृङ्"


@registry.register("9.46", root="श्रन्थ", meaning="विमोचनप्रतिहर्षयोः", gana="Kryadi")
def root_9_46():
    """
    9.46 श्रन्थ विमोचनप्रतिहर्षयोः 
    """
    return "श्रन्थ"


@registry.register("9.47", root="मन्थ", meaning="विलोडने", gana="Kryadi")
def root_9_47():
    """
    9.47 मन्थ विलोडने 
    """
    return "मन्थ"


@registry.register("9.49", root="ग्रन्थ", meaning="सन्दर्भे", gana="Kryadi")
def root_9_49():
    """
    9.49 ग्रन्थ सन्दर्भे 
    """
    return "ग्रन्थ"


@registry.register("9.50", root="कुन्थ", meaning="संश्लेषणे", gana="Kryadi")
def root_9_50():
    """
    9.50 कुन्थ संश्लेषणे 
    """
    return "कुन्थ"


@registry.register("9.51", root="मृद", meaning="क्षोदे", gana="Kryadi")
def root_9_51():
    """
    9.51 मृद क्षोदे 
    """
    return "मृद"


@registry.register("9.52", root="मृड", meaning="सुखे च मृड च", gana="Kryadi")
def root_9_52():
    """
    9.52 मृड सुखे च मृड च 
    """
    return "मृड"


@registry.register("9.53", root="गुध", meaning="रोषे", gana="Kryadi")
def root_9_53():
    """
    9.53 गुध रोषे 
    """
    return "गुध"


@registry.register("9.54", root="कुष", meaning="निष्कर्षे", gana="Kryadi")
def root_9_54():
    """
    9.54 कुष निष्कर्षे 
    """
    return "कुष"


@registry.register("9.55", root="क्षुभ", meaning="सञ्चलने", gana="Kryadi")
def root_9_55():
    """
    9.55 क्षुभ सञ्चलने 
    """
    return "क्षुभ"


@registry.register("9.57", root="तुभ", meaning="हिंसायाम्", gana="Kryadi")
def root_9_57():
    """
    9.57 तुभ हिंसायाम् 
    """
    return "तुभ"


@registry.register("9.58", root="क्लिशू", meaning="विबाधने", gana="Kryadi")
def root_9_58():
    """
    9.58 क्लिशू विबाधने 
    """
    return "क्लिशू"


@registry.register("9.59", root="अश", meaning="भोजने", gana="Kryadi")
def root_9_59():
    """
    9.59 अश भोजने 
    """
    return "अश"


@registry.register("9.60", root="उध्रस", meaning="उञ्छे", gana="Kryadi")
def root_9_60():
    """
    9.60 उध्रस उञ्छे 
    """
    return "उध्रस"


@registry.register("9.61", root="इष", meaning="आभीक्ष्ण्ये", gana="Kryadi")
def root_9_61():
    """
    9.61 इष आभीक्ष्ण्ये 
    """
    return "इष"


@registry.register("9.62", root="विष", meaning="विप्रयोगे", gana="Kryadi")
def root_9_62():
    """
    9.62 विष विप्रयोगे 
    """
    return "विष"


@registry.register("9.64", root="प्लुष", meaning="स्नेहनसेवनपूरणेषु", gana="Kryadi")
def root_9_64():
    """
    9.64 प्लुष स्नेहनसेवनपूरणेषु 
    """
    return "प्लुष"


@registry.register("9.65", root="पुष", meaning="पुष्टौ", gana="Kryadi")
def root_9_65():
    """
    9.65 पुष पुष्टौ 
    """
    return "पुष"


@registry.register("9.66", root="मुष", meaning="स्तेये", gana="Kryadi")
def root_9_66():
    """
    9.66 मुष स्तेये 
    """
    return "मुष"


@registry.register("9.67", root="खच", meaning="भूतप्रादुर्भावे", gana="Kryadi")
def root_9_67():
    """
    9.67 खच भूतप्रादुर्भावे 
    """
    return "खच"


@registry.register("9.68", root="खव", meaning="इत्येके", gana="Kryadi")
def root_9_68():
    """
    9.68 खव इत्येके 
    """
    return "खव"


@registry.register("9.69", root="हेठ", meaning="च", gana="Kryadi")
def root_9_69():
    """
    9.69 हेठ च 
    """
    return "हेठ"


@registry.register("9.70", root="हेढ", meaning="इत्येके", gana="Kryadi")
def root_9_70():
    """
    9.70 हेढ इत्येके 
    """
    return "हेढ"


@registry.register("9.71", root="ग्रह", meaning="उपादाने", gana="Kryadi")
def root_9_71():
    """
    9.71 ग्रह उपादाने 
    """
    return "ग्रह"
