# Auto-generated by scripts/scaffold_roots.py for Gana 6
from . import registry


@registry.register("6.1", root="तुद", meaning="व्यथने", gana="Tudadi")
def root_6_1():
    """
    6.1 तुद व्यथने 
    """
    return "तुद"


@registry.register("6.2", root="णुद", meaning="प्रेरणे", gana="Tudadi")
def root_6_2():
    """
    6.2 णुद प्रेरणे 
    """
    return "णुद"


@registry.register("6.3", root="दिश", meaning="अतिसर्जने", gana="Tudadi")
def root_6_3():
    """
    6.3 दिश अतिसर्जने 
    """
    return "दिश"


@registry.register("6.4", root="भ्रस्ज", meaning="पाके", gana="Tudadi")
def root_6_4():
    """
    6.4 भ्रस्ज पाके 
    """
    return "भ्रस्ज"


@registry.register("6.5", root="क्षिप", meaning="प्रेरणे", gana="Tudadi")
def root_6_5():
    """
    6.5 क्षिप प्रेरणे 
    """
    return "क्षिप"


@registry.register("6.6", root="कृष", meaning="विलेखने", gana="Tudadi")
def root_6_6():
    """
    6.6 कृष विलेखने 
    """
    return "कृष"


@registry.register("6.7", root="ऋषी", meaning="गतौ", gana="Tudadi")
def root_6_7():
    """
    6.7 ऋषी गतौ 
    """
    return "ऋषी"


@registry.register("6.8", root="जुषी", meaning="प्रीतिसेवनयोः", gana="Tudadi")
def root_6_8():
    """
    6.8 जुषी प्रीतिसेवनयोः 
    """
    return "जुषी"


@registry.register("6.9", root="ओविजी", meaning="भयचलनयोः", gana="Tudadi")
def root_6_9():
    """
    6.9 ओविजी भयचलनयोः 
    """
    return "ओविजी"


@registry.register("6.11", root="ओलस्जी", meaning="व्रीडायाम् व्रीडे", gana="Tudadi")
def root_6_11():
    """
    6.11 ओलस्जी व्रीडायाम् व्रीडे 
    """
    return "ओलस्जी"


@registry.register("6.12", root="ओव्रश्चू", meaning="छेदने", gana="Tudadi")
def root_6_12():
    """
    6.12 ओव्रश्चू छेदने 
    """
    return "ओव्रश्चू"


@registry.register("6.13", root="व्यच", meaning="व्याजीकरणे", gana="Tudadi")
def root_6_13():
    """
    6.13 व्यच व्याजीकरणे 
    """
    return "व्यच"


@registry.register("6.14", root="उछि", meaning="उञ्छे", gana="Tudadi")
def root_6_14():
    """
    6.14 उछि उञ्छे 
    """
    return "उछि"


@registry.register("6.15", root="उछी", meaning="विवासे", gana="Tudadi")
def root_6_15():
    """
    6.15 उछी विवासे 
    """
    return "उछी"


@registry.register("6.16", root="ऋछ", meaning="गतीन्द्रियप्रलयमूर्तिभावेषु", gana="Tudadi")
def root_6_16():
    """
    6.16 ऋछ गतीन्द्रियप्रलयमूर्तिभावेषु 
    """
    return "ऋछ"


@registry.register("6.17", root="मिछ", meaning="उत्क्लेशे", gana="Tudadi")
def root_6_17():
    """
    6.17 मिछ उत्क्लेशे 
    """
    return "मिछ"


@registry.register("6.20", root="झर्झ", meaning="परिभाषणभर्त्सनयोः", gana="Tudadi")
def root_6_20():
    """
    6.20 झर्झ परिभाषणभर्त्सनयोः 
    """
    return "झर्झ"


@registry.register("6.21", root="त्वच", meaning="संवरणे", gana="Tudadi")
def root_6_21():
    """
    6.21 त्वच संवरणे 
    """
    return "त्वच"


@registry.register("6.22", root="ऋच", meaning="स्तुतौ", gana="Tudadi")
def root_6_22():
    """
    6.22 ऋच स्तुतौ 
    """
    return "ऋच"


@registry.register("6.23", root="उब्ज", meaning="आर्जवे", gana="Tudadi")
def root_6_23():
    """
    6.23 उब्ज आर्जवे 
    """
    return "उब्ज"


@registry.register("6.24", root="उज्झऽ", meaning="उद्झ उत्सर्गे", gana="Tudadi")
def root_6_24():
    """
    6.24 उज्झऽ उद्झ उत्सर्गे 
    """
    return "उज्झऽ"


@registry.register("6.25", root="लुभ", meaning="विमोहने", gana="Tudadi")
def root_6_25():
    """
    6.25 लुभ विमोहने 
    """
    return "लुभ"


@registry.register("6.26", root="रिफ", meaning="कत्थनयुद्धनिन्दाहिंसादानेषु", gana="Tudadi")
def root_6_26():
    """
    6.26 रिफ कत्थनयुद्धनिन्दाहिंसादानेषु 
    """
    return "रिफ"


@registry.register("6.27", root="रिह", meaning="इत्येके", gana="Tudadi")
def root_6_27():
    """
    6.27 रिह इत्येके 
    """
    return "रिह"


@registry.register("6.29", root="तृम्पऽ", meaning="तृप्तौ", gana="Tudadi")
def root_6_29():
    """
    6.29 तृम्पऽ तृप्तौ 
    """
    return "तृम्पऽ"


@registry.register("6.31", root="तृम्फ", meaning="इत्येके", gana="Tudadi")
def root_6_31():
    """
    6.31 तृम्फ इत्येके 
    """
    return "तृम्फ"


@registry.register("6.35", root="तुम्फ", meaning="हिंसायाम्", gana="Tudadi")
def root_6_35():
    """
    6.35 तुम्फ हिंसायाम् 
    """
    return "तुम्फ"


@registry.register("6.37", root="दृम्प", meaning="उत्क्लेशे", gana="Tudadi")
def root_6_37():
    """
    6.37 दृम्प उत्क्लेशे 
    """
    return "दृम्प"


@registry.register("6.39", root="दृम्फ", meaning="इत्येके", gana="Tudadi")
def root_6_39():
    """
    6.39 दृम्फ इत्येके 
    """
    return "दृम्फ"


@registry.register("6.41", root="ऋम्फ", meaning="हिंसायाम्", gana="Tudadi")
def root_6_41():
    """
    6.41 ऋम्फ हिंसायाम् 
    """
    return "ऋम्फ"


@registry.register("6.43", root="गुम्फ", meaning="ग्रन्थे", gana="Tudadi")
def root_6_43():
    """
    6.43 गुम्फ ग्रन्थे 
    """
    return "गुम्फ"


@registry.register("6.45", root="उम्भ", meaning="पूरणे", gana="Tudadi")
def root_6_45():
    """
    6.45 उम्भ पूरणे 
    """
    return "उम्भ"


@registry.register("6.47", root="शुम्भ", meaning="शोभार्थे", gana="Tudadi")
def root_6_47():
    """
    6.47 शुम्भ शोभार्थे 
    """
    return "शुम्भ"


@registry.register("6.48", root="दृभी", meaning="ग्रन्थे", gana="Tudadi")
def root_6_48():
    """
    6.48 दृभी ग्रन्थे 
    """
    return "दृभी"


@registry.register("6.49", root="चृती", meaning="हिंसाग्रन्थनयोः", gana="Tudadi")
def root_6_49():
    """
    6.49 चृती हिंसाग्रन्थनयोः 
    """
    return "चृती"


@registry.register("6.50", root="विध", meaning="विधाने", gana="Tudadi")
def root_6_50():
    """
    6.50 विध विधाने 
    """
    return "विध"


@registry.register("6.51", root="जुड", meaning="गतौ", gana="Tudadi")
def root_6_51():
    """
    6.51 जुड गतौ 
    """
    return "जुड"


@registry.register("6.52", root="जुन", meaning="इत्येके", gana="Tudadi")
def root_6_52():
    """
    6.52 जुन इत्येके 
    """
    return "जुन"


@registry.register("6.53", root="मृड", meaning="सुखने", gana="Tudadi")
def root_6_53():
    """
    6.53 मृड सुखने 
    """
    return "मृड"


@registry.register("6.54", root="पृड", meaning="च", gana="Tudadi")
def root_6_54():
    """
    6.54 पृड च 
    """
    return "पृड"


@registry.register("6.55", root="पृण", meaning="प्रीणने", gana="Tudadi")
def root_6_55():
    """
    6.55 पृण प्रीणने 
    """
    return "पृण"


@registry.register("6.56", root="वृण", meaning="च", gana="Tudadi")
def root_6_56():
    """
    6.56 वृण च 
    """
    return "वृण"


@registry.register("6.57", root="मृण", meaning="हिंसायाम्", gana="Tudadi")
def root_6_57():
    """
    6.57 मृण हिंसायाम् 
    """
    return "मृण"


@registry.register("6.58", root="तुण", meaning="कौटिल्ये", gana="Tudadi")
def root_6_58():
    """
    6.58 तुण कौटिल्ये 
    """
    return "तुण"


@registry.register("6.59", root="पुण", meaning="कर्मणि शुभे", gana="Tudadi")
def root_6_59():
    """
    6.59 पुण कर्मणि शुभे 
    """
    return "पुण"


@registry.register("6.60", root="मुण", meaning="प्रतिज्ञाने", gana="Tudadi")
def root_6_60():
    """
    6.60 मुण प्रतिज्ञाने 
    """
    return "मुण"


@registry.register("6.61", root="कुण", meaning="शब्दोपकरणयोः शब्दोपतापयोः", gana="Tudadi")
def root_6_61():
    """
    6.61 कुण शब्दोपकरणयोः शब्दोपतापयोः 
    """
    return "कुण"


@registry.register("6.62", root="शुन", meaning="गतौ", gana="Tudadi")
def root_6_62():
    """
    6.62 शुन गतौ 
    """
    return "शुन"


@registry.register("6.63", root="द्रुण", meaning="हिंसागतिकौटिल्येषु", gana="Tudadi")
def root_6_63():
    """
    6.63 द्रुण हिंसागतिकौटिल्येषु 
    """
    return "द्रुण"


@registry.register("6.65", root="घूर्ण", meaning="भ्रमणे", gana="Tudadi")
def root_6_65():
    """
    6.65 घूर्ण भ्रमणे 
    """
    return "घूर्ण"


@registry.register("6.66", root="षुर", meaning="ऐश्वर्यदीप्त्योः", gana="Tudadi")
def root_6_66():
    """
    6.66 षुर ऐश्वर्यदीप्त्योः 
    """
    return "षुर"


@registry.register("6.67", root="कुर", meaning="शब्दे", gana="Tudadi")
def root_6_67():
    """
    6.67 कुर शब्दे 
    """
    return "कुर"


@registry.register("6.68", root="खुर", meaning="छेदने", gana="Tudadi")
def root_6_68():
    """
    6.68 खुर छेदने 
    """
    return "खुर"


@registry.register("6.69", root="मुर", meaning="संवेष्टने सञ्चेष्टने", gana="Tudadi")
def root_6_69():
    """
    6.69 मुर संवेष्टने सञ्चेष्टने 
    """
    return "मुर"


@registry.register("6.70", root="क्षुर", meaning="विलेखने", gana="Tudadi")
def root_6_70():
    """
    6.70 क्षुर विलेखने 
    """
    return "क्षुर"


@registry.register("6.71", root="घुर", meaning="भीमार्थशब्दयोः", gana="Tudadi")
def root_6_71():
    """
    6.71 घुर भीमार्थशब्दयोः 
    """
    return "घुर"


@registry.register("6.72", root="पुर", meaning="अग्रगमने", gana="Tudadi")
def root_6_72():
    """
    6.72 पुर अग्रगमने 
    """
    return "पुर"


@registry.register("6.73", root="वृहू", meaning="उद्यमने", gana="Tudadi")
def root_6_73():
    """
    6.73 वृहू उद्यमने 
    """
    return "वृहू"


@registry.register("6.74", root="बृहू", meaning="इत्येके", gana="Tudadi")
def root_6_74():
    """
    6.74 बृहू इत्येके 
    """
    return "बृहू"


@registry.register("6.77", root="तृंहू", meaning="हिंसार्थाः", gana="Tudadi")
def root_6_77():
    """
    6.77 तृंहू हिंसार्थाः 
    """
    return "तृंहू"


@registry.register("6.78", root="इष", meaning="इषु इच्छायाम्", gana="Tudadi")
def root_6_78():
    """
    6.78 इष इषु इच्छायाम् 
    """
    return "इष"


@registry.register("6.79", root="मिष", meaning="स्पर्धायाम्", gana="Tudadi")
def root_6_79():
    """
    6.79 मिष स्पर्धायाम् 
    """
    return "मिष"


@registry.register("6.80", root="किल", meaning="श्वैत्यक्रीडनयोः श्वैत्ये", gana="Tudadi")
def root_6_80():
    """
    6.80 किल श्वैत्यक्रीडनयोः श्वैत्ये 
    """
    return "किल"


@registry.register("6.81", root="तिल", meaning="स्नेहने स्नेहे", gana="Tudadi")
def root_6_81():
    """
    6.81 तिल स्नेहने स्नेहे 
    """
    return "तिल"


@registry.register("6.82", root="चिल", meaning="वसने", gana="Tudadi")
def root_6_82():
    """
    6.82 चिल वसने 
    """
    return "चिल"


@registry.register("6.83", root="चल", meaning="विलसने", gana="Tudadi")
def root_6_83():
    """
    6.83 चल विलसने 
    """
    return "चल"


@registry.register("6.84", root="इल", meaning="स्वप्नक्षेपनयोः", gana="Tudadi")
def root_6_84():
    """
    6.84 इल स्वप्नक्षेपनयोः 
    """
    return "इल"


@registry.register("6.85", root="विल", meaning="संवरणे", gana="Tudadi")
def root_6_85():
    """
    6.85 विल संवरणे 
    """
    return "विल"


@registry.register("6.86", root="बिल", meaning="भेदने", gana="Tudadi")
def root_6_86():
    """
    6.86 बिल भेदने 
    """
    return "बिल"


@registry.register("6.87", root="णिल", meaning="गहने", gana="Tudadi")
def root_6_87():
    """
    6.87 णिल गहने 
    """
    return "णिल"


@registry.register("6.88", root="हिल", meaning="भावकरणे", gana="Tudadi")
def root_6_88():
    """
    6.88 हिल भावकरणे 
    """
    return "हिल"


@registry.register("6.90", root="षिल", meaning="उञ्छे", gana="Tudadi")
def root_6_90():
    """
    6.90 षिल उञ्छे 
    """
    return "षिल"


@registry.register("6.91", root="मिल", meaning="श्लेषणे", gana="Tudadi")
def root_6_91():
    """
    6.91 मिल श्लेषणे 
    """
    return "मिल"


@registry.register("6.92", root="लिख", meaning="अक्षरविन्यासे", gana="Tudadi")
def root_6_92():
    """
    6.92 लिख अक्षरविन्यासे 
    """
    return "लिख"


@registry.register("6.93", root="कुट", meaning="कौटिल्ये", gana="Tudadi")
def root_6_93():
    """
    6.93 कुट कौटिल्ये 
    """
    return "कुट"


@registry.register("6.94", root="पुट", meaning="संश्लेषणे", gana="Tudadi")
def root_6_94():
    """
    6.94 पुट संश्लेषणे 
    """
    return "पुट"


@registry.register("6.95", root="कुच", meaning="सङ्कोचने", gana="Tudadi")
def root_6_95():
    """
    6.95 कुच सङ्कोचने 
    """
    return "कुच"


@registry.register("6.96", root="गुज", meaning="शब्दे", gana="Tudadi")
def root_6_96():
    """
    6.96 गुज शब्दे 
    """
    return "गुज"


@registry.register("6.97", root="गुड", meaning="रक्षायाम्", gana="Tudadi")
def root_6_97():
    """
    6.97 गुड रक्षायाम् 
    """
    return "गुड"


@registry.register("6.98", root="डिप", meaning="क्षेपे", gana="Tudadi")
def root_6_98():
    """
    6.98 डिप क्षेपे 
    """
    return "डिप"


@registry.register("6.99", root="छुर", meaning="छेदने", gana="Tudadi")
def root_6_99():
    """
    6.99 छुर छेदने 
    """
    return "छुर"


@registry.register("6.100", root="स्फुट", meaning="विकसने", gana="Tudadi")
def root_6_100():
    """
    6.100 स्फुट विकसने 
    """
    return "स्फुट"


@registry.register("6.101", root="मुट", meaning="आक्षेपप्रमर्दनयोः", gana="Tudadi")
def root_6_101():
    """
    6.101 मुट आक्षेपप्रमर्दनयोः 
    """
    return "मुट"


@registry.register("6.102", root="त्रुट", meaning="छेदने", gana="Tudadi")
def root_6_102():
    """
    6.102 त्रुट छेदने 
    """
    return "त्रुट"


@registry.register("6.103", root="तुट", meaning="कलहकर्मणि", gana="Tudadi")
def root_6_103():
    """
    6.103 तुट कलहकर्मणि 
    """
    return "तुट"


@registry.register("6.105", root="छुट", meaning="छेदने", gana="Tudadi")
def root_6_105():
    """
    6.105 छुट छेदने 
    """
    return "छुट"


@registry.register("6.106", root="जुड", meaning="बन्धने", gana="Tudadi")
def root_6_106():
    """
    6.106 जुड बन्धने 
    """
    return "जुड"


@registry.register("6.107", root="जुट", meaning="इत्येके", gana="Tudadi")
def root_6_107():
    """
    6.107 जुट इत्येके 
    """
    return "जुट"


@registry.register("6.108", root="कड", meaning="मदे", gana="Tudadi")
def root_6_108():
    """
    6.108 कड मदे 
    """
    return "कड"


@registry.register("6.109", root="लुट", meaning="संश्लेषणे", gana="Tudadi")
def root_6_109():
    """
    6.109 लुट संश्लेषणे 
    """
    return "लुट"


@registry.register("6.110", root="लुठ", meaning="इत्येके", gana="Tudadi")
def root_6_110():
    """
    6.110 लुठ इत्येके 
    """
    return "लुठ"


@registry.register("6.111", root="लुड", meaning="इत्यन्ये", gana="Tudadi")
def root_6_111():
    """
    6.111 लुड इत्यन्ये 
    """
    return "लुड"


@registry.register("6.112", root="कृड", meaning="घनत्वे", gana="Tudadi")
def root_6_112():
    """
    6.112 कृड घनत्वे 
    """
    return "कृड"


@registry.register("6.113", root="कुड", meaning="बाल्ये", gana="Tudadi")
def root_6_113():
    """
    6.113 कुड बाल्ये 
    """
    return "कुड"


@registry.register("6.114", root="पुड", meaning="उत्सर्गे", gana="Tudadi")
def root_6_114():
    """
    6.114 पुड उत्सर्गे 
    """
    return "पुड"


@registry.register("6.115", root="घुट", meaning="प्रतिघाते", gana="Tudadi")
def root_6_115():
    """
    6.115 घुट प्रतिघाते 
    """
    return "घुट"


@registry.register("6.116", root="तुड", meaning="तोडने", gana="Tudadi")
def root_6_116():
    """
    6.116 तुड तोडने 
    """
    return "तुड"


@registry.register("6.118", root="स्थुड", meaning="संवरणे", gana="Tudadi")
def root_6_118():
    """
    6.118 स्थुड संवरणे 
    """
    return "स्थुड"


@registry.register("6.120", root="छुड", meaning="इत्येके", gana="Tudadi")
def root_6_120():
    """
    6.120 छुड इत्येके 
    """
    return "छुड"


@registry.register("6.122", root="स्फुल", meaning="सञ्चलने", gana="Tudadi")
def root_6_122():
    """
    6.122 स्फुल सञ्चलने 
    """
    return "स्फुल"


@registry.register("6.124", root="स्फल", meaning="इत्यन्ये", gana="Tudadi")
def root_6_124():
    """
    6.124 स्फल इत्यन्ये 
    """
    return "स्फल"


@registry.register("6.127", root="व्रुड", meaning="संवरणे", gana="Tudadi")
def root_6_127():
    """
    6.127 व्रुड संवरणे 
    """
    return "व्रुड"


@registry.register("6.129", root="भृड", meaning="निमज्जने इत्येके", gana="Tudadi")
def root_6_129():
    """
    6.129 भृड निमज्जने इत्येके 
    """
    return "भृड"


@registry.register("6.130", root="हुड", meaning="सङ्घाते", gana="Tudadi")
def root_6_130():
    """
    6.130 हुड सङ्घाते 
    """
    return "हुड"


@registry.register("6.131", root="गुरी", meaning="उद्यमने", gana="Tudadi")
def root_6_131():
    """
    6.131 गुरी उद्यमने 
    """
    return "गुरी"


@registry.register("6.132", root="णू", meaning="णु स्तुतौ", gana="Tudadi")
def root_6_132():
    """
    6.132 णू णु स्तुतौ 
    """
    return "णू"


@registry.register("6.133", root="धू", meaning="धु विधूनने", gana="Tudadi")
def root_6_133():
    """
    6.133 धू धु विधूनने 
    """
    return "धू"


@registry.register("6.134", root="गु", meaning="पुरीषोत्सर्गे", gana="Tudadi")
def root_6_134():
    """
    6.134 गु पुरीषोत्सर्गे 
    """
    return "गु"


@registry.register("6.135", root="ध्रु", meaning="गतिस्थैर्ययोः", gana="Tudadi")
def root_6_135():
    """
    6.135 ध्रु गतिस्थैर्ययोः 
    """
    return "ध्रु"


@registry.register("6.136", root="कुङ्", meaning="शब्दे", gana="Tudadi")
def root_6_136():
    """
    6.136 कुङ् शब्दे 
    """
    return "कुङ्"


@registry.register("6.137", root="कूङ्", meaning="इत्येके दीर्घान्त इति कैयटादयः", gana="Tudadi")
def root_6_137():
    """
    6.137 कूङ् इत्येके दीर्घान्त इति कैयटादयः 
    """
    return "कूङ्"


@registry.register("6.138", root="पृङ्", meaning="व्यायामे", gana="Tudadi")
def root_6_138():
    """
    6.138 पृङ् व्यायामे 
    """
    return "पृङ्"


@registry.register("6.139", root="मृङ्", meaning="प्राणत्यागे", gana="Tudadi")
def root_6_139():
    """
    6.139 मृङ् प्राणत्यागे 
    """
    return "मृङ्"


@registry.register("6.141", root="पि", meaning="गतौ", gana="Tudadi")
def root_6_141():
    """
    6.141 पि गतौ 
    """
    return "पि"


@registry.register("6.142", root="धि", meaning="धारणे", gana="Tudadi")
def root_6_142():
    """
    6.142 धि धारणे 
    """
    return "धि"


@registry.register("6.143", root="क्षि", meaning="निवासगत्योः", gana="Tudadi")
def root_6_143():
    """
    6.143 क्षि निवासगत्योः 
    """
    return "क्षि"


@registry.register("6.144", root="षू", meaning="प्रेरणे", gana="Tudadi")
def root_6_144():
    """
    6.144 षू प्रेरणे 
    """
    return "षू"


@registry.register("6.145", root="कृई", meaning="विक्षेपे निक्षेपे", gana="Tudadi")
def root_6_145():
    """
    6.145 कृई विक्षेपे निक्षेपे 
    """
    return "कृई"


@registry.register("6.146", root="गृई", meaning="निगरणे", gana="Tudadi")
def root_6_146():
    """
    6.146 गृई निगरणे 
    """
    return "गृई"


@registry.register("6.147", root="दृङ्", meaning="आदरे", gana="Tudadi")
def root_6_147():
    """
    6.147 दृङ् आदरे 
    """
    return "दृङ्"


@registry.register("6.148", root="धृङ्", meaning="अवस्थाने", gana="Tudadi")
def root_6_148():
    """
    6.148 धृङ् अवस्थाने 
    """
    return "धृङ्"


@registry.register("6.149", root="प्रछ", meaning="ज्ञीप्सायाम्", gana="Tudadi")
def root_6_149():
    """
    6.149 प्रछ ज्ञीप्सायाम् 
    """
    return "प्रछ"


@registry.register("6.150", root="सृज", meaning="विसर्गे", gana="Tudadi")
def root_6_150():
    """
    6.150 सृज विसर्गे 
    """
    return "सृज"


@registry.register("6.151", root="टुमस्जो", meaning="शुद्धौ", gana="Tudadi")
def root_6_151():
    """
    6.151 टुमस्जो शुद्धौ 
    """
    return "टुमस्जो"


@registry.register("6.152", root="रुजो", meaning="भङ्गे", gana="Tudadi")
def root_6_152():
    """
    6.152 रुजो भङ्गे 
    """
    return "रुजो"


@registry.register("6.153", root="भुजो", meaning="कौटिल्ये", gana="Tudadi")
def root_6_153():
    """
    6.153 भुजो कौटिल्ये 
    """
    return "भुजो"


@registry.register("6.154", root="छुप", meaning="स्पर्शे", gana="Tudadi")
def root_6_154():
    """
    6.154 छुप स्पर्शे 
    """
    return "छुप"


@registry.register("6.156", root="रिश", meaning="हिंसायाम्", gana="Tudadi")
def root_6_156():
    """
    6.156 रिश हिंसायाम् 
    """
    return "रिश"


@registry.register("6.157", root="लिश", meaning="गतौ", gana="Tudadi")
def root_6_157():
    """
    6.157 लिश गतौ 
    """
    return "लिश"


@registry.register("6.158", root="स्पृश", meaning="संस्पर्शने", gana="Tudadi")
def root_6_158():
    """
    6.158 स्पृश संस्पर्शने 
    """
    return "स्पृश"


@registry.register("6.159", root="विछ", meaning="गतौ", gana="Tudadi")
def root_6_159():
    """
    6.159 विछ गतौ 
    """
    return "विछ"


@registry.register("6.160", root="विश", meaning="प्रवेशने", gana="Tudadi")
def root_6_160():
    """
    6.160 विश प्रवेशने 
    """
    return "विश"


@registry.register("6.161", root="मृश", meaning="आमर्शणे", gana="Tudadi")
def root_6_161():
    """
    6.161 मृश आमर्शणे 
    """
    return "मृश"


@registry.register("6.162", root="णुद", meaning="प्रेरणे", gana="Tudadi")
def root_6_162():
    """
    6.162 णुद प्रेरणे 
    """
    return "णुद"


@registry.register("6.163", root="षदॢ", meaning="विशरणगत्यवसादनेषु", gana="Tudadi")
def root_6_163():
    """
    6.163 षदॢ विशरणगत्यवसादनेषु 
    """
    return "षदॢ"


@registry.register("6.164", root="शदॢ", meaning="शातने", gana="Tudadi")
def root_6_164():
    """
    6.164 शदॢ शातने 
    """
    return "शदॢ"


@registry.register("6.165", root="मिल", meaning="सङ्गमे सङ्गमने", gana="Tudadi")
def root_6_165():
    """
    6.165 मिल सङ्गमे सङ्गमने 
    """
    return "मिल"


@registry.register("6.166", root="मुचॢ", meaning="मोक्षणे मोचने", gana="Tudadi")
def root_6_166():
    """
    6.166 मुचॢ मोक्षणे मोचने 
    """
    return "मुचॢ"


@registry.register("6.167", root="लुपॢ", meaning="छेदने", gana="Tudadi")
def root_6_167():
    """
    6.167 लुपॢ छेदने 
    """
    return "लुपॢ"


@registry.register("6.168", root="विदॢ", meaning="लाभे", gana="Tudadi")
def root_6_168():
    """
    6.168 विदॢ लाभे 
    """
    return "विदॢ"


@registry.register("6.169", root="लिप", meaning="उपदेहे", gana="Tudadi")
def root_6_169():
    """
    6.169 लिप उपदेहे 
    """
    return "लिप"


@registry.register("6.170", root="षिच", meaning="क्षरणे", gana="Tudadi")
def root_6_170():
    """
    6.170 षिच क्षरणे 
    """
    return "षिच"


@registry.register("6.171", root="कृती", meaning="छेदने", gana="Tudadi")
def root_6_171():
    """
    6.171 कृती छेदने 
    """
    return "कृती"


@registry.register("6.172", root="खिद", meaning="परिघाते परिघातने", gana="Tudadi")
def root_6_172():
    """
    6.172 खिद परिघाते परिघातने 
    """
    return "खिद"


@registry.register("6.173", root="पिश", meaning="अवयवे", gana="Tudadi")
def root_6_173():
    """
    6.173 पिश अवयवे 
    """
    return "पिश"
