# Auto-generated by scripts/scaffold_roots.py for Gana 4
from . import registry


@registry.register("4.1", root="दिवु", meaning="क्रीडाविजिगीषाव्यवहारद्युतिस्तुतिमोदमदस्वप्नकान्तिगतिषु", gana="Divadi")
def root_4_1():
    """
    4.1 दिवु क्रीडाविजिगीषाव्यवहारद्युतिस्तुतिमोदमदस्वप्नकान्तिगतिषु 
    """
    return "दिवु"


@registry.register("4.2", root="षिवु", meaning="तन्तुसन्ताने", gana="Divadi")
def root_4_2():
    """
    4.2 षिवु तन्तुसन्ताने 
    """
    return "षिवु"


@registry.register("4.3", root="स्रिवु", meaning="गतिशोषणयोः", gana="Divadi")
def root_4_3():
    """
    4.3 स्रिवु गतिशोषणयोः 
    """
    return "स्रिवु"


@registry.register("4.4", root="ष्ठिवु", meaning="निरसने", gana="Divadi")
def root_4_4():
    """
    4.4 ष्ठिवु निरसने 
    """
    return "ष्ठिवु"


@registry.register("4.5", root="ष्णुसु", meaning="अदने", gana="Divadi")
def root_4_5():
    """
    4.5 ष्णुसु अदने 
    """
    return "ष्णुसु"


@registry.register("4.6", root="ष्णसु", meaning="निरसने", gana="Divadi")
def root_4_6():
    """
    4.6 ष्णसु निरसने 
    """
    return "ष्णसु"


@registry.register("4.7", root="क्नसु", meaning="ह्वरणदीप्त्योः", gana="Divadi")
def root_4_7():
    """
    4.7 क्नसु ह्वरणदीप्त्योः 
    """
    return "क्नसु"


@registry.register("4.8", root="व्युष", meaning="दाहे", gana="Divadi")
def root_4_8():
    """
    4.8 व्युष दाहे 
    """
    return "व्युष"


@registry.register("4.9", root="प्लुष", meaning="च", gana="Divadi")
def root_4_9():
    """
    4.9 प्लुष च 
    """
    return "प्लुष"


@registry.register("4.10", root="नृती", meaning="गात्रविक्षेपे", gana="Divadi")
def root_4_10():
    """
    4.10 नृती गात्रविक्षेपे 
    """
    return "नृती"


@registry.register("4.11", root="त्रसी", meaning="उद्वेगे", gana="Divadi")
def root_4_11():
    """
    4.11 त्रसी उद्वेगे 
    """
    return "त्रसी"


@registry.register("4.12", root="कुथ", meaning="पूतीभावे", gana="Divadi")
def root_4_12():
    """
    4.12 कुथ पूतीभावे 
    """
    return "कुथ"


@registry.register("4.13", root="पुथ", meaning="हिंसायाम्", gana="Divadi")
def root_4_13():
    """
    4.13 पुथ हिंसायाम् 
    """
    return "पुथ"


@registry.register("4.14", root="गुध", meaning="परिवेष्टने", gana="Divadi")
def root_4_14():
    """
    4.14 गुध परिवेष्टने 
    """
    return "गुध"


@registry.register("4.15", root="क्षिप", meaning="प्रेरणे", gana="Divadi")
def root_4_15():
    """
    4.15 क्षिप प्रेरणे 
    """
    return "क्षिप"


@registry.register("4.16", root="पुष्प", meaning="विकसने", gana="Divadi")
def root_4_16():
    """
    4.16 पुष्प विकसने 
    """
    return "पुष्प"


@registry.register("4.20", root="ष्टीम", meaning="आर्द्रीभावे", gana="Divadi")
def root_4_20():
    """
    4.20 ष्टीम आर्द्रीभावे 
    """
    return "ष्टीम"


@registry.register("4.21", root="व्रीड", meaning="चोदने लज्जायां च", gana="Divadi")
def root_4_21():
    """
    4.21 व्रीड चोदने लज्जायां च 
    """
    return "व्रीड"


@registry.register("4.22", root="इष", meaning="गतौ", gana="Divadi")
def root_4_22():
    """
    4.22 इष गतौ 
    """
    return "इष"


@registry.register("4.24", root="षुह", meaning="चक्यर्थे", gana="Divadi")
def root_4_24():
    """
    4.24 षुह चक्यर्थे 
    """
    return "षुह"


@registry.register("4.26", root="झृईष्", meaning="वयोहानौ", gana="Divadi")
def root_4_26():
    """
    4.26 झृईष् वयोहानौ 
    """
    return "झृईष्"


@registry.register("4.27", root="ओषूङ्", meaning="प्राणिप्रसवे", gana="Divadi")
def root_4_27():
    """
    4.27 ओषूङ् प्राणिप्रसवे 
    """
    return "ओषूङ्"


@registry.register("4.28", root="ओदूङ्", meaning="परितापे", gana="Divadi")
def root_4_28():
    """
    4.28 ओदूङ् परितापे 
    """
    return "ओदूङ्"


@registry.register("4.29", root="ओदीङ्", meaning="क्षये", gana="Divadi")
def root_4_29():
    """
    4.29 ओदीङ् क्षये 
    """
    return "ओदीङ्"


@registry.register("4.30", root="ओडीङ्", meaning="विहायसा गतौ", gana="Divadi")
def root_4_30():
    """
    4.30 ओडीङ् विहायसा गतौ 
    """
    return "ओडीङ्"


@registry.register("4.31", root="ओधीङ्", meaning="आधारे", gana="Divadi")
def root_4_31():
    """
    4.31 ओधीङ् आधारे 
    """
    return "ओधीङ्"


@registry.register("4.32", root="ओमीङ्", meaning="हिंसायाम्", gana="Divadi")
def root_4_32():
    """
    4.32 ओमीङ् हिंसायाम् 
    """
    return "ओमीङ्"


@registry.register("4.33", root="ओरीङ्", meaning="श्रवणे", gana="Divadi")
def root_4_33():
    """
    4.33 ओरीङ् श्रवणे 
    """
    return "ओरीङ्"


@registry.register("4.34", root="ओलीङ्", meaning="श्लेषणे", gana="Divadi")
def root_4_34():
    """
    4.34 ओलीङ् श्लेषणे 
    """
    return "ओलीङ्"


@registry.register("4.35", root="ओव्रीङ्", meaning="वृणोत्यर्थे", gana="Divadi")
def root_4_35():
    """
    4.35 ओव्रीङ् वृणोत्यर्थे 
    """
    return "ओव्रीङ्"


@registry.register("4.36", root="पीङ्", meaning="पाने", gana="Divadi")
def root_4_36():
    """
    4.36 पीङ् पाने 
    """
    return "पीङ्"


@registry.register("4.37", root="माङ्", meaning="माने", gana="Divadi")
def root_4_37():
    """
    4.37 माङ् माने 
    """
    return "माङ्"


@registry.register("4.38", root="ईङ्", meaning="गतौ", gana="Divadi")
def root_4_38():
    """
    4.38 ईङ् गतौ 
    """
    return "ईङ्"


@registry.register("4.39", root="प्रीङ्", meaning="प्रीतौ प्रीणने", gana="Divadi")
def root_4_39():
    """
    4.39 प्रीङ् प्रीतौ प्रीणने 
    """
    return "प्रीङ्"


@registry.register("4.40", root="शो", meaning="तनूकरणे", gana="Divadi")
def root_4_40():
    """
    4.40 शो तनूकरणे 
    """
    return "शो"


@registry.register("4.41", root="छो", meaning="छेदने", gana="Divadi")
def root_4_41():
    """
    4.41 छो छेदने 
    """
    return "छो"


@registry.register("4.42", root="षो", meaning="अन्तकर्मणि", gana="Divadi")
def root_4_42():
    """
    4.42 षो अन्तकर्मणि 
    """
    return "षो"


@registry.register("4.43", root="दो", meaning="अवखण्डने", gana="Divadi")
def root_4_43():
    """
    4.43 दो अवखण्डने 
    """
    return "दो"


@registry.register("4.44", root="जनी", meaning="प्रादुर्भावे", gana="Divadi")
def root_4_44():
    """
    4.44 जनी प्रादुर्भावे 
    """
    return "जनी"


@registry.register("4.45", root="दीपी", meaning="दीप्तौ", gana="Divadi")
def root_4_45():
    """
    4.45 दीपी दीप्तौ 
    """
    return "दीपी"


@registry.register("4.46", root="पूरी", meaning="आप्यायने", gana="Divadi")
def root_4_46():
    """
    4.46 पूरी आप्यायने 
    """
    return "पूरी"


@registry.register("4.47", root="तूरी", meaning="गतित्वरणहिंसनयोः", gana="Divadi")
def root_4_47():
    """
    4.47 तूरी गतित्वरणहिंसनयोः 
    """
    return "तूरी"


@registry.register("4.49", root="गूरी", meaning="हिंसागत्योः", gana="Divadi")
def root_4_49():
    """
    4.49 गूरी हिंसागत्योः 
    """
    return "गूरी"


@registry.register("4.51", root="जूरी", meaning="हिंसावयोहन्योः", gana="Divadi")
def root_4_51():
    """
    4.51 जूरी हिंसावयोहन्योः 
    """
    return "जूरी"


@registry.register("4.52", root="शूरी", meaning="हिंसास्तम्भनयोः हिंसस्तम्भयोः", gana="Divadi")
def root_4_52():
    """
    4.52 शूरी हिंसास्तम्भनयोः हिंसस्तम्भयोः 
    """
    return "शूरी"


@registry.register("4.53", root="चूरी", meaning="दाहे", gana="Divadi")
def root_4_53():
    """
    4.53 चूरी दाहे 
    """
    return "चूरी"


@registry.register("4.54", root="तप", meaning="ऐश्वेर्ये वा", gana="Divadi")
def root_4_54():
    """
    4.54 तप ऐश्वेर्ये वा 
    """
    return "तप"


@registry.register("4.55", root="वृतु", meaning="वरणे वर्तने", gana="Divadi")
def root_4_55():
    """
    4.55 वृतु वरणे वर्तने 
    """
    return "वृतु"


@registry.register("4.56", root="वावृतु", meaning="इति केचित्", gana="Divadi")
def root_4_56():
    """
    4.56 वावृतु इति केचित् 
    """
    return "वावृतु"


@registry.register("4.57", root="क्लिश", meaning="उपतापे", gana="Divadi")
def root_4_57():
    """
    4.57 क्लिश उपतापे 
    """
    return "क्लिश"


@registry.register("4.58", root="काश‍ृ", meaning="दीप्तौ", gana="Divadi")
def root_4_58():
    """
    4.58 काश‍ृ दीप्तौ 
    """
    return "काश‍ृ"


@registry.register("4.59", root="वाश‍ृ", meaning="शब्दे", gana="Divadi")
def root_4_59():
    """
    4.59 वाश‍ृ शब्दे 
    """
    return "वाश‍ृ"


@registry.register("4.60", root="मृष", meaning="तितिक्षायाम्", gana="Divadi")
def root_4_60():
    """
    4.60 मृष तितिक्षायाम् 
    """
    return "मृष"


@registry.register("4.61", root="ईशुचिर्", meaning="पूतीभावे", gana="Divadi")
def root_4_61():
    """
    4.61 ईशुचिर् पूतीभावे 
    """
    return "ईशुचिर्"


@registry.register("4.62", root="णह", meaning="बन्धने", gana="Divadi")
def root_4_62():
    """
    4.62 णह बन्धने 
    """
    return "णह"


@registry.register("4.63", root="रञ्ज", meaning="रागे", gana="Divadi")
def root_4_63():
    """
    4.63 रञ्ज रागे 
    """
    return "रञ्ज"


@registry.register("4.64", root="शप", meaning="आक्रोशे", gana="Divadi")
def root_4_64():
    """
    4.64 शप आक्रोशे 
    """
    return "शप"


@registry.register("4.65", root="पद", meaning="गतौ", gana="Divadi")
def root_4_65():
    """
    4.65 पद गतौ 
    """
    return "पद"


@registry.register("4.66", root="खिद", meaning="दैन्ये", gana="Divadi")
def root_4_66():
    """
    4.66 खिद दैन्ये 
    """
    return "खिद"


@registry.register("4.67", root="विद", meaning="सत्तायाम्", gana="Divadi")
def root_4_67():
    """
    4.67 विद सत्तायाम् 
    """
    return "विद"


@registry.register("4.68", root="बुध", meaning="अवगमने", gana="Divadi")
def root_4_68():
    """
    4.68 बुध अवगमने 
    """
    return "बुध"


@registry.register("4.69", root="युध", meaning="सम्प्रहारे", gana="Divadi")
def root_4_69():
    """
    4.69 युध सम्प्रहारे 
    """
    return "युध"


@registry.register("4.70", root="अनोरुध", meaning="कामे", gana="Divadi")
def root_4_70():
    """
    4.70 अनोरुध कामे 
    """
    return "अनोरुध"


@registry.register("4.71", root="अण", meaning="प्राणने", gana="Divadi")
def root_4_71():
    """
    4.71 अण प्राणने 
    """
    return "अण"


@registry.register("4.72", root="अन", meaning="इत्येके", gana="Divadi")
def root_4_72():
    """
    4.72 अन इत्येके 
    """
    return "अन"


@registry.register("4.73", root="मन", meaning="ज्ञाने", gana="Divadi")
def root_4_73():
    """
    4.73 मन ज्ञाने 
    """
    return "मन"


@registry.register("4.74", root="युज", meaning="समाधौ", gana="Divadi")
def root_4_74():
    """
    4.74 युज समाधौ 
    """
    return "युज"


@registry.register("4.75", root="सृज", meaning="विसर्गे", gana="Divadi")
def root_4_75():
    """
    4.75 सृज विसर्गे 
    """
    return "सृज"


@registry.register("4.76", root="लिश", meaning="अल्पीभावे", gana="Divadi")
def root_4_76():
    """
    4.76 लिश अल्पीभावे 
    """
    return "लिश"


@registry.register("4.78", root="व्यध", meaning="ताडने", gana="Divadi")
def root_4_78():
    """
    4.78 व्यध ताडने 
    """
    return "व्यध"


@registry.register("4.79", root="पुष", meaning="पुष्टौ", gana="Divadi")
def root_4_79():
    """
    4.79 पुष पुष्टौ 
    """
    return "पुष"


@registry.register("4.80", root="शुष", meaning="शोषणे", gana="Divadi")
def root_4_80():
    """
    4.80 शुष शोषणे 
    """
    return "शुष"


@registry.register("4.81", root="तुष", meaning="प्रीतौ", gana="Divadi")
def root_4_81():
    """
    4.81 तुष प्रीतौ 
    """
    return "तुष"


@registry.register("4.82", root="दुष", meaning="वैकृत्ये", gana="Divadi")
def root_4_82():
    """
    4.82 दुष वैकृत्ये 
    """
    return "दुष"


@registry.register("4.83", root="श्लिष", meaning="आलिङ्गने", gana="Divadi")
def root_4_83():
    """
    4.83 श्लिष आलिङ्गने 
    """
    return "श्लिष"


@registry.register("4.84", root="शक", meaning="विभाषितो मर्षणे", gana="Divadi")
def root_4_84():
    """
    4.84 शक विभाषितो मर्षणे 
    """
    return "शक"


@registry.register("4.85", root="ष्विदा", meaning="गात्रप्रक्षरणे", gana="Divadi")
def root_4_85():
    """
    4.85 ष्विदा गात्रप्रक्षरणे 
    """
    return "ष्विदा"


@registry.register("4.86", root="क्रुध", meaning="क्रोधे कोपे", gana="Divadi")
def root_4_86():
    """
    4.86 क्रुध क्रोधे कोपे 
    """
    return "क्रुध"


@registry.register("4.87", root="क्षुध", meaning="बुभुक्षायाम्", gana="Divadi")
def root_4_87():
    """
    4.87 क्षुध बुभुक्षायाम् 
    """
    return "क्षुध"


@registry.register("4.88", root="शुध", meaning="शौचे", gana="Divadi")
def root_4_88():
    """
    4.88 शुध शौचे 
    """
    return "शुध"


@registry.register("4.89", root="षिधु", meaning="संराद्धौ", gana="Divadi")
def root_4_89():
    """
    4.89 षिधु संराद्धौ 
    """
    return "षिधु"


@registry.register("4.90", root="रध", meaning="हिंसासंराद्ध्योः", gana="Divadi")
def root_4_90():
    """
    4.90 रध हिंसासंराद्ध्योः 
    """
    return "रध"


@registry.register("4.91", root="णश", meaning="अदर्शने", gana="Divadi")
def root_4_91():
    """
    4.91 णश अदर्शने 
    """
    return "णश"


@registry.register("4.92", root="तृप", meaning="प्रीणने", gana="Divadi")
def root_4_92():
    """
    4.92 तृप प्रीणने 
    """
    return "तृप"


@registry.register("4.93", root="दृप", meaning="हर्षमोहनयोः", gana="Divadi")
def root_4_93():
    """
    4.93 दृप हर्षमोहनयोः 
    """
    return "दृप"


@registry.register("4.94", root="द्रुह", meaning="जिघांसायाम्", gana="Divadi")
def root_4_94():
    """
    4.94 द्रुह जिघांसायाम् 
    """
    return "द्रुह"


@registry.register("4.95", root="मुह", meaning="वैचित्त्ये", gana="Divadi")
def root_4_95():
    """
    4.95 मुह वैचित्त्ये 
    """
    return "मुह"


@registry.register("4.96", root="ष्णुह", meaning="उद्गिरणे", gana="Divadi")
def root_4_96():
    """
    4.96 ष्णुह उद्गिरणे 
    """
    return "ष्णुह"


@registry.register("4.97", root="ष्णिह", meaning="प्रीतौ", gana="Divadi")
def root_4_97():
    """
    4.97 ष्णिह प्रीतौ 
    """
    return "ष्णिह"


@registry.register("4.98", root="शमु", meaning="उपशमे", gana="Divadi")
def root_4_98():
    """
    4.98 शमु उपशमे 
    """
    return "शमु"


@registry.register("4.99", root="तमु", meaning="काङ्क्षायाम्", gana="Divadi")
def root_4_99():
    """
    4.99 तमु काङ्क्षायाम् 
    """
    return "तमु"


@registry.register("4.100", root="दमु", meaning="उपशमे", gana="Divadi")
def root_4_100():
    """
    4.100 दमु उपशमे 
    """
    return "दमु"


@registry.register("4.101", root="श्रमु", meaning="तपसि खेदे च", gana="Divadi")
def root_4_101():
    """
    4.101 श्रमु तपसि खेदे च 
    """
    return "श्रमु"


@registry.register("4.102", root="भ्रमु", meaning="अनवस्थाने", gana="Divadi")
def root_4_102():
    """
    4.102 भ्रमु अनवस्थाने 
    """
    return "भ्रमु"


@registry.register("4.103", root="क्षमू", meaning="सहने", gana="Divadi")
def root_4_103():
    """
    4.103 क्षमू सहने 
    """
    return "क्षमू"


@registry.register("4.104", root="क्लमु", meaning="ग्लानौ", gana="Divadi")
def root_4_104():
    """
    4.104 क्लमु ग्लानौ 
    """
    return "क्लमु"


@registry.register("4.105", root="मदी", meaning="हर्षे", gana="Divadi")
def root_4_105():
    """
    4.105 मदी हर्षे 
    """
    return "मदी"


@registry.register("4.106", root="असु", meaning="क्षेपने", gana="Divadi")
def root_4_106():
    """
    4.106 असु क्षेपने 
    """
    return "असु"


@registry.register("4.107", root="यसु", meaning="प्रयत्ने", gana="Divadi")
def root_4_107():
    """
    4.107 यसु प्रयत्ने 
    """
    return "यसु"


@registry.register("4.108", root="जसु", meaning="मोक्षने", gana="Divadi")
def root_4_108():
    """
    4.108 जसु मोक्षने 
    """
    return "जसु"


@registry.register("4.109", root="तसु", meaning="उपक्षये", gana="Divadi")
def root_4_109():
    """
    4.109 तसु उपक्षये 
    """
    return "तसु"


@registry.register("4.110", root="दसु", meaning="च", gana="Divadi")
def root_4_110():
    """
    4.110 दसु च 
    """
    return "दसु"


@registry.register("4.111", root="वसु", meaning="स्तम्भे", gana="Divadi")
def root_4_111():
    """
    4.111 वसु स्तम्भे 
    """
    return "वसु"


@registry.register("4.112", root="बसु", meaning="इत्येके बादिरित्येके", gana="Divadi")
def root_4_112():
    """
    4.112 बसु इत्येके बादिरित्येके 
    """
    return "बसु"


@registry.register("4.113", root="भसु", meaning="इति केचित्", gana="Divadi")
def root_4_113():
    """
    4.113 भसु इति केचित् 
    """
    return "भसु"


@registry.register("4.114", root="व्युष", meaning="विभागे", gana="Divadi")
def root_4_114():
    """
    4.114 व्युष विभागे 
    """
    return "व्युष"


@registry.register("4.115", root="व्युस", meaning="इत्येके", gana="Divadi")
def root_4_115():
    """
    4.115 व्युस इत्येके 
    """
    return "व्युस"


@registry.register("4.116", root="ब्युस", meaning="इत्यन्ये ओष्ठ्यादिर्दन्त्यन्तो ब्युस इत्यन्ये", gana="Divadi")
def root_4_116():
    """
    4.116 ब्युस इत्यन्ये ओष्ठ्यादिर्दन्त्यन्तो ब्युस इत्यन्ये 
    """
    return "ब्युस"


@registry.register("4.117", root="बुस", meaning="इत्यपरे अयकार बुस इत्यपरे", gana="Divadi")
def root_4_117():
    """
    4.117 बुस इत्यपरे अयकार बुस इत्यपरे 
    """
    return "बुस"


@registry.register("4.118", root="वुस", meaning="इति केचित्", gana="Divadi")
def root_4_118():
    """
    4.118 वुस इति केचित् 
    """
    return "वुस"


@registry.register("4.121", root="पुष", meaning="च", gana="Divadi")
def root_4_121():
    """
    4.121 पुष च 
    """
    return "पुष"


@registry.register("4.122", root="प्लुष", meaning="दाहे", gana="Divadi")
def root_4_122():
    """
    4.122 प्लुष दाहे 
    """
    return "प्लुष"


@registry.register("4.123", root="विस", meaning="प्रेरणे", gana="Divadi")
def root_4_123():
    """
    4.123 विस प्रेरणे 
    """
    return "विस"


@registry.register("4.124", root="बिस", meaning="इत्येके", gana="Divadi")
def root_4_124():
    """
    4.124 बिस इत्येके 
    """
    return "बिस"


@registry.register("4.125", root="कुस", meaning="संश्लेषणे श्लेषणे", gana="Divadi")
def root_4_125():
    """
    4.125 कुस संश्लेषणे श्लेषणे 
    """
    return "कुस"


@registry.register("4.126", root="कुश", meaning="इत्येके", gana="Divadi")
def root_4_126():
    """
    4.126 कुश इत्येके 
    """
    return "कुश"


@registry.register("4.127", root="कुंस", meaning="इत्यन्ये", gana="Divadi")
def root_4_127():
    """
    4.127 कुंस इत्यन्ये 
    """
    return "कुंस"


@registry.register("4.128", root="कुंश", meaning="इत्यपरे", gana="Divadi")
def root_4_128():
    """
    4.128 कुंश इत्यपरे 
    """
    return "कुंश"


@registry.register("4.129", root="बुस", meaning="उत्सर्गे", gana="Divadi")
def root_4_129():
    """
    4.129 बुस उत्सर्गे 
    """
    return "बुस"


@registry.register("4.130", root="मुस", meaning="खण्डने", gana="Divadi")
def root_4_130():
    """
    4.130 मुस खण्डने 
    """
    return "मुस"


@registry.register("4.131", root="मसी", meaning="परिमाने", gana="Divadi")
def root_4_131():
    """
    4.131 मसी परिमाने 
    """
    return "मसी"


@registry.register("4.132", root="समी", meaning="इत्येके", gana="Divadi")
def root_4_132():
    """
    4.132 समी इत्येके 
    """
    return "समी"


@registry.register("4.133", root="लुट", meaning="विलोडने", gana="Divadi")
def root_4_133():
    """
    4.133 लुट विलोडने 
    """
    return "लुट"


@registry.register("4.134", root="लुठ", meaning="इत्येके", gana="Divadi")
def root_4_134():
    """
    4.134 लुठ इत्येके 
    """
    return "लुठ"


@registry.register("4.135", root="उच", meaning="समवाये", gana="Divadi")
def root_4_135():
    """
    4.135 उच समवाये 
    """
    return "उच"


@registry.register("4.138", root="भ्रंशु", meaning="अधःपतने", gana="Divadi")
def root_4_138():
    """
    4.138 भ्रंशु अधःपतने 
    """
    return "भ्रंशु"


@registry.register("4.139", root="वृश", meaning="वरणे", gana="Divadi")
def root_4_139():
    """
    4.139 वृश वरणे 
    """
    return "वृश"


@registry.register("4.140", root="कृश", meaning="तनूकरणे", gana="Divadi")
def root_4_140():
    """
    4.140 कृश तनूकरणे 
    """
    return "कृश"


@registry.register("4.141", root="ञितृष", meaning="ञितृषा पिपासायाम्", gana="Divadi")
def root_4_141():
    """
    4.141 ञितृष ञितृषा पिपासायाम् 
    """
    return "ञितृष"


@registry.register("4.142", root="हृष", meaning="तुष्टौ", gana="Divadi")
def root_4_142():
    """
    4.142 हृष तुष्टौ 
    """
    return "हृष"


@registry.register("4.143", root="रुष", meaning="रोषे", gana="Divadi")
def root_4_143():
    """
    4.143 रुष रोषे 
    """
    return "रुष"


@registry.register("4.144", root="रिष", meaning="हिंसायाम्", gana="Divadi")
def root_4_144():
    """
    4.144 रिष हिंसायाम् 
    """
    return "रिष"


@registry.register("4.145", root="डिप", meaning="क्षेपे", gana="Divadi")
def root_4_145():
    """
    4.145 डिप क्षेपे 
    """
    return "डिप"


@registry.register("4.146", root="कुप", meaning="क्रोधे", gana="Divadi")
def root_4_146():
    """
    4.146 कुप क्रोधे 
    """
    return "कुप"


@registry.register("4.147", root="गुप", meaning="व्याकुलत्वे", gana="Divadi")
def root_4_147():
    """
    4.147 गुप व्याकुलत्वे 
    """
    return "गुप"


@registry.register("4.150", root="लुप", meaning="विमोहने", gana="Divadi")
def root_4_150():
    """
    4.150 लुप विमोहने 
    """
    return "लुप"


@registry.register("4.151", root="ष्टुप", meaning="समुच्छ्राये", gana="Divadi")
def root_4_151():
    """
    4.151 ष्टुप समुच्छ्राये 
    """
    return "ष्टुप"


@registry.register("4.152", root="ष्टूप", meaning="इत्येके", gana="Divadi")
def root_4_152():
    """
    4.152 ष्टूप इत्येके 
    """
    return "ष्टूप"


@registry.register("4.153", root="लुभ", meaning="गार्द्ध्ये गार्ध्न्ये", gana="Divadi")
def root_4_153():
    """
    4.153 लुभ गार्द्ध्ये गार्ध्न्ये 
    """
    return "लुभ"


@registry.register("4.154", root="क्षुभ", meaning="सञ्चलने", gana="Divadi")
def root_4_154():
    """
    4.154 क्षुभ सञ्चलने 
    """
    return "क्षुभ"


@registry.register("4.156", root="तुभ", meaning="हिंसायाम्", gana="Divadi")
def root_4_156():
    """
    4.156 तुभ हिंसायाम् 
    """
    return "तुभ"


@registry.register("4.157", root="क्लिदू", meaning="आद्रीभावे", gana="Divadi")
def root_4_157():
    """
    4.157 क्लिदू आद्रीभावे 
    """
    return "क्लिदू"


@registry.register("4.158", root="ञिमिदा", meaning="स्नेहने", gana="Divadi")
def root_4_158():
    """
    4.158 ञिमिदा स्नेहने 
    """
    return "ञिमिदा"


@registry.register("4.159", root="ञिक्ष्विदा", meaning="स्नेहनमोचनयोः", gana="Divadi")
def root_4_159():
    """
    4.159 ञिक्ष्विदा स्नेहनमोचनयोः 
    """
    return "ञिक्ष्विदा"


@registry.register("4.160", root="ऋधु", meaning="वृद्धौ", gana="Divadi")
def root_4_160():
    """
    4.160 ऋधु वृद्धौ 
    """
    return "ऋधु"


@registry.register("4.161", root="गृधु", meaning="अभिकाङ्क्षायाम्", gana="Divadi")
def root_4_161():
    """
    4.161 गृधु अभिकाङ्क्षायाम् 
    """
    return "गृधु"
