# Auto-generated by scripts/scaffold_roots.py for Gana 3
from . import registry


@registry.register("3.1", root="हु", meaning="दानादनयोः", gana="Juhotyadi")
def root_3_1():
    """
    3.1 हु दानादनयोः 
    """
    return "हु"


@registry.register("3.2", root="ञिभी", meaning="भये", gana="Juhotyadi")
def root_3_2():
    """
    3.2 ञिभी भये 
    """
    return "ञिभी"


@registry.register("3.3", root="ह्री", meaning="लज्जायाम्", gana="Juhotyadi")
def root_3_3():
    """
    3.3 ह्री लज्जायाम् 
    """
    return "ह्री"


@registry.register("3.4", root="पृई", meaning="पालनपूरणयोः", gana="Juhotyadi")
def root_3_4():
    """
    3.4 पृई पालनपूरणयोः 
    """
    return "पृई"


@registry.register("3.5", root="पृ", meaning="इत्येके ह्रस्वान्तोऽयमित्येके", gana="Juhotyadi")
def root_3_5():
    """
    3.5 पृ इत्येके ह्रस्वान्तोऽयमित्येके 
    """
    return "पृ"


@registry.register("3.6", root="डुभृञ्", meaning="धारणपोषणयोः", gana="Juhotyadi")
def root_3_6():
    """
    3.6 डुभृञ् धारणपोषणयोः 
    """
    return "डुभृञ्"


@registry.register("3.7", root="माङ्", meaning="माने शब्दे च", gana="Juhotyadi")
def root_3_7():
    """
    3.7 माङ् माने शब्दे च 
    """
    return "माङ्"


@registry.register("3.8", root="ओहाङ्", meaning="गतौ", gana="Juhotyadi")
def root_3_8():
    """
    3.8 ओहाङ् गतौ 
    """
    return "ओहाङ्"


@registry.register("3.9", root="ओहाक्", meaning="त्यागे", gana="Juhotyadi")
def root_3_9():
    """
    3.9 ओहाक् त्यागे 
    """
    return "ओहाक्"


@registry.register("3.10", root="डुदाञ्", meaning="दाने", gana="Juhotyadi")
def root_3_10():
    """
    3.10 डुदाञ् दाने 
    """
    return "डुदाञ्"


@registry.register("3.11", root="डुधाञ्", meaning="धारणपोषणयोः", gana="Juhotyadi")
def root_3_11():
    """
    3.11 डुधाञ् धारणपोषणयोः 
    """
    return "डुधाञ्"


@registry.register("3.12", root="णिजिर्", meaning="शौचपोषणयोः", gana="Juhotyadi")
def root_3_12():
    """
    3.12 णिजिर् शौचपोषणयोः 
    """
    return "णिजिर्"


@registry.register("3.13", root="विजिर्", meaning="पृथग्भावे", gana="Juhotyadi")
def root_3_13():
    """
    3.13 विजिर् पृथग्भावे 
    """
    return "विजिर्"


@registry.register("3.14", root="विषॢ", meaning="व्याप्तौ", gana="Juhotyadi")
def root_3_14():
    """
    3.14 विषॢ व्याप्तौ 
    """
    return "विषॢ"


@registry.register("3.15", root="घृ", meaning="क्षरणदीप्त्योः", gana="Juhotyadi")
def root_3_15():
    """
    3.15 घृ क्षरणदीप्त्योः 
    """
    return "घृ"


@registry.register("3.16", root="हृ", meaning="प्रसह्यकरणे", gana="Juhotyadi")
def root_3_16():
    """
    3.16 हृ प्रसह्यकरणे 
    """
    return "हृ"


@registry.register("3.18", root="सृ", meaning="गतौ", gana="Juhotyadi")
def root_3_18():
    """
    3.18 सृ गतौ 
    """
    return "सृ"


@registry.register("3.19", root="भस", meaning="भर्त्सनदीप्त्योः", gana="Juhotyadi")
def root_3_19():
    """
    3.19 भस भर्त्सनदीप्त्योः 
    """
    return "भस"


@registry.register("3.20", root="कि", meaning="ज्ञाने", gana="Juhotyadi")
def root_3_20():
    """
    3.20 कि ज्ञाने 
    """
    return "कि"


@registry.register("3.21", root="कित", meaning="च", gana="Juhotyadi")
def root_3_21():
    """
    3.21 कित च
    """
    return "कित"


@registry.register("3.22", root="तुर", meaning="त्वरणे", gana="Juhotyadi")
def root_3_22():
    """
    3.22 तुर त्वरणे 
    """
    return "तुर"


@registry.register("3.23", root="धिष", meaning="शब्दे", gana="Juhotyadi")
def root_3_23():
    """
    3.23 धिष शब्दे 
    """
    return "धिष"


@registry.register("3.24", root="धन", meaning="धान्ये", gana="Juhotyadi")
def root_3_24():
    """
    3.24 धन धान्ये 
    """
    return "धन"


@registry.register("3.25", root="जन", meaning="जनने", gana="Juhotyadi")
def root_3_25():
    """
    3.25 जन जनने 
    """
    return "जन"


@registry.register("3.26", root="गा", meaning="स्तुतौ", gana="Juhotyadi")
def root_3_26():
    """
    3.26 गा स्तुतौ 
    """
    return "गा"
