# Auto-generated by scripts/scaffold_roots.py for Gana 5
from . import registry


@registry.register("5.1", root="षुञ्", meaning="अभिषवे", gana="Svadi")
def root_5_1():
    """
    5.1 षुञ् अभिषवे 
    """
    return "षुञ्"


@registry.register("5.2", root="षिञ्", meaning="बन्धने", gana="Svadi")
def root_5_2():
    """
    5.2 षिञ् बन्धने 
    """
    return "षिञ्"


@registry.register("5.3", root="शिञ्", meaning="निशाने", gana="Svadi")
def root_5_3():
    """
    5.3 शिञ् निशाने 
    """
    return "शिञ्"


@registry.register("5.4", root="डुमिञ्", meaning="प्रक्षेपने", gana="Svadi")
def root_5_4():
    """
    5.4 डुमिञ् प्रक्षेपने 
    """
    return "डुमिञ्"


@registry.register("5.5", root="चिञ्", meaning="चयने", gana="Svadi")
def root_5_5():
    """
    5.5 चिञ् चयने 
    """
    return "चिञ्"


@registry.register("5.6", root="स्तृञ्", meaning="आच्छादने", gana="Svadi")
def root_5_6():
    """
    5.6 स्तृञ् आच्छादने 
    """
    return "स्तृञ्"


@registry.register("5.7", root="कृञ्", meaning="हिंसायाम्", gana="Svadi")
def root_5_7():
    """
    5.7 कृञ् हिंसायाम् 
    """
    return "कृञ्"


@registry.register("5.8", root="वृञ्", meaning="वरणे", gana="Svadi")
def root_5_8():
    """
    5.8 वृञ् वरणे 
    """
    return "वृञ्"


@registry.register("5.9", root="धुञ्", meaning="कम्पने", gana="Svadi")
def root_5_9():
    """
    5.9 धुञ् कम्पने 
    """
    return "धुञ्"


@registry.register("5.10", root="धूञ्", meaning="इत्येके दीर्घन्तोऽपीत्येके", gana="Svadi")
def root_5_10():
    """
    5.10 धूञ् इत्येके दीर्घन्तोऽपीत्येके 
    """
    return "धूञ्"


@registry.register("5.11", root="टुदु", meaning="उपतापे", gana="Svadi")
def root_5_11():
    """
    5.11 टुदु उपतापे 
    """
    return "टुदु"


@registry.register("5.12", root="हि", meaning="गतौ वृद्धौ च", gana="Svadi")
def root_5_12():
    """
    5.12 हि गतौ वृद्धौ च 
    """
    return "हि"


@registry.register("5.13", root="पृ", meaning="प्रीतौ", gana="Svadi")
def root_5_13():
    """
    5.13 पृ प्रीतौ 
    """
    return "पृ"


@registry.register("5.14", root="स्पृ", meaning="प्रीतिपालनयोः", gana="Svadi")
def root_5_14():
    """
    5.14 स्पृ प्रीतिपालनयोः 
    """
    return "स्पृ"


@registry.register("5.15", root="स्मृ", meaning="इत्येके", gana="Svadi")
def root_5_15():
    """
    5.15 स्मृ इत्येके 
    """
    return "स्मृ"


@registry.register("5.16", root="आपॢ", meaning="व्याप्तौ", gana="Svadi")
def root_5_16():
    """
    5.16 आपॢ व्याप्तौ 
    """
    return "आपॢ"


@registry.register("5.17", root="शकॢ", meaning="शक्तौ", gana="Svadi")
def root_5_17():
    """
    5.17 शकॢ शक्तौ 
    """
    return "शकॢ"


@registry.register("5.19", root="साध", meaning="संसिद्धौ", gana="Svadi")
def root_5_19():
    """
    5.19 साध संसिद्धौ 
    """
    return "साध"


@registry.register("5.20", root="अशू", meaning="व्याप्तौ सङ्घाते च", gana="Svadi")
def root_5_20():
    """
    5.20 अशू व्याप्तौ सङ्घाते च 
    """
    return "अशू"


@registry.register("5.21", root="ष्टिघ", meaning="आस्कन्दने", gana="Svadi")
def root_5_21():
    """
    5.21 ष्टिघ आस्कन्दने 
    """
    return "ष्टिघ"


@registry.register("5.23", root="तिग", meaning="गतौ च", gana="Svadi")
def root_5_23():
    """
    5.23 तिग गतौ च 
    """
    return "तिग"


@registry.register("5.24", root="षघ", meaning="हिंसायाम्", gana="Svadi")
def root_5_24():
    """
    5.24 षघ हिंसायाम् 
    """
    return "षघ"


@registry.register("5.25", root="ञिधृषा", meaning="प्रागल्भ्ये", gana="Svadi")
def root_5_25():
    """
    5.25 ञिधृषा प्रागल्भ्ये 
    """
    return "ञिधृषा"


@registry.register("5.26", root="दम्भु", meaning="दम्भने दम्भे", gana="Svadi")
def root_5_26():
    """
    5.26 दम्भु दम्भने दम्भे 
    """
    return "दम्भु"


@registry.register("5.27", root="ऋधु", meaning="वृद्धौ", gana="Svadi")
def root_5_27():
    """
    5.27 ऋधु वृद्धौ 
    """
    return "ऋधु"


@registry.register("5.28", root="तृप", meaning="प्रीणन इत्येके", gana="Svadi")
def root_5_28():
    """
    5.28 तृप प्रीणन इत्येके 
    """
    return "तृप"


@registry.register("5.29", root="अह", meaning="व्याप्तौ", gana="Svadi")
def root_5_29():
    """
    5.29 अह व्याप्तौ 
    """
    return "अह"


@registry.register("5.30", root="दघ", meaning="घातने पालने च", gana="Svadi")
def root_5_30():
    """
    5.30 दघ घातने पालने च 
    """
    return "दघ"


@registry.register("5.31", root="चमु", meaning="भक्षणे", gana="Svadi")
def root_5_31():
    """
    5.31 चमु भक्षणे 
    """
    return "चमु"


@registry.register("5.32", root="रिऽ", meaning="ऋऽ", gana="Svadi")
def root_5_32():
    """
    5.32 रिऽ ऋऽ
    """
    return "रिऽ"


@registry.register("5.33", root="क्षिऽ", meaning="क्षीऽ", gana="Svadi")
def root_5_33():
    """
    5.33 क्षिऽ क्षीऽ
    """
    return "क्षिऽ"


@registry.register("5.37", root="दृई", meaning="हिंसायाम्", gana="Svadi")
def root_5_37():
    """
    5.37 दृई हिंसायाम् 
    """
    return "दृई"


@registry.register("5.39", root="क्षी", meaning="इत्येक एवाजादिरित्येके", gana="Svadi")
def root_5_39():
    """
    5.39 क्षी इत्येक एवाजादिरित्येके 
    """
    return "क्षी"
