# Auto-generated by scripts/scaffold_rules.py
from . import registry


@registry.register("5.1.1", text="प्राक् क्रीताच्छः ।")
def rule_5_1_1(ctx=None):
    """
    5.1.1: प्राक् क्रीताच्छः ।
    """
    pass


@registry.register("5.1.2", text="उगवादिभ्योऽत् ।")
def rule_5_1_2(ctx=None):
    """
    5.1.2: उगवादिभ्योऽत् ।
    """
    pass


@registry.register("5.1.3", text="कम्बलाच्च संज्ञायाम् ।")
def rule_5_1_3(ctx=None):
    """
    5.1.3: कम्बलाच्च संज्ञायाम् ।
    """
    pass


@registry.register("5.1.4", text="विभाषा हविरपूपादिभ्यः ।")
def rule_5_1_4(ctx=None):
    """
    5.1.4: विभाषा हविरपूपादिभ्यः ।
    """
    pass


@registry.register("5.1.5", text="तस्मै हितम् ।")
def rule_5_1_5(ctx=None):
    """
    5.1.5: तस्मै हितम् ।
    """
    pass


@registry.register("5.1.6", text="शरीरावयवाद्यत् ।")
def rule_5_1_6(ctx=None):
    """
    5.1.6: शरीरावयवाद्यत् ।
    """
    pass


@registry.register("5.1.7", text="खलयवमाषतिलवृषब्रह्मणश्च ।")
def rule_5_1_7(ctx=None):
    """
    5.1.7: खलयवमाषतिलवृषब्रह्मणश्च ।
    """
    pass


@registry.register("5.1.8", text="अजाविभ्यां थ्यन् ।")
def rule_5_1_8(ctx=None):
    """
    5.1.8: अजाविभ्यां थ्यन् ।
    """
    pass


@registry.register("5.1.9", text="आत्मन्विश्वजनभोगोत्तरपदात् खः ।")
def rule_5_1_9(ctx=None):
    """
    5.1.9: आत्मन्विश्वजनभोगोत्तरपदात् खः ।
    """
    pass


@registry.register("5.1.10", text="सर्वपुरुषाभ्यां णढञौ ।")
def rule_5_1_10(ctx=None):
    """
    5.1.10: सर्वपुरुषाभ्यां णढञौ ।
    """
    pass


@registry.register("5.1.11", text="माणवचरकाभ्यां खञ् ।")
def rule_5_1_11(ctx=None):
    """
    5.1.11: माणवचरकाभ्यां खञ् ।
    """
    pass


@registry.register("5.1.12", text="तदर्थं विकृतेः प्रकृतौ ।")
def rule_5_1_12(ctx=None):
    """
    5.1.12: तदर्थं विकृतेः प्रकृतौ ।
    """
    pass


@registry.register("5.1.13", text="छदिरुपधिबलेः ढञ् ।")
def rule_5_1_13(ctx=None):
    """
    5.1.13: छदिरुपधिबलेः ढञ् ।
    """
    pass


@registry.register("5.1.14", text="ऋषभोपानहोर्य्यः ।")
def rule_5_1_14(ctx=None):
    """
    5.1.14: ऋषभोपानहोर्य्यः ।
    """
    pass


@registry.register("5.1.15", text="चर्मणोऽञ् ।")
def rule_5_1_15(ctx=None):
    """
    5.1.15: चर्मणोऽञ् ।
    """
    pass


@registry.register("5.1.16", text="तदस्य तदस्मिन् स्यादिति ।")
def rule_5_1_16(ctx=None):
    """
    5.1.16: तदस्य तदस्मिन् स्यादिति ।
    """
    pass


@registry.register("5.1.17", text="परिखाया ढञ् ।")
def rule_5_1_17(ctx=None):
    """
    5.1.17: परिखाया ढञ् ।
    """
    pass


@registry.register("5.1.18", text="प्राग्वतेष्ठञ् ।")
def rule_5_1_18(ctx=None):
    """
    5.1.18: प्राग्वतेष्ठञ् ।
    """
    pass


@registry.register("5.1.19", text="आर्हादगोपुच्छसंख्यापरिमाणाट्ठक् ।")
def rule_5_1_19(ctx=None):
    """
    5.1.19: आर्हादगोपुच्छसंख्यापरिमाणाट्ठक् ।
    """
    pass


@registry.register("5.1.20", text="असमासे निष्कादिभ्यः ।")
def rule_5_1_20(ctx=None):
    """
    5.1.20: असमासे निष्कादिभ्यः ।
    """
    pass


@registry.register("5.1.21", text="शताच्च ठन्यतावशते ।")
def rule_5_1_21(ctx=None):
    """
    5.1.21: शताच्च ठन्यतावशते ।
    """
    pass


@registry.register("5.1.22", text="संख्याया अतिशदन्तायाः कन् ।")
def rule_5_1_22(ctx=None):
    """
    5.1.22: संख्याया अतिशदन्तायाः कन् ।
    """
    pass


@registry.register("5.1.23", text="वतोरिड्डा ।")
def rule_5_1_23(ctx=None):
    """
    5.1.23: वतोरिड्डा ।
    """
    pass


@registry.register("5.1.24", text="विंशतित्रिंशच्यां गुन्नसंज्ञायाम् ।")
def rule_5_1_24(ctx=None):
    """
    5.1.24: विंशतित्रिंशच्यां गुन्नसंज्ञायाम् ।
    """
    pass


@registry.register("5.1.25", text="कंसाट्टिठन् ।")
def rule_5_1_25(ctx=None):
    """
    5.1.25: कंसाट्टिठन् ।
    """
    pass


@registry.register("5.1.26", text="शूर्पादञन्यतरस्याम् ।")
def rule_5_1_26(ctx=None):
    """
    5.1.26: शूर्पादञन्यतरस्याम् ।
    """
    pass


@registry.register("5.1.27", text="शतमानविंशतिकसहस्रवसनादण् ।")
def rule_5_1_27(ctx=None):
    """
    5.1.27: शतमानविंशतिकसहस्रवसनादण् ।
    """
    pass


@registry.register("5.1.28", text="अध्यर्धपूर्वद्विगोर्तुगसंज्ञायाम् ।")
def rule_5_1_28(ctx=None):
    """
    5.1.28: अध्यर्धपूर्वद्विगोर्तुगसंज्ञायाम् ।
    """
    pass


@registry.register("5.1.29", text="विभाषा कार्षापणसहस्राभ्याम् ।")
def rule_5_1_29(ctx=None):
    """
    5.1.29: विभाषा कार्षापणसहस्राभ्याम् ।
    """
    pass


@registry.register("5.1.30", text="द्वित्रिपूर्वान्निष्कात् ।")
def rule_5_1_30(ctx=None):
    """
    5.1.30: द्वित्रिपूर्वान्निष्कात् ।
    """
    pass


@registry.register("5.1.31", text="बिस्ताच्च ।")
def rule_5_1_31(ctx=None):
    """
    5.1.31: बिस्ताच्च ।
    """
    pass


@registry.register("5.1.32", text="विंशतिकात् खः ।")
def rule_5_1_32(ctx=None):
    """
    5.1.32: विंशतिकात् खः ।
    """
    pass


@registry.register("5.1.33", text="खार्या ईकन् ।")
def rule_5_1_33(ctx=None):
    """
    5.1.33: खार्या ईकन् ।
    """
    pass


@registry.register("5.1.34", text="पणपादमाषशतादत् ।")
def rule_5_1_34(ctx=None):
    """
    5.1.34: पणपादमाषशतादत् ।
    """
    pass


@registry.register("5.1.35", text="शाणाद्वा ।")
def rule_5_1_35(ctx=None):
    """
    5.1.35: शाणाद्वा ।
    """
    pass


@registry.register("5.1.36", text="द्वित्रिपूर्वादण् च ।")
def rule_5_1_36(ctx=None):
    """
    5.1.36: द्वित्रिपूर्वादण् च ।
    """
    pass


@registry.register("5.1.37", text="तेन क्रीतम् ।")
def rule_5_1_37(ctx=None):
    """
    5.1.37: तेन क्रीतम् ।
    """
    pass


@registry.register("5.1.38", text="तस्य निमित्तं संयोगोत्पातौ ।")
def rule_5_1_38(ctx=None):
    """
    5.1.38: तस्य निमित्तं संयोगोत्पातौ ।
    """
    pass


@registry.register("5.1.39", text="गोद्व्यचोरसंख्यापरिमाणाश्वादेर्यत् ।")
def rule_5_1_39(ctx=None):
    """
    5.1.39: गोद्व्यचोरसंख्यापरिमाणाश्वादेर्यत् ।
    """
    pass


@registry.register("5.1.40", text="पुत्राच्छ च ।")
def rule_5_1_40(ctx=None):
    """
    5.1.40: पुत्राच्छ च ।
    """
    pass


@registry.register("5.1.41", text="सर्वभूमिपृथिवीभ्यामणौ ।")
def rule_5_1_41(ctx=None):
    """
    5.1.41: सर्वभूमिपृथिवीभ्यामणौ ।
    """
    pass


@registry.register("5.1.42", text="तस्येश्वरः ।")
def rule_5_1_42(ctx=None):
    """
    5.1.42: तस्येश्वरः ।
    """
    pass


@registry.register("5.1.43", text="तत्र विदित इति च ।")
def rule_5_1_43(ctx=None):
    """
    5.1.43: तत्र विदित इति च ।
    """
    pass


@registry.register("5.1.44", text="लोकसर्वलोकाट्ठञ् ।")
def rule_5_1_44(ctx=None):
    """
    5.1.44: लोकसर्वलोकाट्ठञ् ।
    """
    pass


@registry.register("5.1.45", text="तस्य वापः ।")
def rule_5_1_45(ctx=None):
    """
    5.1.45: तस्य वापः ।
    """
    pass


@registry.register("5.1.46", text="पात्रात् ष्ठन् ।")
def rule_5_1_46(ctx=None):
    """
    5.1.46: पात्रात् ष्ठन् ।
    """
    pass


@registry.register("5.1.47", text="तदस्मिन् वृद्ध्यायलाभशुल्कोपदा दीयते ।")
def rule_5_1_47(ctx=None):
    """
    5.1.47: तदस्मिन् वृद्ध्यायलाभशुल्कोपदा दीयते ।
    """
    pass


@registry.register("5.1.48", text="पूरणार्धाट्ठन् ।")
def rule_5_1_48(ctx=None):
    """
    5.1.48: पूरणार्धाट्ठन् ।
    """
    pass


@registry.register("5.1.49", text="भागाद्यच्च ।")
def rule_5_1_49(ctx=None):
    """
    5.1.49: भागाद्यच्च ।
    """
    pass


@registry.register("5.1.49", text="तद्धरति वहत्यावहति भाराद्वंशादिभ्यः ।")
def rule_5_1_49(ctx=None):
    """
    5.1.49: तद्धरति वहत्यावहति भाराद्वंशादिभ्यः ।
    """
    pass


@registry.register("5.1.51", text="वस्नद्रव्याभ्यां ठन्कनौ ।")
def rule_5_1_51(ctx=None):
    """
    5.1.51: वस्नद्रव्याभ्यां ठन्कनौ ।
    """
    pass


@registry.register("5.1.52", text="सम्भवत्यवहरति पचति ।")
def rule_5_1_52(ctx=None):
    """
    5.1.52: सम्भवत्यवहरति पचति ।
    """
    pass


@registry.register("5.1.53", text="आढकाचितपात्रात् खोऽन्यतरयाम् ।")
def rule_5_1_53(ctx=None):
    """
    5.1.53: आढकाचितपात्रात् खोऽन्यतरयाम् ।
    """
    pass


@registry.register("5.1.54", text="द्विगोष्ठंश्च ।")
def rule_5_1_54(ctx=None):
    """
    5.1.54: द्विगोष्ठंश्च ।
    """
    pass


@registry.register("5.1.55", text="कुलिजाल्लुक्खौ च ।")
def rule_5_1_55(ctx=None):
    """
    5.1.55: कुलिजाल्लुक्खौ च ।
    """
    pass


@registry.register("5.1.56", text="सोऽस्यांशवस्त्रभृतयः ।")
def rule_5_1_56(ctx=None):
    """
    5.1.56: सोऽस्यांशवस्त्रभृतयः ।
    """
    pass


@registry.register("5.1.57", text="तदस्य परिमाणम् ।")
def rule_5_1_57(ctx=None):
    """
    5.1.57: तदस्य परिमाणम् ।
    """
    pass


@registry.register("5.1.58", text="संख्यायाः संज्ञासंघसूत्राध्ययनेषु ।")
def rule_5_1_58(ctx=None):
    """
    5.1.58: संख्यायाः संज्ञासंघसूत्राध्ययनेषु ।
    """
    pass


@registry.register("5.1.59", text="पङ्किविंशतित्रिंशत्वत्वारिंशत्पञ्चाशत्षष्टिसप्तत्यशीतिनवतिशतम् ।")
def rule_5_1_59(ctx=None):
    """
    5.1.59: पङ्किविंशतित्रिंशत्वत्वारिंशत्पञ्चाशत्षष्टिसप्तत्यशीतिनवतिशतम् ।
    """
    pass


@registry.register("5.1.60", text="पञ्चद्दशतौ वर्गे वा ।")
def rule_5_1_60(ctx=None):
    """
    5.1.60: पञ्चद्दशतौ वर्गे वा ।
    """
    pass


@registry.register("5.1.61", text="सप्तनोऽञ् छन्दसि ।")
def rule_5_1_61(ctx=None):
    """
    5.1.61: सप्तनोऽञ् छन्दसि ।
    """
    pass


@registry.register("5.1.62", text="त्रिंशच्चत्वारिंशतोर्ब्रह्मणे संज्ञायां डण् ।")
def rule_5_1_62(ctx=None):
    """
    5.1.62: त्रिंशच्चत्वारिंशतोर्ब्रह्मणे संज्ञायां डण् ।
    """
    pass


@registry.register("5.1.63", text="तद् अर्हति ।")
def rule_5_1_63(ctx=None):
    """
    5.1.63: तद् अर्हति ।
    """
    pass


@registry.register("5.1.64", text="छेदादिभ्यो नित्यम् ।")
def rule_5_1_64(ctx=None):
    """
    5.1.64: छेदादिभ्यो नित्यम् ।
    """
    pass


@registry.register("5.1.65", text="शीर्षच्छेदाद्यच्च ।")
def rule_5_1_65(ctx=None):
    """
    5.1.65: शीर्षच्छेदाद्यच्च ।
    """
    pass


@registry.register("5.1.66", text="दण्डादिभ्यः ।")
def rule_5_1_66(ctx=None):
    """
    5.1.66: दण्डादिभ्यः ।
    """
    pass


@registry.register("5.1.67", text="छन्दसि च ।")
def rule_5_1_67(ctx=None):
    """
    5.1.67: छन्दसि च ।
    """
    pass


@registry.register("5.1.68", text="पात्राद्वंश्च ।")
def rule_5_1_68(ctx=None):
    """
    5.1.68: पात्राद्वंश्च ।
    """
    pass


@registry.register("5.1.69", text="कडङ्गरदक्षिणाच्छ च ।")
def rule_5_1_69(ctx=None):
    """
    5.1.69: कडङ्गरदक्षिणाच्छ च ।
    """
    pass


@registry.register("5.1.70", text="स्थालीबिलात् ।")
def rule_5_1_70(ctx=None):
    """
    5.1.70: स्थालीबिलात् ।
    """
    pass


@registry.register("5.1.71", text="यज्ञर्विग्भ्यां घखौ ।")
def rule_5_1_71(ctx=None):
    """
    5.1.71: यज्ञर्विग्भ्यां घखौ ।
    """
    pass


@registry.register("5.1.72", text="पारायणतुरायणचान्द्रायणं वर्तयति ।")
def rule_5_1_72(ctx=None):
    """
    5.1.72: पारायणतुरायणचान्द्रायणं वर्तयति ।
    """
    pass


@registry.register("5.1.73", text="संशयमापन्नः ।")
def rule_5_1_73(ctx=None):
    """
    5.1.73: संशयमापन्नः ।
    """
    pass


@registry.register("5.1.74", text="योजनं गच्छति ।")
def rule_5_1_74(ctx=None):
    """
    5.1.74: योजनं गच्छति ।
    """
    pass


@registry.register("5.1.75", text="पथः ष्कन् ।")
def rule_5_1_75(ctx=None):
    """
    5.1.75: पथः ष्कन् ।
    """
    pass


@registry.register("5.1.76", text="पन्थो ण नित्यम् ।")
def rule_5_1_76(ctx=None):
    """
    5.1.76: पन्थो ण नित्यम् ।
    """
    pass


@registry.register("5.1.77", text="उत्तरपथेनाहृतं च ।")
def rule_5_1_77(ctx=None):
    """
    5.1.77: उत्तरपथेनाहृतं च ।
    """
    pass


@registry.register("5.1.78", text="कालात् ।")
def rule_5_1_78(ctx=None):
    """
    5.1.78: कालात् ।
    """
    pass


@registry.register("5.1.79", text="तेन निर्वृत्तम् ।")
def rule_5_1_79(ctx=None):
    """
    5.1.79: तेन निर्वृत्तम् ।
    """
    pass


@registry.register("5.1.80", text="तमधीष्टो भृतो भूतो भावी ।")
def rule_5_1_80(ctx=None):
    """
    5.1.80: तमधीष्टो भृतो भूतो भावी ।
    """
    pass


@registry.register("5.1.81", text="मासाद्वयसि यत्खौ ।")
def rule_5_1_81(ctx=None):
    """
    5.1.81: मासाद्वयसि यत्खौ ।
    """
    pass


@registry.register("5.1.82", text="द्विगोर्यप् ।")
def rule_5_1_82(ctx=None):
    """
    5.1.82: द्विगोर्यप् ।
    """
    pass


@registry.register("5.1.83", text="षण्मासाण्ण्यच्च ।")
def rule_5_1_83(ctx=None):
    """
    5.1.83: षण्मासाण्ण्यच्च ।
    """
    pass


@registry.register("5.1.84", text="अवयसि ठंश्च ।")
def rule_5_1_84(ctx=None):
    """
    5.1.84: अवयसि ठंश्च ।
    """
    pass


@registry.register("5.1.85", text="समायाः खः ।")
def rule_5_1_85(ctx=None):
    """
    5.1.85: समायाः खः ।
    """
    pass


@registry.register("5.1.86", text="द्विगोर्वा ।")
def rule_5_1_86(ctx=None):
    """
    5.1.86: द्विगोर्वा ।
    """
    pass


@registry.register("5.1.87", text="रात्र्यहस्संवत्सराच्च ।")
def rule_5_1_87(ctx=None):
    """
    5.1.87: रात्र्यहस्संवत्सराच्च ।
    """
    pass


@registry.register("5.1.88", text="वर्षाल्लुक् च ।")
def rule_5_1_88(ctx=None):
    """
    5.1.88: वर्षाल्लुक् च ।
    """
    pass


@registry.register("5.1.89", text="चित्तवति नित्यम् ।")
def rule_5_1_89(ctx=None):
    """
    5.1.89: चित्तवति नित्यम् ।
    """
    pass


@registry.register("5.1.90", text="षष्टिकाः षष्टिरात्रेण पच्यन्ते ।")
def rule_5_1_90(ctx=None):
    """
    5.1.90: षष्टिकाः षष्टिरात्रेण पच्यन्ते ।
    """
    pass


@registry.register("5.1.91", text="वत्सरान्ताच्छश्छन्दसि ।")
def rule_5_1_91(ctx=None):
    """
    5.1.91: वत्सरान्ताच्छश्छन्दसि ।
    """
    pass


@registry.register("5.1.92", text="सम्परिपूर्वात् ख च ।")
def rule_5_1_92(ctx=None):
    """
    5.1.92: सम्परिपूर्वात् ख च ।
    """
    pass


@registry.register("5.1.93", text="तेन परिजय्यलभ्यकार्यसुकरम् ।")
def rule_5_1_93(ctx=None):
    """
    5.1.93: तेन परिजय्यलभ्यकार्यसुकरम् ।
    """
    pass


@registry.register("5.1.94", text="तदस्य ब्रह्मचर्यम् ।")
def rule_5_1_94(ctx=None):
    """
    5.1.94: तदस्य ब्रह्मचर्यम् ।
    """
    pass


@registry.register("5.1.95", text="तस्य च दक्षिणा यज्ञाख्येभ्यः ।")
def rule_5_1_95(ctx=None):
    """
    5.1.95: तस्य च दक्षिणा यज्ञाख्येभ्यः ।
    """
    pass


@registry.register("5.1.96", text="तत्र च दीयते कार्यं भववत् ।")
def rule_5_1_96(ctx=None):
    """
    5.1.96: तत्र च दीयते कार्यं भववत् ।
    """
    pass


@registry.register("5.1.97", text="व्युष्टादिभ्योऽण् ।")
def rule_5_1_97(ctx=None):
    """
    5.1.97: व्युष्टादिभ्योऽण् ।
    """
    pass


@registry.register("5.1.98", text="तेन यथाकथाचहस्ताभ्यां णयतौ ।")
def rule_5_1_98(ctx=None):
    """
    5.1.98: तेन यथाकथाचहस्ताभ्यां णयतौ ।
    """
    pass


@registry.register("5.1.99", text="सम्पादिनि ।")
def rule_5_1_99(ctx=None):
    """
    5.1.99: सम्पादिनि ।
    """
    pass


@registry.register("5.1.100", text="कर्मवेषाद्यत् ।")
def rule_5_1_100(ctx=None):
    """
    5.1.100: कर्मवेषाद्यत् ।
    """
    pass


@registry.register("5.1.101", text="तस्मै प्रभवति संतापादिभ्यः ।")
def rule_5_1_101(ctx=None):
    """
    5.1.101: तस्मै प्रभवति संतापादिभ्यः ।
    """
    pass


@registry.register("5.1.102", text="योगाद्यच्च ।")
def rule_5_1_102(ctx=None):
    """
    5.1.102: योगाद्यच्च ।
    """
    pass


@registry.register("5.1.103", text="कर्मण उकञ् ।")
def rule_5_1_103(ctx=None):
    """
    5.1.103: कर्मण उकञ् ।
    """
    pass


@registry.register("5.1.104", text="समयस्तदस्य प्राप्तम् ।")
def rule_5_1_104(ctx=None):
    """
    5.1.104: समयस्तदस्य प्राप्तम् ।
    """
    pass


@registry.register("5.1.105", text="ऋतोरण् ।")
def rule_5_1_105(ctx=None):
    """
    5.1.105: ऋतोरण् ।
    """
    pass


@registry.register("5.1.106", text="छन्दसि घस् ।")
def rule_5_1_106(ctx=None):
    """
    5.1.106: छन्दसि घस् ।
    """
    pass


@registry.register("5.1.107", text="कालाद्यत् ।")
def rule_5_1_107(ctx=None):
    """
    5.1.107: कालाद्यत् ।
    """
    pass


@registry.register("5.1.108", text="प्रकृष्टे ठञ् ।")
def rule_5_1_108(ctx=None):
    """
    5.1.108: प्रकृष्टे ठञ् ।
    """
    pass


@registry.register("5.1.109", text="प्रयोजनम् ।")
def rule_5_1_109(ctx=None):
    """
    5.1.109: प्रयोजनम् ।
    """
    pass


@registry.register("5.1.110", text="विशाखाऽऽषाढादण् मन्थदण्डयोः ।")
def rule_5_1_110(ctx=None):
    """
    5.1.110: विशाखाऽऽषाढादण् मन्थदण्डयोः ।
    """
    pass


@registry.register("5.1.111", text="अनुप्रवचनादिभ्यश्छः ।")
def rule_5_1_111(ctx=None):
    """
    5.1.111: अनुप्रवचनादिभ्यश्छः ।
    """
    pass


@registry.register("5.1.112", text="समापनात् सपूर्वपदात् ।")
def rule_5_1_112(ctx=None):
    """
    5.1.112: समापनात् सपूर्वपदात् ।
    """
    pass


@registry.register("5.1.113", text="ऐकागारिकट् चौरे ।")
def rule_5_1_113(ctx=None):
    """
    5.1.113: ऐकागारिकट् चौरे ।
    """
    pass


@registry.register("5.1.114", text="आकालिकडाद्यन्तवचने ।")
def rule_5_1_114(ctx=None):
    """
    5.1.114: आकालिकडाद्यन्तवचने ।
    """
    pass


@registry.register("5.1.115", text="तेन तुल्यं क्रिया चेद्वतिः ।")
def rule_5_1_115(ctx=None):
    """
    5.1.115: तेन तुल्यं क्रिया चेद्वतिः ।
    """
    pass


@registry.register("5.1.116", text="तत्र तस्येव ।")
def rule_5_1_116(ctx=None):
    """
    5.1.116: तत्र तस्येव ।
    """
    pass


@registry.register("5.1.117", text="तदर्हम् ।")
def rule_5_1_117(ctx=None):
    """
    5.1.117: तदर्हम् ।
    """
    pass


@registry.register("5.1.118", text="उपसर्गाच्छन्दसि धात्वर्थे ।")
def rule_5_1_118(ctx=None):
    """
    5.1.118: उपसर्गाच्छन्दसि धात्वर्थे ।
    """
    pass


@registry.register("5.1.119", text="तस्य भावस्त्वतलौ ।")
def rule_5_1_119(ctx=None):
    """
    5.1.119: तस्य भावस्त्वतलौ ।
    """
    pass


@registry.register("5.1.120", text="आ च त्वात् ।")
def rule_5_1_120(ctx=None):
    """
    5.1.120: आ च त्वात् ।
    """
    pass


@registry.register("5.1.121", text="न नपूर्वात्तत्पुरुषादचतुरसंगतलवणवटयुधकतरसलसेभ्यः ।")
def rule_5_1_121(ctx=None):
    """
    5.1.121: न नपूर्वात्तत्पुरुषादचतुरसंगतलवणवटयुधकतरसलसेभ्यः ।
    """
    pass


@registry.register("5.1.122", text="पृथ्वादिभ्य इमनिज्वा ।")
def rule_5_1_122(ctx=None):
    """
    5.1.122: पृथ्वादिभ्य इमनिज्वा ।
    """
    pass


@registry.register("5.1.123", text="वर्णदृढादिभ्यः ष्यञ् च ।")
def rule_5_1_123(ctx=None):
    """
    5.1.123: वर्णदृढादिभ्यः ष्यञ् च ।
    """
    pass


@registry.register("5.1.124", text="गुणवचनब्राह्मणादिभ्यः कर्मणि च ।")
def rule_5_1_124(ctx=None):
    """
    5.1.124: गुणवचनब्राह्मणादिभ्यः कर्मणि च ।
    """
    pass


@registry.register("5.1.125", text="स्तेनाद्यन्नलोपश्च ।")
def rule_5_1_125(ctx=None):
    """
    5.1.125: स्तेनाद्यन्नलोपश्च ।
    """
    pass


@registry.register("5.1.126", text="सख्युर्यः ।")
def rule_5_1_126(ctx=None):
    """
    5.1.126: सख्युर्यः ।
    """
    pass


@registry.register("5.1.127", text="कपिज्ञात्योर्दक् ।")
def rule_5_1_127(ctx=None):
    """
    5.1.127: कपिज्ञात्योर्दक् ।
    """
    pass


@registry.register("5.1.128", text="पत्यन्तपुरोहितादिभ्यो यक् ।")
def rule_5_1_128(ctx=None):
    """
    5.1.128: पत्यन्तपुरोहितादिभ्यो यक् ।
    """
    pass


@registry.register("5.1.129", text="प्राणभृज्जातिवयोवचनोद्गात्रादिभ्योऽञ् ।")
def rule_5_1_129(ctx=None):
    """
    5.1.129: प्राणभृज्जातिवयोवचनोद्गात्रादिभ्योऽञ् ।
    """
    pass


@registry.register("5.1.130", text="हायनान्तयुवादिभ्योऽण् ।")
def rule_5_1_130(ctx=None):
    """
    5.1.130: हायनान्तयुवादिभ्योऽण् ।
    """
    pass


@registry.register("5.1.131", text="इगन्ताच्च लघुपूर्वात् ।")
def rule_5_1_131(ctx=None):
    """
    5.1.131: इगन्ताच्च लघुपूर्वात् ।
    """
    pass


@registry.register("5.1.132", text="योपधाद्गुरूपोत्तमाङ्गुञ् ।")
def rule_5_1_132(ctx=None):
    """
    5.1.132: योपधाद्गुरूपोत्तमाङ्गुञ् ।
    """
    pass


@registry.register("5.1.133", text="द्वंद्वमनोज्ञादिभ्यश्च ।")
def rule_5_1_133(ctx=None):
    """
    5.1.133: द्वंद्वमनोज्ञादिभ्यश्च ।
    """
    pass


@registry.register("5.1.134", text="गोत्रचरणाच्लाघाऽत्याकारतदवेतेषु ।")
def rule_5_1_134(ctx=None):
    """
    5.1.134: गोत्रचरणाच्लाघाऽत्याकारतदवेतेषु ।
    """
    pass


@registry.register("5.1.135", text="होत्राभ्यश्छः ।")
def rule_5_1_135(ctx=None):
    """
    5.1.135: होत्राभ्यश्छः ।
    """
    pass


@registry.register("5.1.136", text="ब्रह्मणस्त्वः ।")
def rule_5_1_136(ctx=None):
    """
    5.1.136: ब्रह्मणस्त्वः ।
    """
    pass


@registry.register("5.2.1", text="धान्यानां भवने क्षेत्रे खञ् ।")
def rule_5_2_1(ctx=None):
    """
    5.2.1: धान्यानां भवने क्षेत्रे खञ् ।
    """
    pass


@registry.register("5.2.2", text="व्रीहिशाल्योर्दक् ।")
def rule_5_2_2(ctx=None):
    """
    5.2.2: व्रीहिशाल्योर्दक् ।
    """
    pass


@registry.register("5.2.3", text="यवयवकषष्टिकादत् ।")
def rule_5_2_3(ctx=None):
    """
    5.2.3: यवयवकषष्टिकादत् ।
    """
    pass


@registry.register("5.2.4", text="विभाषा तिलमाषोमाभङ्गाऽणुभ्यः ।")
def rule_5_2_4(ctx=None):
    """
    5.2.4: विभाषा तिलमाषोमाभङ्गाऽणुभ्यः ।
    """
    pass


@registry.register("5.2.5", text="सर्वचर्मणः कृतः खखौ ।")
def rule_5_2_5(ctx=None):
    """
    5.2.5: सर्वचर्मणः कृतः खखौ ।
    """
    pass


@registry.register("5.2.6", text="यथामुखसंमुखस्य दर्शनः खः ।")
def rule_5_2_6(ctx=None):
    """
    5.2.6: यथामुखसंमुखस्य दर्शनः खः ।
    """
    pass


@registry.register("5.2.7", text="तत्सर्वादेः पथ्यङ्गकर्मपत्रपात्रं व्याप्नोति ।")
def rule_5_2_7(ctx=None):
    """
    5.2.7: तत्सर्वादेः पथ्यङ्गकर्मपत्रपात्रं व्याप्नोति ।
    """
    pass


@registry.register("5.2.8", text="आप्रपदं प्राप्नोति ।")
def rule_5_2_8(ctx=None):
    """
    5.2.8: आप्रपदं प्राप्नोति ।
    """
    pass


@registry.register("5.2.9", text="अनुपदसर्वान्नायानयं बद्धाभक्षयतिनेयेषु ।")
def rule_5_2_9(ctx=None):
    """
    5.2.9: अनुपदसर्वान्नायानयं बद्धाभक्षयतिनेयेषु ।
    """
    pass


@registry.register("5.2.10", text="परोवरपरम्परपुत्रपौत्रमनुभवति ।")
def rule_5_2_10(ctx=None):
    """
    5.2.10: परोवरपरम्परपुत्रपौत्रमनुभवति ।
    """
    pass


@registry.register("5.2.11", text="अवारपारात्यन्तानुकामं गामी ।")
def rule_5_2_11(ctx=None):
    """
    5.2.11: अवारपारात्यन्तानुकामं गामी ।
    """
    pass


@registry.register("5.2.12", text="समांसमां विजायते ।")
def rule_5_2_12(ctx=None):
    """
    5.2.12: समांसमां विजायते ।
    """
    pass


@registry.register("5.2.13", text="अद्यश्वीनाऽवष्टब्धे ।")
def rule_5_2_13(ctx=None):
    """
    5.2.13: अद्यश्वीनाऽवष्टब्धे ।
    """
    pass


@registry.register("5.2.14", text="आगवीनः ।")
def rule_5_2_14(ctx=None):
    """
    5.2.14: आगवीनः ।
    """
    pass


@registry.register("5.2.15", text="अनुग्वलंगामी ।")
def rule_5_2_15(ctx=None):
    """
    5.2.15: अनुग्वलंगामी ।
    """
    pass


@registry.register("5.2.16", text="अध्वनो यत्खौ ।")
def rule_5_2_16(ctx=None):
    """
    5.2.16: अध्वनो यत्खौ ।
    """
    pass


@registry.register("5.2.17", text="अभ्यमित्राच्छ च ।")
def rule_5_2_17(ctx=None):
    """
    5.2.17: अभ्यमित्राच्छ च ।
    """
    pass


@registry.register("5.2.18", text="गोष्ठात् खञ् भूतपूर्वे ।")
def rule_5_2_18(ctx=None):
    """
    5.2.18: गोष्ठात् खञ् भूतपूर्वे ।
    """
    pass


@registry.register("5.2.19", text="अश्वस्यैकाहगमः ।")
def rule_5_2_19(ctx=None):
    """
    5.2.19: अश्वस्यैकाहगमः ।
    """
    pass


@registry.register("5.2.20", text="शालीनकौपीने अधृष्टाकार्ययोः ।")
def rule_5_2_20(ctx=None):
    """
    5.2.20: शालीनकौपीने अधृष्टाकार्ययोः ।
    """
    pass


@registry.register("5.2.21", text="व्रातेन जीवति ।")
def rule_5_2_21(ctx=None):
    """
    5.2.21: व्रातेन जीवति ।
    """
    pass


@registry.register("5.2.22", text="साप्तपदीनं सख्यम् ।")
def rule_5_2_22(ctx=None):
    """
    5.2.22: साप्तपदीनं सख्यम् ।
    """
    pass


@registry.register("5.2.23", text="हैयंगवीनं संज्ञायाम् ।")
def rule_5_2_23(ctx=None):
    """
    5.2.23: हैयंगवीनं संज्ञायाम् ।
    """
    pass


@registry.register("5.2.24", text="तस्य पाकमूले पील्वदिकर्णादिभ्यः कुणजाहचौ ।")
def rule_5_2_24(ctx=None):
    """
    5.2.24: तस्य पाकमूले पील्वदिकर्णादिभ्यः कुणजाहचौ ।
    """
    pass


@registry.register("5.2.25", text="पक्षात्तिः ।")
def rule_5_2_25(ctx=None):
    """
    5.2.25: पक्षात्तिः ।
    """
    pass


@registry.register("5.2.26", text="तेन वित्तश्चञ्चप्वणपौ ।")
def rule_5_2_26(ctx=None):
    """
    5.2.26: तेन वित्तश्चञ्चप्वणपौ ।
    """
    pass


@registry.register("5.2.27", text="विनञ्भ्यां नानाञौ नसह ।")
def rule_5_2_27(ctx=None):
    """
    5.2.27: विनञ्भ्यां नानाञौ नसह ।
    """
    pass


@registry.register("5.2.28", text="वेः शालच्छङ्कटचौ ।")
def rule_5_2_28(ctx=None):
    """
    5.2.28: वेः शालच्छङ्कटचौ ।
    """
    pass


@registry.register("5.2.29", text="सम्प्रोदश्च कटच् ।")
def rule_5_2_29(ctx=None):
    """
    5.2.29: सम्प्रोदश्च कटच् ।
    """
    pass


@registry.register("5.2.30", text="अवात् कुटारच्च ।")
def rule_5_2_30(ctx=None):
    """
    5.2.30: अवात् कुटारच्च ।
    """
    pass


@registry.register("5.2.31", text="नते नासिकायाः संज्ञायां टीटञ्नाटज्भ्राटचः ।")
def rule_5_2_31(ctx=None):
    """
    5.2.31: नते नासिकायाः संज्ञायां टीटञ्नाटज्भ्राटचः ।
    """
    pass


@registry.register("5.2.32", text="नेर्बिडज्बिरीसचौ ।")
def rule_5_2_32(ctx=None):
    """
    5.2.32: नेर्बिडज्बिरीसचौ ।
    """
    pass


@registry.register("5.2.33", text="इनच्पिटच्चिकचि च ।")
def rule_5_2_33(ctx=None):
    """
    5.2.33: इनच्पिटच्चिकचि च ।
    """
    pass


@registry.register("5.2.34", text="उपाधिभ्यां त्यकन्नासन्नारूढ्योः ।")
def rule_5_2_34(ctx=None):
    """
    5.2.34: उपाधिभ्यां त्यकन्नासन्नारूढ्योः ।
    """
    pass


@registry.register("5.2.35", text="कर्मणि घटोऽठच् ।")
def rule_5_2_35(ctx=None):
    """
    5.2.35: कर्मणि घटोऽठच् ।
    """
    pass


@registry.register("5.2.36", text="तदस्य संजातं तारकाऽऽदिभ्य इतच् ।")
def rule_5_2_36(ctx=None):
    """
    5.2.36: तदस्य संजातं तारकाऽऽदिभ्य इतच् ।
    """
    pass


@registry.register("5.2.37", text="प्रमाणे द्वयसज्दघ्नमात्रचः ।")
def rule_5_2_37(ctx=None):
    """
    5.2.37: प्रमाणे द्वयसज्दघ्नमात्रचः ।
    """
    pass


@registry.register("5.2.38", text="पुरुषहस्तिभ्यामण् च ।")
def rule_5_2_38(ctx=None):
    """
    5.2.38: पुरुषहस्तिभ्यामण् च ।
    """
    pass


@registry.register("5.2.39", text="यद्गदेतेभ्यः परिमाणे वतुप् ।")
def rule_5_2_39(ctx=None):
    """
    5.2.39: यद्गदेतेभ्यः परिमाणे वतुप् ।
    """
    pass


@registry.register("5.2.40", text="किमिदंभ्यां वो घः ।")
def rule_5_2_40(ctx=None):
    """
    5.2.40: किमिदंभ्यां वो घः ।
    """
    pass


@registry.register("5.2.41", text="किमः संख्यापरिमाणे डति च ।")
def rule_5_2_41(ctx=None):
    """
    5.2.41: किमः संख्यापरिमाणे डति च ।
    """
    pass


@registry.register("5.2.42", text="संख्याया अवयवे तयप् ।")
def rule_5_2_42(ctx=None):
    """
    5.2.42: संख्याया अवयवे तयप् ।
    """
    pass


@registry.register("5.2.43", text="द्वित्रिभ्यां तयस्यायज्वा ।")
def rule_5_2_43(ctx=None):
    """
    5.2.43: द्वित्रिभ्यां तयस्यायज्वा ।
    """
    pass


@registry.register("5.2.44", text="उभादुदात्तो नित्यम् ।")
def rule_5_2_44(ctx=None):
    """
    5.2.44: उभादुदात्तो नित्यम् ।
    """
    pass


@registry.register("5.2.45", text="तदस्मिन्नधिकमिति दशान्ताड्डः ।")
def rule_5_2_45(ctx=None):
    """
    5.2.45: तदस्मिन्नधिकमिति दशान्ताड्डः ।
    """
    pass


@registry.register("5.2.46", text="शदन्तविंशतेश्च ।")
def rule_5_2_46(ctx=None):
    """
    5.2.46: शदन्तविंशतेश्च ।
    """
    pass


@registry.register("5.2.47", text="संख्याया गुणस्य निमाने मयट् ।")
def rule_5_2_47(ctx=None):
    """
    5.2.47: संख्याया गुणस्य निमाने मयट् ।
    """
    pass


@registry.register("5.2.48", text="तस्य पूरणे डट् ।")
def rule_5_2_48(ctx=None):
    """
    5.2.48: तस्य पूरणे डट् ।
    """
    pass


@registry.register("5.2.49", text="नान्तादसंख्याऽऽदेर्मट् ।")
def rule_5_2_49(ctx=None):
    """
    5.2.49: नान्तादसंख्याऽऽदेर्मट् ।
    """
    pass


@registry.register("5.2.50", text="थट् च च्छन्दसि ।")
def rule_5_2_50(ctx=None):
    """
    5.2.50: थट् च च्छन्दसि ।
    """
    pass


@registry.register("5.2.51", text="षट्गतिकतिपयचतुरां थुक् ।")
def rule_5_2_51(ctx=None):
    """
    5.2.51: षट्गतिकतिपयचतुरां थुक् ।
    """
    pass


@registry.register("5.2.52", text="बहुपूगगणसंघस्य तिथुक् ।")
def rule_5_2_52(ctx=None):
    """
    5.2.52: बहुपूगगणसंघस्य तिथुक् ।
    """
    pass


@registry.register("5.2.53", text="वतोरिथुक् ।")
def rule_5_2_53(ctx=None):
    """
    5.2.53: वतोरिथुक् ।
    """
    pass


@registry.register("5.2.54", text="द्वेस्तीयः ।")
def rule_5_2_54(ctx=None):
    """
    5.2.54: द्वेस्तीयः ।
    """
    pass


@registry.register("5.2.55", text="त्रेः सम्प्रसारणम् च ।")
def rule_5_2_55(ctx=None):
    """
    5.2.55: त्रेः सम्प्रसारणम् च ।
    """
    pass


@registry.register("5.2.56", text="विंशत्यादिभ्यस्तमडन्यतरस्याम् ।")
def rule_5_2_56(ctx=None):
    """
    5.2.56: विंशत्यादिभ्यस्तमडन्यतरस्याम् ।
    """
    pass


@registry.register("5.2.57", text="नित्यं शतादिमासार्धमाससंवत्सराच्च ।")
def rule_5_2_57(ctx=None):
    """
    5.2.57: नित्यं शतादिमासार्धमाससंवत्सराच्च ।
    """
    pass


@registry.register("5.2.58", text="षष्ट्यादेश्चासंख्याऽऽदेः ।")
def rule_5_2_58(ctx=None):
    """
    5.2.58: षष्ट्यादेश्चासंख्याऽऽदेः ।
    """
    pass


@registry.register("5.2.59", text="मतौ च्छः सूक्तसाम्नोः ।")
def rule_5_2_59(ctx=None):
    """
    5.2.59: मतौ च्छः सूक्तसाम्नोः ।
    """
    pass


@registry.register("5.2.61", text="विमुक्तादिभ्योऽण् ।")
def rule_5_2_61(ctx=None):
    """
    5.2.61: विमुक्तादिभ्योऽण् ।
    """
    pass


@registry.register("5.2.62", text="गोषदादिभ्यो वुन् ।")
def rule_5_2_62(ctx=None):
    """
    5.2.62: गोषदादिभ्यो वुन् ।
    """
    pass


@registry.register("5.2.63", text="तत्र कुशलः पथः ।")
def rule_5_2_63(ctx=None):
    """
    5.2.63: तत्र कुशलः पथः ।
    """
    pass


@registry.register("5.2.64", text="आकर्षादिभ्यः कन् ।")
def rule_5_2_64(ctx=None):
    """
    5.2.64: आकर्षादिभ्यः कन् ।
    """
    pass


@registry.register("5.2.65", text="धनहिरण्यात् कामे ।")
def rule_5_2_65(ctx=None):
    """
    5.2.65: धनहिरण्यात् कामे ।
    """
    pass


@registry.register("5.2.66", text="स्वाङ्गेभ्यः प्रसिते ।")
def rule_5_2_66(ctx=None):
    """
    5.2.66: स्वाङ्गेभ्यः प्रसिते ।
    """
    pass


@registry.register("5.2.67", text="उदराट्ठगाद्यूने ।")
def rule_5_2_67(ctx=None):
    """
    5.2.67: उदराट्ठगाद्यूने ।
    """
    pass


@registry.register("5.2.68", text="सस्येन परिजातः ।")
def rule_5_2_68(ctx=None):
    """
    5.2.68: सस्येन परिजातः ।
    """
    pass


@registry.register("5.2.69", text="अंशं हारी ।")
def rule_5_2_69(ctx=None):
    """
    5.2.69: अंशं हारी ।
    """
    pass


@registry.register("5.2.70", text="तन्त्रादचिरापहृते ।")
def rule_5_2_70(ctx=None):
    """
    5.2.70: तन्त्रादचिरापहृते ।
    """
    pass


@registry.register("5.2.71", text="ब्राह्मणकोष्णिके संज्ञायाम् ।")
def rule_5_2_71(ctx=None):
    """
    5.2.71: ब्राह्मणकोष्णिके संज्ञायाम् ।
    """
    pass


@registry.register("5.2.72", text="शीतोष्णाभ्यां कारिणि ।")
def rule_5_2_72(ctx=None):
    """
    5.2.72: शीतोष्णाभ्यां कारिणि ।
    """
    pass


@registry.register("5.2.73", text="अधिकम् ।")
def rule_5_2_73(ctx=None):
    """
    5.2.73: अधिकम् ।
    """
    pass


@registry.register("5.2.74", text="अनुकाभिकाभीकः कमिता ।")
def rule_5_2_74(ctx=None):
    """
    5.2.74: अनुकाभिकाभीकः कमिता ।
    """
    pass


@registry.register("5.2.75", text="पार्श्वनान्विच्छति ।")
def rule_5_2_75(ctx=None):
    """
    5.2.75: पार्श्वनान्विच्छति ।
    """
    pass


@registry.register("5.2.76", text="अयःशूलदण्डाजिनाभ्यां ठक्ठञौ ।")
def rule_5_2_76(ctx=None):
    """
    5.2.76: अयःशूलदण्डाजिनाभ्यां ठक्ठञौ ।
    """
    pass


@registry.register("5.2.77", text="तावतिथं ग्रहणमिति लुग्वा ।")
def rule_5_2_77(ctx=None):
    """
    5.2.77: तावतिथं ग्रहणमिति लुग्वा ।
    """
    pass


@registry.register("5.2.78", text="स एषां ग्रामणीः ।")
def rule_5_2_78(ctx=None):
    """
    5.2.78: स एषां ग्रामणीः ।
    """
    pass


@registry.register("5.2.79", text="शृङ्खलमस्य बन्धनं करभे ।")
def rule_5_2_79(ctx=None):
    """
    5.2.79: शृङ्खलमस्य बन्धनं करभे ।
    """
    pass


@registry.register("5.2.80", text="उत्क उन्मनाः ।")
def rule_5_2_80(ctx=None):
    """
    5.2.80: उत्क उन्मनाः ।
    """
    pass


@registry.register("5.2.81", text="कालप्रयोजनाद्रोगे ।")
def rule_5_2_81(ctx=None):
    """
    5.2.81: कालप्रयोजनाद्रोगे ।
    """
    pass


@registry.register("5.2.82", text="तदस्मिन्नन्नं प्राये संज्ञायाम् ।")
def rule_5_2_82(ctx=None):
    """
    5.2.82: तदस्मिन्नन्नं प्राये संज्ञायाम् ।
    """
    pass


@registry.register("5.2.83", text="कुल्माषादञ् ।")
def rule_5_2_83(ctx=None):
    """
    5.2.83: कुल्माषादञ् ।
    """
    pass


@registry.register("5.2.84", text="श्रोत्रियंश्छन्दोऽधीते ।")
def rule_5_2_84(ctx=None):
    """
    5.2.84: श्रोत्रियंश्छन्दोऽधीते ।
    """
    pass


@registry.register("5.2.85", text="श्राद्धमनेन भुक्तमिनिठनौ ।")
def rule_5_2_85(ctx=None):
    """
    5.2.85: श्राद्धमनेन भुक्तमिनिठनौ ।
    """
    pass


@registry.register("5.2.86", text="पूर्वादिनिः ।")
def rule_5_2_86(ctx=None):
    """
    5.2.86: पूर्वादिनिः ।
    """
    pass


@registry.register("5.2.87", text="सपूर्वाच्च ।")
def rule_5_2_87(ctx=None):
    """
    5.2.87: सपूर्वाच्च ।
    """
    pass


@registry.register("5.2.88", text="इष्टादिभ्यश्च ।")
def rule_5_2_88(ctx=None):
    """
    5.2.88: इष्टादिभ्यश्च ।
    """
    pass


@registry.register("5.2.89", text="छन्दसि परिपन्थिपरिपरिणौ पर्यवस्थातरि ।")
def rule_5_2_89(ctx=None):
    """
    5.2.89: छन्दसि परिपन्थिपरिपरिणौ पर्यवस्थातरि ।
    """
    pass


@registry.register("5.2.90", text="अनुपद्यन्वेष्टा ।")
def rule_5_2_90(ctx=None):
    """
    5.2.90: अनुपद्यन्वेष्टा ।
    """
    pass


@registry.register("5.2.91", text="साक्षाद्दष्टरि संज्ञायाम् ।")
def rule_5_2_91(ctx=None):
    """
    5.2.91: साक्षाद्दष्टरि संज्ञायाम् ।
    """
    pass


@registry.register("5.2.92", text="क्षेत्रियच् परक्षेत्रे चिकित्स्यः ।")
def rule_5_2_92(ctx=None):
    """
    5.2.92: क्षेत्रियच् परक्षेत्रे चिकित्स्यः ।
    """
    pass


@registry.register("5.2.93", text="इन्द्रियमिन्द्रलिंगमिन्द्रदृष्टमिन्द्रसृष्टमिन्द्रजुष्टमिन्द्रदत्तमिति वा ।")
def rule_5_2_93(ctx=None):
    """
    5.2.93: इन्द्रियमिन्द्रलिंगमिन्द्रदृष्टमिन्द्रसृष्टमिन्द्रजुष्टमिन्द्रदत्तमिति वा ।
    """
    pass


@registry.register("5.2.94", text="तदस्यास्त्यस्मिन्निति मतुप् ।")
def rule_5_2_94(ctx=None):
    """
    5.2.94: तदस्यास्त्यस्मिन्निति मतुप् ।
    """
    pass


@registry.register("5.2.95", text="रसादिभ्यश्च ।")
def rule_5_2_95(ctx=None):
    """
    5.2.95: रसादिभ्यश्च ।
    """
    pass


@registry.register("5.2.96", text="प्राणिस्थादातो लजन्यतरस्याम् ।")
def rule_5_2_96(ctx=None):
    """
    5.2.96: प्राणिस्थादातो लजन्यतरस्याम् ।
    """
    pass


@registry.register("5.2.97", text="सिध्मादिभ्यश्च ।")
def rule_5_2_97(ctx=None):
    """
    5.2.97: सिध्मादिभ्यश्च ।
    """
    pass


@registry.register("5.2.98", text="वत्सांसाभ्यां कामबले ।")
def rule_5_2_98(ctx=None):
    """
    5.2.98: वत्सांसाभ्यां कामबले ।
    """
    pass


@registry.register("5.2.99", text="फेनादिलच् च ।")
def rule_5_2_99(ctx=None):
    """
    5.2.99: फेनादिलच् च ।
    """
    pass


@registry.register("5.2.100", text="लोमादिपामादिपिच्छादिभ्यः शनेलचः ।")
def rule_5_2_100(ctx=None):
    """
    5.2.100: लोमादिपामादिपिच्छादिभ्यः शनेलचः ।
    """
    pass


@registry.register("5.2.101", text="प्रज्ञाश्रद्धाऽर्चावृत्तिभ्यो णः ।")
def rule_5_2_101(ctx=None):
    """
    5.2.101: प्रज्ञाश्रद्धाऽर्चावृत्तिभ्यो णः ।
    """
    pass


@registry.register("5.2.102", text="तपःसहस्राभ्यां विनीनी ।")
def rule_5_2_102(ctx=None):
    """
    5.2.102: तपःसहस्राभ्यां विनीनी ।
    """
    pass


@registry.register("5.2.103", text="अण् च ।")
def rule_5_2_103(ctx=None):
    """
    5.2.103: अण् च ।
    """
    pass


@registry.register("5.2.104", text="सिकताशर्कराभ्यां च ।")
def rule_5_2_104(ctx=None):
    """
    5.2.104: सिकताशर्कराभ्यां च ।
    """
    pass


@registry.register("5.2.105", text="देशे लुबिलचौ च ।")
def rule_5_2_105(ctx=None):
    """
    5.2.105: देशे लुबिलचौ च ।
    """
    pass


@registry.register("5.2.106", text="दन्त उन्नत उरच् ।")
def rule_5_2_106(ctx=None):
    """
    5.2.106: दन्त उन्नत उरच् ।
    """
    pass


@registry.register("5.2.107", text="ऊषसुषिमुष्कमधो रः ।")
def rule_5_2_107(ctx=None):
    """
    5.2.107: ऊषसुषिमुष्कमधो रः ।
    """
    pass


@registry.register("5.2.108", text="द्युद्रुभ्यां मः ।")
def rule_5_2_108(ctx=None):
    """
    5.2.108: द्युद्रुभ्यां मः ।
    """
    pass


@registry.register("5.2.109", text="केशाब्द्वोऽन्यतरस्याम् ।")
def rule_5_2_109(ctx=None):
    """
    5.2.109: केशाब्द्वोऽन्यतरस्याम् ।
    """
    pass


@registry.register("5.2.110", text="गाण्ड्यजगात् संज्ञायाम् ।")
def rule_5_2_110(ctx=None):
    """
    5.2.110: गाण्ड्यजगात् संज्ञायाम् ।
    """
    pass


@registry.register("5.2.111", text="काण्डाण्डादीरन्नीरचौ ।")
def rule_5_2_111(ctx=None):
    """
    5.2.111: काण्डाण्डादीरन्नीरचौ ।
    """
    pass


@registry.register("5.2.112", text="रजःकृष्यासुतिपरिषदो वलच् ।")
def rule_5_2_112(ctx=None):
    """
    5.2.112: रजःकृष्यासुतिपरिषदो वलच् ।
    """
    pass


@registry.register("5.2.113", text="दन्तशिखात् संज्ञायाम् ।")
def rule_5_2_113(ctx=None):
    """
    5.2.113: दन्तशिखात् संज्ञायाम् ।
    """
    pass


@registry.register("5.2.114", text="ज्योत्स्नातमिस्राशृङ्गिणोजस्विन्नूर्जस्वलगोमिन्मलिनमलीमसाः ।")
def rule_5_2_114(ctx=None):
    """
    5.2.114: ज्योत्स्नातमिस्राशृङ्गिणोजस्विन्नूर्जस्वलगोमिन्मलिनमलीमसाः ।
    """
    pass


@registry.register("5.2.115", text="अत इनिठनौ ।")
def rule_5_2_115(ctx=None):
    """
    5.2.115: अत इनिठनौ ।
    """
    pass


@registry.register("5.2.116", text="व्रीह्यादिभ्यश्च ।")
def rule_5_2_116(ctx=None):
    """
    5.2.116: व्रीह्यादिभ्यश्च ।
    """
    pass


@registry.register("5.2.117", text="तुन्दादिभ्य इलच् च ।")
def rule_5_2_117(ctx=None):
    """
    5.2.117: तुन्दादिभ्य इलच् च ।
    """
    pass


@registry.register("5.2.118", text="एकगोपूर्वाट्ठञ् नित्यम् ।")
def rule_5_2_118(ctx=None):
    """
    5.2.118: एकगोपूर्वाट्ठञ् नित्यम् ।
    """
    pass


@registry.register("5.2.119", text="शतसहस्रान्ताच्च निष्कात् ।")
def rule_5_2_119(ctx=None):
    """
    5.2.119: शतसहस्रान्ताच्च निष्कात् ।
    """
    pass


@registry.register("5.2.120", text="रूपादाहतप्रशंसयोरप् ।")
def rule_5_2_120(ctx=None):
    """
    5.2.120: रूपादाहतप्रशंसयोरप् ।
    """
    pass


@registry.register("5.2.121", text="अस्मायामेधास्रजो विनिः ।")
def rule_5_2_121(ctx=None):
    """
    5.2.121: अस्मायामेधास्रजो विनिः ।
    """
    pass


@registry.register("5.2.122", text="बहुलं छन्दसि ।")
def rule_5_2_122(ctx=None):
    """
    5.2.122: बहुलं छन्दसि ।
    """
    pass


@registry.register("5.2.123", text="ऊर्णाया युस् ।")
def rule_5_2_123(ctx=None):
    """
    5.2.123: ऊर्णाया युस् ।
    """
    pass


@registry.register("5.2.124", text="वाचो ग्मिनिः ।")
def rule_5_2_124(ctx=None):
    """
    5.2.124: वाचो ग्मिनिः ।
    """
    pass


@registry.register("5.2.125", text="आलजाटचौ बहुभाषिणि ।")
def rule_5_2_125(ctx=None):
    """
    5.2.125: आलजाटचौ बहुभाषिणि ।
    """
    pass


@registry.register("5.2.126", text="स्वामिन्नैश्वर्ये ।")
def rule_5_2_126(ctx=None):
    """
    5.2.126: स्वामिन्नैश्वर्ये ।
    """
    pass


@registry.register("5.2.127", text="अर्शादिभ्योऽच् ।")
def rule_5_2_127(ctx=None):
    """
    5.2.127: अर्शादिभ्योऽच् ।
    """
    pass


@registry.register("5.2.128", text="द्वंद्वोपतापगह्यत् प्राणिस्थादिनिः ।")
def rule_5_2_128(ctx=None):
    """
    5.2.128: द्वंद्वोपतापगह्यत् प्राणिस्थादिनिः ।
    """
    pass


@registry.register("5.2.129", text="वातातिसाराभ्यां कुक् च ।")
def rule_5_2_129(ctx=None):
    """
    5.2.129: वातातिसाराभ्यां कुक् च ।
    """
    pass


@registry.register("5.2.130", text="वयसि पूरणात् ।")
def rule_5_2_130(ctx=None):
    """
    5.2.130: वयसि पूरणात् ।
    """
    pass


@registry.register("5.2.131", text="सुखादिभ्यश्च ।")
def rule_5_2_131(ctx=None):
    """
    5.2.131: सुखादिभ्यश्च ।
    """
    pass


@registry.register("5.2.132", text="धर्मशीलवर्णान्ताच्च ।")
def rule_5_2_132(ctx=None):
    """
    5.2.132: धर्मशीलवर्णान्ताच्च ।
    """
    pass


@registry.register("5.2.133", text="हस्ताज्जातौ ।")
def rule_5_2_133(ctx=None):
    """
    5.2.133: हस्ताज्जातौ ।
    """
    pass


@registry.register("5.2.134", text="वर्णाद्ब्रह्मचारिणि ।")
def rule_5_2_134(ctx=None):
    """
    5.2.134: वर्णाद्ब्रह्मचारिणि ।
    """
    pass


@registry.register("5.2.135", text="पुष्करादिभ्यो देशे ।")
def rule_5_2_135(ctx=None):
    """
    5.2.135: पुष्करादिभ्यो देशे ।
    """
    pass


@registry.register("5.2.136", text="बलादिभ्यो मतुबन्यतरस्याम् ।")
def rule_5_2_136(ctx=None):
    """
    5.2.136: बलादिभ्यो मतुबन्यतरस्याम् ।
    """
    pass


@registry.register("5.2.137", text="संज्ञायां मन्माभ्याम् ।")
def rule_5_2_137(ctx=None):
    """
    5.2.137: संज्ञायां मन्माभ्याम् ।
    """
    pass


@registry.register("5.2.138", text="कंशंभ्यां बभयुस्तितुतयसः ।")
def rule_5_2_138(ctx=None):
    """
    5.2.138: कंशंभ्यां बभयुस्तितुतयसः ।
    """
    pass


@registry.register("5.2.139", text="तुन्दिवलिवटेर्भः ।")
def rule_5_2_139(ctx=None):
    """
    5.2.139: तुन्दिवलिवटेर्भः ।
    """
    pass


@registry.register("5.2.140", text="अहंशुभमोर्युस् ।")
def rule_5_2_140(ctx=None):
    """
    5.2.140: अहंशुभमोर्युस् ।
    """
    pass


@registry.register("5.3.1", text="प्राग्दिशो विभक्तिः ।")
def rule_5_3_1(ctx=None):
    """
    5.3.1: प्राग्दिशो विभक्तिः ।
    """
    pass


@registry.register("5.3.2", text="किंसर्वनामबहुभ्योऽब्यादिभ्यः ।")
def rule_5_3_2(ctx=None):
    """
    5.3.2: किंसर्वनामबहुभ्योऽब्यादिभ्यः ।
    """
    pass


@registry.register("5.3.3", text="इदम इश् ।")
def rule_5_3_3(ctx=None):
    """
    5.3.3: इदम इश् ।
    """
    pass


@registry.register("5.3.4", text="एतेतौ रथोः ।")
def rule_5_3_4(ctx=None):
    """
    5.3.4: एतेतौ रथोः ।
    """
    pass


@registry.register("5.3.5", text="एतदोऽश् ।")
def rule_5_3_5(ctx=None):
    """
    5.3.5: एतदोऽश् ।
    """
    pass


@registry.register("5.3.6", text="सर्वस्य सोऽन्यतरस्यां दि ।")
def rule_5_3_6(ctx=None):
    """
    5.3.6: सर्वस्य सोऽन्यतरस्यां दि ।
    """
    pass


@registry.register("5.3.7", text="पञ्चम्यास्तसिल् ।")
def rule_5_3_7(ctx=None):
    """
    5.3.7: पञ्चम्यास्तसिल् ।
    """
    pass


@registry.register("5.3.8", text="तसेश्च ।")
def rule_5_3_8(ctx=None):
    """
    5.3.8: तसेश्च ।
    """
    pass


@registry.register("5.3.9", text="पर्यभिभ्यां च ।")
def rule_5_3_9(ctx=None):
    """
    5.3.9: पर्यभिभ्यां च ।
    """
    pass


@registry.register("5.3.10", text="सप्तम्यास्त्रल् ।")
def rule_5_3_10(ctx=None):
    """
    5.3.10: सप्तम्यास्त्रल् ।
    """
    pass


@registry.register("5.3.11", text="इदमो हः ।")
def rule_5_3_11(ctx=None):
    """
    5.3.11: इदमो हः ।
    """
    pass


@registry.register("5.3.12", text="किमोऽत् ।")
def rule_5_3_12(ctx=None):
    """
    5.3.12: किमोऽत् ।
    """
    pass


@registry.register("5.3.13", text="वा ह च च्छन्दसि ।")
def rule_5_3_13(ctx=None):
    """
    5.3.13: वा ह च च्छन्दसि ।
    """
    pass


@registry.register("5.3.14", text="इतराभ्योऽपि दृश्यन्ते ।")
def rule_5_3_14(ctx=None):
    """
    5.3.14: इतराभ्योऽपि दृश्यन्ते ।
    """
    pass


@registry.register("5.3.15", text="सर्वेकान्यकिंयत्तदः काले दा ।")
def rule_5_3_15(ctx=None):
    """
    5.3.15: सर्वेकान्यकिंयत्तदः काले दा ।
    """
    pass


@registry.register("5.3.16", text="इदमो र्हिल् ।")
def rule_5_3_16(ctx=None):
    """
    5.3.16: इदमो र्हिल् ।
    """
    pass


@registry.register("5.3.17", text="अधुना ।")
def rule_5_3_17(ctx=None):
    """
    5.3.17: अधुना ।
    """
    pass


@registry.register("5.3.18", text="दानीं च ।")
def rule_5_3_18(ctx=None):
    """
    5.3.18: दानीं च ।
    """
    pass


@registry.register("5.3.19", text="तदो दा च ।")
def rule_5_3_19(ctx=None):
    """
    5.3.19: तदो दा च ।
    """
    pass


@registry.register("5.3.20", text="तयोर्दार्हिलौ च च्छन्दसि ।")
def rule_5_3_20(ctx=None):
    """
    5.3.20: तयोर्दार्हिलौ च च्छन्दसि ।
    """
    pass


@registry.register("5.3.21", text="अनद्यतने र्हिलन्यतरस्याम् ।")
def rule_5_3_21(ctx=None):
    """
    5.3.21: अनद्यतने र्हिलन्यतरस्याम् ।
    """
    pass


@registry.register("5.3.22", text="सद्यःपरुत्परार्येषमःपरेद्यव्यद्यपूर्वेद्युरन्येद्युरन्यतरेद्युरितरेद्युरपरेद्युरधरेद्युरुभयेद्युरुत्तरेद्युः ।")
def rule_5_3_22(ctx=None):
    """
    5.3.22: सद्यःपरुत्परार्येषमःपरेद्यव्यद्यपूर्वेद्युरन्येद्युरन्यतरेद्युरितरेद्युरपरेद्युरधरेद्युरुभयेद्युरुत्तरेद्युः ।
    """
    pass


@registry.register("5.3.23", text="प्रकारवचने थाल् ।")
def rule_5_3_23(ctx=None):
    """
    5.3.23: प्रकारवचने थाल् ।
    """
    pass


@registry.register("5.3.24", text="इदमस्थमुः ।")
def rule_5_3_24(ctx=None):
    """
    5.3.24: इदमस्थमुः ।
    """
    pass


@registry.register("5.3.25", text="किमश्च ।")
def rule_5_3_25(ctx=None):
    """
    5.3.25: किमश्च ।
    """
    pass


@registry.register("5.3.26", text="था हेतौ च च्छन्दसि ।")
def rule_5_3_26(ctx=None):
    """
    5.3.26: था हेतौ च च्छन्दसि ।
    """
    pass


@registry.register("5.3.27", text="दिक्शब्देभ्यः सप्तमीपञ्चमीप्रथमाभ्यो दिग्देशकालेष्वस्तातिः ।")
def rule_5_3_27(ctx=None):
    """
    5.3.27: दिक्शब्देभ्यः सप्तमीपञ्चमीप्रथमाभ्यो दिग्देशकालेष्वस्तातिः ।
    """
    pass


@registry.register("5.3.28", text="दक्षिणोत्तराभ्यामतसुच् ।")
def rule_5_3_28(ctx=None):
    """
    5.3.28: दक्षिणोत्तराभ्यामतसुच् ।
    """
    pass


@registry.register("5.3.29", text="विभाषा परावराभ्याम् ।")
def rule_5_3_29(ctx=None):
    """
    5.3.29: विभाषा परावराभ्याम् ।
    """
    pass


@registry.register("5.3.30", text="अञ्चेर्लुक् ।")
def rule_5_3_30(ctx=None):
    """
    5.3.30: अञ्चेर्लुक् ।
    """
    pass


@registry.register("5.3.31", text="उपर्युपरिष्टात् ।")
def rule_5_3_31(ctx=None):
    """
    5.3.31: उपर्युपरिष्टात् ।
    """
    pass


@registry.register("5.3.32", text="पश्चात् ।")
def rule_5_3_32(ctx=None):
    """
    5.3.32: पश्चात् ।
    """
    pass


@registry.register("5.3.33", text="पश्च पश्चा च च्छन्दसि ।")
def rule_5_3_33(ctx=None):
    """
    5.3.33: पश्च पश्चा च च्छन्दसि ।
    """
    pass


@registry.register("5.3.34", text="उत्तराधरदक्षिणादातिः ।")
def rule_5_3_34(ctx=None):
    """
    5.3.34: उत्तराधरदक्षिणादातिः ।
    """
    pass


@registry.register("5.3.35", text="एनबन्यतरस्यामदूरेऽपञ्चम्याः ।")
def rule_5_3_35(ctx=None):
    """
    5.3.35: एनबन्यतरस्यामदूरेऽपञ्चम्याः ।
    """
    pass


@registry.register("5.3.36", text="दक्षिणादाच् ।")
def rule_5_3_36(ctx=None):
    """
    5.3.36: दक्षिणादाच् ।
    """
    pass


@registry.register("5.3.37", text="आहि च दूरे ।")
def rule_5_3_37(ctx=None):
    """
    5.3.37: आहि च दूरे ।
    """
    pass


@registry.register("5.3.38", text="उत्तराच्च ।")
def rule_5_3_38(ctx=None):
    """
    5.3.38: उत्तराच्च ।
    """
    pass


@registry.register("5.3.39", text="पूर्वाधरावराणामसि पुरधवश्चैषाम् ।")
def rule_5_3_39(ctx=None):
    """
    5.3.39: पूर्वाधरावराणामसि पुरधवश्चैषाम् ।
    """
    pass


@registry.register("5.3.40", text="अस्ताति च ।")
def rule_5_3_40(ctx=None):
    """
    5.3.40: अस्ताति च ।
    """
    pass


@registry.register("5.3.41", text="विभाषाऽवरस्य ।")
def rule_5_3_41(ctx=None):
    """
    5.3.41: विभाषाऽवरस्य ।
    """
    pass


@registry.register("5.3.42", text="संख्याया विधाऽर्थे धा ।")
def rule_5_3_42(ctx=None):
    """
    5.3.42: संख्याया विधाऽर्थे धा ।
    """
    pass


@registry.register("5.3.43", text="अधिकरणविचाले च ।")
def rule_5_3_43(ctx=None):
    """
    5.3.43: अधिकरणविचाले च ।
    """
    pass


@registry.register("5.3.44", text="एकाद्धो ध्यमुञन्यारयाम् ।")
def rule_5_3_44(ctx=None):
    """
    5.3.44: एकाद्धो ध्यमुञन्यारयाम् ।
    """
    pass


@registry.register("5.3.45", text="द्वित्र्योश्च धमुञ् ।")
def rule_5_3_45(ctx=None):
    """
    5.3.45: द्वित्र्योश्च धमुञ् ।
    """
    pass


@registry.register("5.3.46", text="एधाच्च ।")
def rule_5_3_46(ctx=None):
    """
    5.3.46: एधाच्च ।
    """
    pass


@registry.register("5.3.47", text="याप्ये पाशप् ।")
def rule_5_3_47(ctx=None):
    """
    5.3.47: याप्ये पाशप् ।
    """
    pass


@registry.register("5.3.48", text="पूरणाद्भागे तीयादन् ।")
def rule_5_3_48(ctx=None):
    """
    5.3.48: पूरणाद्भागे तीयादन् ।
    """
    pass


@registry.register("5.3.49", text="प्रागेकादशभ्योऽच्छन्दसि ।")
def rule_5_3_49(ctx=None):
    """
    5.3.49: प्रागेकादशभ्योऽच्छन्दसि ।
    """
    pass


@registry.register("5.3.50", text="षष्ठाष्टमाभ्यां ञ च ।")
def rule_5_3_50(ctx=None):
    """
    5.3.50: षष्ठाष्टमाभ्यां ञ च ।
    """
    pass


@registry.register("5.3.51", text="मानपश्वङ्गयोः कन्लुकौ च ।")
def rule_5_3_51(ctx=None):
    """
    5.3.51: मानपश्वङ्गयोः कन्लुकौ च ।
    """
    pass


@registry.register("5.3.52", text="एकादाकिनिच्चासहाये ।")
def rule_5_3_52(ctx=None):
    """
    5.3.52: एकादाकिनिच्चासहाये ।
    """
    pass


@registry.register("5.3.53", text="भूतपूर्व चरट् ।")
def rule_5_3_53(ctx=None):
    """
    5.3.53: भूतपूर्व चरट् ।
    """
    pass


@registry.register("5.3.54", text="षष्ठ्या रूप्य च ।")
def rule_5_3_54(ctx=None):
    """
    5.3.54: षष्ठ्या रूप्य च ।
    """
    pass


@registry.register("5.3.55", text="अतिशायने तमबिष्ठनौ ।")
def rule_5_3_55(ctx=None):
    """
    5.3.55: अतिशायने तमबिष्ठनौ ।
    """
    pass


@registry.register("5.3.56", text="तिङश्च ।")
def rule_5_3_56(ctx=None):
    """
    5.3.56: तिङश्च ।
    """
    pass


@registry.register("5.3.57", text="द्विवचनविभज्योपपदे तरबीयसुनौ ।")
def rule_5_3_57(ctx=None):
    """
    5.3.57: द्विवचनविभज्योपपदे तरबीयसुनौ ।
    """
    pass


@registry.register("5.3.58", text="अजादी गुणवचनादेव ।")
def rule_5_3_58(ctx=None):
    """
    5.3.58: अजादी गुणवचनादेव ।
    """
    pass


@registry.register("5.3.59", text="तुश्छन्दसि ।")
def rule_5_3_59(ctx=None):
    """
    5.3.59: तुश्छन्दसि ।
    """
    pass


@registry.register("5.3.60", text="प्रशस्यस्य श्रः ।")
def rule_5_3_60(ctx=None):
    """
    5.3.60: प्रशस्यस्य श्रः ।
    """
    pass


@registry.register("5.3.61", text="ज्य च ।")
def rule_5_3_61(ctx=None):
    """
    5.3.61: ज्य च ।
    """
    pass


@registry.register("5.3.62", text="वृद्धस्य च ।")
def rule_5_3_62(ctx=None):
    """
    5.3.62: वृद्धस्य च ।
    """
    pass


@registry.register("5.3.63", text="अन्तिकबाढयोर्नेदसाधौ ।")
def rule_5_3_63(ctx=None):
    """
    5.3.63: अन्तिकबाढयोर्नेदसाधौ ।
    """
    pass


@registry.register("5.3.64", text="युवाल्पयोः कनन्यतरस्याम् ।")
def rule_5_3_64(ctx=None):
    """
    5.3.64: युवाल्पयोः कनन्यतरस्याम् ।
    """
    pass


@registry.register("5.3.65", text="विन्मतोर्लुक् ।")
def rule_5_3_65(ctx=None):
    """
    5.3.65: विन्मतोर्लुक् ।
    """
    pass


@registry.register("5.3.66", text="प्रशंसायां रूपप् ।")
def rule_5_3_66(ctx=None):
    """
    5.3.66: प्रशंसायां रूपप् ।
    """
    pass


@registry.register("5.3.67", text="ईषदसमाप्तौ कल्पब्देश्यदेशीयरः ।")
def rule_5_3_67(ctx=None):
    """
    5.3.67: ईषदसमाप्तौ कल्पब्देश्यदेशीयरः ।
    """
    pass


@registry.register("5.3.68", text="विभाषा सुपो बहुच् पुरस्तात्तु ।")
def rule_5_3_68(ctx=None):
    """
    5.3.68: विभाषा सुपो बहुच् पुरस्तात्तु ।
    """
    pass


@registry.register("5.3.69", text="प्रकारवचने जातीयर्।")
def rule_5_3_69(ctx=None):
    """
    5.3.69: प्रकारवचने जातीयर्।
    """
    pass


@registry.register("5.3.70", text="प्रागिवात्कः ।")
def rule_5_3_70(ctx=None):
    """
    5.3.70: प्रागिवात्कः ।
    """
    pass


@registry.register("5.3.71", text="अव्ययसर्वनाम्नामकच् प्राक् टेः ।")
def rule_5_3_71(ctx=None):
    """
    5.3.71: अव्ययसर्वनाम्नामकच् प्राक् टेः ।
    """
    pass


@registry.register("5.3.72", text="कस्य च दः ।")
def rule_5_3_72(ctx=None):
    """
    5.3.72: कस्य च दः ।
    """
    pass


@registry.register("5.3.73", text="अज्ञाते ।")
def rule_5_3_73(ctx=None):
    """
    5.3.73: अज्ञाते ।
    """
    pass


@registry.register("5.3.74", text="कुत्सिते ।")
def rule_5_3_74(ctx=None):
    """
    5.3.74: कुत्सिते ।
    """
    pass


@registry.register("5.3.75", text="संज्ञायां कन् ।")
def rule_5_3_75(ctx=None):
    """
    5.3.75: संज्ञायां कन् ।
    """
    pass


@registry.register("5.3.76", text="अनुकम्पायाम् ।")
def rule_5_3_76(ctx=None):
    """
    5.3.76: अनुकम्पायाम् ।
    """
    pass


@registry.register("5.3.77", text="नीतौ च तद्युक्तात् ।")
def rule_5_3_77(ctx=None):
    """
    5.3.77: नीतौ च तद्युक्तात् ।
    """
    pass


@registry.register("5.3.78", text="बह्वचो मनुष्यनाम्नष्ठज्वा ।")
def rule_5_3_78(ctx=None):
    """
    5.3.78: बह्वचो मनुष्यनाम्नष्ठज्वा ।
    """
    pass


@registry.register("5.3.79", text="घनिलचौ च ।")
def rule_5_3_79(ctx=None):
    """
    5.3.79: घनिलचौ च ।
    """
    pass


@registry.register("5.3.80", text="प्राचामुपादेरडज्वुचौ च ।")
def rule_5_3_80(ctx=None):
    """
    5.3.80: प्राचामुपादेरडज्वुचौ च ।
    """
    pass


@registry.register("5.3.81", text="जातिनाम्नः कन् ।")
def rule_5_3_81(ctx=None):
    """
    5.3.81: जातिनाम्नः कन् ।
    """
    pass


@registry.register("5.3.82", text="अजिनान्तस्योत्तरपदलोपश्च ।")
def rule_5_3_82(ctx=None):
    """
    5.3.82: अजिनान्तस्योत्तरपदलोपश्च ।
    """
    pass


@registry.register("5.3.83", text="ठाजादावूर्ध्वं द्वितीयादचः ।")
def rule_5_3_83(ctx=None):
    """
    5.3.83: ठाजादावूर्ध्वं द्वितीयादचः ।
    """
    pass


@registry.register("5.3.84", text="शेवलसुपरिविशालवरुणार्यमादीनां तृतीयात् ।")
def rule_5_3_84(ctx=None):
    """
    5.3.84: शेवलसुपरिविशालवरुणार्यमादीनां तृतीयात् ।
    """
    pass


@registry.register("5.3.85", text="अल्पे ।")
def rule_5_3_85(ctx=None):
    """
    5.3.85: अल्पे ।
    """
    pass


@registry.register("5.3.86", text="ह्रस्वे ।")
def rule_5_3_86(ctx=None):
    """
    5.3.86: ह्रस्वे ।
    """
    pass


@registry.register("5.3.87", text="संज्ञायां कन् ।")
def rule_5_3_87(ctx=None):
    """
    5.3.87: संज्ञायां कन् ।
    """
    pass


@registry.register("5.3.88", text="कुटीशमीशुण्डाभ्यो रः ।")
def rule_5_3_88(ctx=None):
    """
    5.3.88: कुटीशमीशुण्डाभ्यो रः ।
    """
    pass


@registry.register("5.3.89", text="कुत्वा डुपच् ।")
def rule_5_3_89(ctx=None):
    """
    5.3.89: कुत्वा डुपच् ।
    """
    pass


@registry.register("5.3.90", text="कासूगोणीभ्यां ष्टरच् ।")
def rule_5_3_90(ctx=None):
    """
    5.3.90: कासूगोणीभ्यां ष्टरच् ।
    """
    pass


@registry.register("5.3.91", text="वत्सोक्षाश्वर्षभेभ्यश्च तनुत्वे ।")
def rule_5_3_91(ctx=None):
    """
    5.3.91: वत्सोक्षाश्वर्षभेभ्यश्च तनुत्वे ।
    """
    pass


@registry.register("5.3.92", text="किंयत्तदो निर्द्धारणे द्वयोरेकस्य डतरच् ।")
def rule_5_3_92(ctx=None):
    """
    5.3.92: किंयत्तदो निर्द्धारणे द्वयोरेकस्य डतरच् ।
    """
    pass


@registry.register("5.3.93", text="वा बहूनां जातिपरिप्रश्ने डतमच् ।")
def rule_5_3_93(ctx=None):
    """
    5.3.93: वा बहूनां जातिपरिप्रश्ने डतमच् ।
    """
    pass


@registry.register("5.3.94", text="एकाच्च प्राचाम् ।")
def rule_5_3_94(ctx=None):
    """
    5.3.94: एकाच्च प्राचाम् ।
    """
    pass


@registry.register("5.3.95", text="अवक्षेपणे कन् ।")
def rule_5_3_95(ctx=None):
    """
    5.3.95: अवक्षेपणे कन् ।
    """
    pass


@registry.register("5.3.96", text="इवे प्रतिकृतौ ।")
def rule_5_3_96(ctx=None):
    """
    5.3.96: इवे प्रतिकृतौ ।
    """
    pass


@registry.register("5.3.97", text="संज्ञायां च ।")
def rule_5_3_97(ctx=None):
    """
    5.3.97: संज्ञायां च ।
    """
    pass


@registry.register("5.3.98", text="लुम्मनुष्ये ।")
def rule_5_3_98(ctx=None):
    """
    5.3.98: लुम्मनुष्ये ।
    """
    pass


@registry.register("5.3.99", text="जीविकाऽर्थे चापण्ये ।")
def rule_5_3_99(ctx=None):
    """
    5.3.99: जीविकाऽर्थे चापण्ये ।
    """
    pass


@registry.register("5.3.100", text="देवपथादिभ्यश्च ।")
def rule_5_3_100(ctx=None):
    """
    5.3.100: देवपथादिभ्यश्च ।
    """
    pass


@registry.register("5.3.101", text="वस्तेर्ढञ् ।")
def rule_5_3_101(ctx=None):
    """
    5.3.101: वस्तेर्ढञ् ।
    """
    pass


@registry.register("5.3.102", text="शिलाया ढः ।")
def rule_5_3_102(ctx=None):
    """
    5.3.102: शिलाया ढः ।
    """
    pass


@registry.register("5.3.103", text="शाखाऽऽदिभ्यो यत् ।")
def rule_5_3_103(ctx=None):
    """
    5.3.103: शाखाऽऽदिभ्यो यत् ।
    """
    pass


@registry.register("5.3.104", text="द्रव्यं च भव्ये ।")
def rule_5_3_104(ctx=None):
    """
    5.3.104: द्रव्यं च भव्ये ।
    """
    pass


@registry.register("5.3.105", text="कुशाग्राच्छः ।")
def rule_5_3_105(ctx=None):
    """
    5.3.105: कुशाग्राच्छः ।
    """
    pass


@registry.register("5.3.106", text="समासाच्च तद्विषयात् ।")
def rule_5_3_106(ctx=None):
    """
    5.3.106: समासाच्च तद्विषयात् ।
    """
    pass


@registry.register("5.3.107", text="शर्कराऽऽदिभ्योऽण् ।")
def rule_5_3_107(ctx=None):
    """
    5.3.107: शर्कराऽऽदिभ्योऽण् ।
    """
    pass


@registry.register("5.3.108", text="अङ्गुल्यादिभ्यष्ठक् ।")
def rule_5_3_108(ctx=None):
    """
    5.3.108: अङ्गुल्यादिभ्यष्ठक् ।
    """
    pass


@registry.register("5.3.109", text="एकशालायाष्ठजन्यतरस्याम् ।")
def rule_5_3_109(ctx=None):
    """
    5.3.109: एकशालायाष्ठजन्यतरस्याम् ।
    """
    pass


@registry.register("5.3.110", text="कर्कलोहितादीकक् ।")
def rule_5_3_110(ctx=None):
    """
    5.3.110: कर्कलोहितादीकक् ।
    """
    pass


@registry.register("5.3.111", text="प्रत्नपूर्वविश्वेमात्थाल् छन्दसि ।")
def rule_5_3_111(ctx=None):
    """
    5.3.111: प्रत्नपूर्वविश्वेमात्थाल् छन्दसि ।
    """
    pass


@registry.register("5.3.112", text="पूगाञ्ज्योऽग्रामणीपूर्वात् ।")
def rule_5_3_112(ctx=None):
    """
    5.3.112: पूगाञ्ज्योऽग्रामणीपूर्वात् ।
    """
    pass


@registry.register("5.3.113", text="व्रातच्फञोरस्त्रियाम् ।")
def rule_5_3_113(ctx=None):
    """
    5.3.113: व्रातच्फञोरस्त्रियाम् ।
    """
    pass


@registry.register("5.3.114", text="आयुधजीविसंघाञ्यवाहीकेष्वब्राह्मणराजन्यात् ।")
def rule_5_3_114(ctx=None):
    """
    5.3.114: आयुधजीविसंघाञ्यवाहीकेष्वब्राह्मणराजन्यात् ।
    """
    pass


@registry.register("5.3.115", text="वृकाट्टेण्यण् ।")
def rule_5_3_115(ctx=None):
    """
    5.3.115: वृकाट्टेण्यण् ।
    """
    pass


@registry.register("5.3.116", text="दामन्यादित्रिगर्तषष्ठाच्छः ।")
def rule_5_3_116(ctx=None):
    """
    5.3.116: दामन्यादित्रिगर्तषष्ठाच्छः ।
    """
    pass


@registry.register("5.3.117", text="पश्वदियौधेयादिभ्यामणौ ।")
def rule_5_3_117(ctx=None):
    """
    5.3.117: पश्वदियौधेयादिभ्यामणौ ।
    """
    pass


@registry.register("5.3.118", text="अभिजिद्विदभृच्छालावच्छिखावच्छमीवदूर्णावच्छ्रुमदणो यञ् ।")
def rule_5_3_118(ctx=None):
    """
    5.3.118: अभिजिद्विदभृच्छालावच्छिखावच्छमीवदूर्णावच्छ्रुमदणो यञ् ।
    """
    pass


@registry.register("5.3.119", text="ज्यादयस्तद्राजाः ।")
def rule_5_3_119(ctx=None):
    """
    5.3.119: ज्यादयस्तद्राजाः ।
    """
    pass


@registry.register("5.4.1", text="पादशतस्य संख्याऽऽदेर्वीप्सायां वुन् लोपश्च ।")
def rule_5_4_1(ctx=None):
    """
    5.4.1: पादशतस्य संख्याऽऽदेर्वीप्सायां वुन् लोपश्च ।
    """
    pass


@registry.register("5.4.2", text="दण्डव्यवसर्गयोश्च ।")
def rule_5_4_2(ctx=None):
    """
    5.4.2: दण्डव्यवसर्गयोश्च ।
    """
    pass


@registry.register("5.4.3", text="स्थूलादिभ्यः प्रकारवचने कन् ।")
def rule_5_4_3(ctx=None):
    """
    5.4.3: स्थूलादिभ्यः प्रकारवचने कन् ।
    """
    pass


@registry.register("5.4.4", text="अनत्यन्तगतौ क्तात् ।")
def rule_5_4_4(ctx=None):
    """
    5.4.4: अनत्यन्तगतौ क्तात् ।
    """
    pass


@registry.register("5.4.5", text="न सामिवचने ।")
def rule_5_4_5(ctx=None):
    """
    5.4.5: न सामिवचने ।
    """
    pass


@registry.register("5.4.6", text="बृहत्या आच्छादने ।")
def rule_5_4_6(ctx=None):
    """
    5.4.6: बृहत्या आच्छादने ।
    """
    pass


@registry.register("5.4.7", text="अषडक्षाशितङ्घलंकर्मालम्पुरुषाध्युत्तरपदात् खः ।")
def rule_5_4_7(ctx=None):
    """
    5.4.7: अषडक्षाशितङ्घलंकर्मालम्पुरुषाध्युत्तरपदात् खः ।
    """
    pass


@registry.register("5.4.8", text="विभाषा अञ्चरदिक्त्रियाम् ।")
def rule_5_4_8(ctx=None):
    """
    5.4.8: विभाषा अञ्चरदिक्त्रियाम् ।
    """
    pass


@registry.register("5.4.9", text="जात्यन्ताच्छ बन्धुनि ।")
def rule_5_4_9(ctx=None):
    """
    5.4.9: जात्यन्ताच्छ बन्धुनि ।
    """
    pass


@registry.register("5.4.10", text="स्थानान्ताद्विभाषा सस्थानेनेति चेत् ।")
def rule_5_4_10(ctx=None):
    """
    5.4.10: स्थानान्ताद्विभाषा सस्थानेनेति चेत् ।
    """
    pass


@registry.register("5.4.11", text="किमेत्तिङव्ययघादाम्वद्रव्यप्रकर्षे ।")
def rule_5_4_11(ctx=None):
    """
    5.4.11: किमेत्तिङव्ययघादाम्वद्रव्यप्रकर्षे ।
    """
    pass


@registry.register("5.4.12", text="अमु च च्छन्दसि ।")
def rule_5_4_12(ctx=None):
    """
    5.4.12: अमु च च्छन्दसि ।
    """
    pass


@registry.register("5.4.13", text="अनुगादिनष्ठक् ।")
def rule_5_4_13(ctx=None):
    """
    5.4.13: अनुगादिनष्ठक् ।
    """
    pass


@registry.register("5.4.14", text="णचः स्त्रियामञ् ।")
def rule_5_4_14(ctx=None):
    """
    5.4.14: णचः स्त्रियामञ् ।
    """
    pass


@registry.register("5.4.15", text="अणिनुणः ।")
def rule_5_4_15(ctx=None):
    """
    5.4.15: अणिनुणः ।
    """
    pass


@registry.register("5.4.16", text="विसारिणो मत्स्ये ।")
def rule_5_4_16(ctx=None):
    """
    5.4.16: विसारिणो मत्स्ये ।
    """
    pass


@registry.register("5.4.17", text="संख्यायाः क्रियाऽभ्यावृत्तिगणने कृत्वसुच् ।")
def rule_5_4_17(ctx=None):
    """
    5.4.17: संख्यायाः क्रियाऽभ्यावृत्तिगणने कृत्वसुच् ।
    """
    pass


@registry.register("5.4.18", text="द्वित्रिचतुर्थ्यः सुच् ।")
def rule_5_4_18(ctx=None):
    """
    5.4.18: द्वित्रिचतुर्थ्यः सुच् ।
    """
    pass


@registry.register("5.4.19", text="एकस्य सकृच्च ।")
def rule_5_4_19(ctx=None):
    """
    5.4.19: एकस्य सकृच्च ।
    """
    pass


@registry.register("5.4.20", text="विभाषा बहोर्धाऽविप्रकृष्टकाले ।")
def rule_5_4_20(ctx=None):
    """
    5.4.20: विभाषा बहोर्धाऽविप्रकृष्टकाले ।
    """
    pass


@registry.register("5.4.21", text="तत्प्रकृतवचने मयट् ।")
def rule_5_4_21(ctx=None):
    """
    5.4.21: तत्प्रकृतवचने मयट् ।
    """
    pass


@registry.register("5.4.22", text="समूहवच्च बहुषु ।")
def rule_5_4_22(ctx=None):
    """
    5.4.22: समूहवच्च बहुषु ।
    """
    pass


@registry.register("5.4.23", text="अनन्तावसथेतिहभेषजाञ्यः ।")
def rule_5_4_23(ctx=None):
    """
    5.4.23: अनन्तावसथेतिहभेषजाञ्यः ।
    """
    pass


@registry.register("5.4.24", text="देवतान्तात्तादर्थ्य यत् ।")
def rule_5_4_24(ctx=None):
    """
    5.4.24: देवतान्तात्तादर्थ्य यत् ।
    """
    pass


@registry.register("5.4.25", text="पादार्घाभ्यां च ।")
def rule_5_4_25(ctx=None):
    """
    5.4.25: पादार्घाभ्यां च ।
    """
    pass


@registry.register("5.4.26", text="अतिथेर्ज्यः ।")
def rule_5_4_26(ctx=None):
    """
    5.4.26: अतिथेर्ज्यः ।
    """
    pass


@registry.register("5.4.27", text="देवात्तल् ।")
def rule_5_4_27(ctx=None):
    """
    5.4.27: देवात्तल् ।
    """
    pass


@registry.register("5.4.28", text="अवेः कः ।")
def rule_5_4_28(ctx=None):
    """
    5.4.28: अवेः कः ।
    """
    pass


@registry.register("5.4.29", text="यावादिभ्यः कन् ।")
def rule_5_4_29(ctx=None):
    """
    5.4.29: यावादिभ्यः कन् ।
    """
    pass


@registry.register("5.4.30", text="लोहितान्मणौ ।")
def rule_5_4_30(ctx=None):
    """
    5.4.30: लोहितान्मणौ ।
    """
    pass


@registry.register("5.4.31", text="वर्णे चानित्ये ।")
def rule_5_4_31(ctx=None):
    """
    5.4.31: वर्णे चानित्ये ।
    """
    pass


@registry.register("5.4.32", text="रक्ते ।")
def rule_5_4_32(ctx=None):
    """
    5.4.32: रक्ते ।
    """
    pass


@registry.register("5.4.33", text="कालाच्च ।")
def rule_5_4_33(ctx=None):
    """
    5.4.33: कालाच्च ।
    """
    pass


@registry.register("5.4.34", text="विनयादिभ्यष्ठक् ।")
def rule_5_4_34(ctx=None):
    """
    5.4.34: विनयादिभ्यष्ठक् ।
    """
    pass


@registry.register("5.4.35", text="वाचो व्याहृतार्थायाम् ।")
def rule_5_4_35(ctx=None):
    """
    5.4.35: वाचो व्याहृतार्थायाम् ।
    """
    pass


@registry.register("5.4.36", text="तद्युक्तात् कर्मणोऽण् ।")
def rule_5_4_36(ctx=None):
    """
    5.4.36: तद्युक्तात् कर्मणोऽण् ।
    """
    pass


@registry.register("5.4.37", text="ओषधेरजातौ ।")
def rule_5_4_37(ctx=None):
    """
    5.4.37: ओषधेरजातौ ।
    """
    pass


@registry.register("5.4.38", text="प्रज्ञादिभ्यश्च ।")
def rule_5_4_38(ctx=None):
    """
    5.4.38: प्रज्ञादिभ्यश्च ।
    """
    pass


@registry.register("5.4.39", text="मृदस्तिकन् ।")
def rule_5_4_39(ctx=None):
    """
    5.4.39: मृदस्तिकन् ।
    """
    pass


@registry.register("5.4.40", text="सस्त्रौ प्रशंसायाम् ।")
def rule_5_4_40(ctx=None):
    """
    5.4.40: सस्त्रौ प्रशंसायाम् ।
    """
    pass


@registry.register("5.4.41", text="वृकज्येष्ठाभ्यां तिल्तातिलौ च च्छन्दसि ।")
def rule_5_4_41(ctx=None):
    """
    5.4.41: वृकज्येष्ठाभ्यां तिल्तातिलौ च च्छन्दसि ।
    """
    pass


@registry.register("5.4.42", text="बह्वल्पार्थाच्छस् कारकादन्यतरस्याम् ।")
def rule_5_4_42(ctx=None):
    """
    5.4.42: बह्वल्पार्थाच्छस् कारकादन्यतरस्याम् ।
    """
    pass


@registry.register("5.4.43", text="संख्यैकवचनाच्च वीप्सायाम् ।")
def rule_5_4_43(ctx=None):
    """
    5.4.43: संख्यैकवचनाच्च वीप्सायाम् ।
    """
    pass


@registry.register("5.4.44", text="प्रतियोगे पञ्चम्यास्तसिः ।")
def rule_5_4_44(ctx=None):
    """
    5.4.44: प्रतियोगे पञ्चम्यास्तसिः ।
    """
    pass


@registry.register("5.4.45", text="अपादाने चाहीयरुहोः ।")
def rule_5_4_45(ctx=None):
    """
    5.4.45: अपादाने चाहीयरुहोः ।
    """
    pass


@registry.register("5.4.46", text="अतिग्रहाव्यथनक्षेपेष्वकर्तरि तृतीयायाः ।")
def rule_5_4_46(ctx=None):
    """
    5.4.46: अतिग्रहाव्यथनक्षेपेष्वकर्तरि तृतीयायाः ।
    """
    pass


@registry.register("5.4.47", text="हीयमानपापयोगाच्च ।")
def rule_5_4_47(ctx=None):
    """
    5.4.47: हीयमानपापयोगाच्च ।
    """
    pass


@registry.register("5.4.48", text="षष्ठ्ठ्या व्याश्रये ।")
def rule_5_4_48(ctx=None):
    """
    5.4.48: षष्ठ्ठ्या व्याश्रये ।
    """
    pass


@registry.register("5.4.49", text="रोगाच्चापनयने ।")
def rule_5_4_49(ctx=None):
    """
    5.4.49: रोगाच्चापनयने ।
    """
    pass


@registry.register("5.4.50", text="अभूततद्भावे कृभ्वस्तियोगे सम्पद्यकर्तरि च्चिः ।")
def rule_5_4_50(ctx=None):
    """
    5.4.50: अभूततद्भावे कृभ्वस्तियोगे सम्पद्यकर्तरि च्चिः ।
    """
    pass


@registry.register("5.4.51", text="अरुर्मनश्चक्षुश्चेतोरहोरजसां लोपश्च ।")
def rule_5_4_51(ctx=None):
    """
    5.4.51: अरुर्मनश्चक्षुश्चेतोरहोरजसां लोपश्च ।
    """
    pass


@registry.register("5.4.52", text="विभाषा साति कार्ये ।")
def rule_5_4_52(ctx=None):
    """
    5.4.52: विभाषा साति कार्ये ।
    """
    pass


@registry.register("5.4.53", text="अभिविधौ सम्पदा च ।")
def rule_5_4_53(ctx=None):
    """
    5.4.53: अभिविधौ सम्पदा च ।
    """
    pass


@registry.register("5.4.54", text="तदधीनवचने ।")
def rule_5_4_54(ctx=None):
    """
    5.4.54: तदधीनवचने ।
    """
    pass


@registry.register("5.4.55", text="देये त्रा च ।")
def rule_5_4_55(ctx=None):
    """
    5.4.55: देये त्रा च ।
    """
    pass


@registry.register("5.4.56", text="देवमनुष्यपुरुषमर्त्यभ्यो द्वितीयासप्तम्योर्बहुलम् ।")
def rule_5_4_56(ctx=None):
    """
    5.4.56: देवमनुष्यपुरुषमर्त्यभ्यो द्वितीयासप्तम्योर्बहुलम् ।
    """
    pass


@registry.register("5.4.57", text="अव्यक्तानुकरणाह्मजवरार्धादनितौ डाच् ।")
def rule_5_4_57(ctx=None):
    """
    5.4.57: अव्यक्तानुकरणाह्मजवरार्धादनितौ डाच् ।
    """
    pass


@registry.register("5.4.58", text="कृञो द्वितीयतृतीयशम्बबीजात् कृषौ ।")
def rule_5_4_58(ctx=None):
    """
    5.4.58: कृञो द्वितीयतृतीयशम्बबीजात् कृषौ ।
    """
    pass


@registry.register("5.4.59", text="संख्यायाश्च गुणान्तायाः ।")
def rule_5_4_59(ctx=None):
    """
    5.4.59: संख्यायाश्च गुणान्तायाः ।
    """
    pass


@registry.register("5.4.60", text="समयाच्च यापनायाम् ।")
def rule_5_4_60(ctx=None):
    """
    5.4.60: समयाच्च यापनायाम् ।
    """
    pass


@registry.register("5.4.61", text="सपत्रनिष्पत्रादतिव्यथने ।")
def rule_5_4_61(ctx=None):
    """
    5.4.61: सपत्रनिष्पत्रादतिव्यथने ।
    """
    pass


@registry.register("5.4.62", text="निष्कुलान्निष्कोषणे ।")
def rule_5_4_62(ctx=None):
    """
    5.4.62: निष्कुलान्निष्कोषणे ।
    """
    pass


@registry.register("5.4.63", text="सुखप्रियादानुलोम्ये ।")
def rule_5_4_63(ctx=None):
    """
    5.4.63: सुखप्रियादानुलोम्ये ।
    """
    pass


@registry.register("5.4.64", text="दुःखात् प्रातिलोम्ये ।")
def rule_5_4_64(ctx=None):
    """
    5.4.64: दुःखात् प्रातिलोम्ये ।
    """
    pass


@registry.register("5.4.65", text="शूलात् पाके ।")
def rule_5_4_65(ctx=None):
    """
    5.4.65: शूलात् पाके ।
    """
    pass


@registry.register("5.4.66", text="सत्यादशपथे ।")
def rule_5_4_66(ctx=None):
    """
    5.4.66: सत्यादशपथे ।
    """
    pass


@registry.register("5.4.67", text="मद्रात् परिवापणे ।")
def rule_5_4_67(ctx=None):
    """
    5.4.67: मद्रात् परिवापणे ।
    """
    pass


@registry.register("5.4.68", text="समासान्ताः ।")
def rule_5_4_68(ctx=None):
    """
    5.4.68: समासान्ताः ।
    """
    pass


@registry.register("5.4.69", text="न पूजनात् ।")
def rule_5_4_69(ctx=None):
    """
    5.4.69: न पूजनात् ।
    """
    pass


@registry.register("5.4.70", text="किमः क्षेपे ।")
def rule_5_4_70(ctx=None):
    """
    5.4.70: किमः क्षेपे ।
    """
    pass


@registry.register("5.4.71", text="नञस्तत्पुरुषात् ।")
def rule_5_4_71(ctx=None):
    """
    5.4.71: नञस्तत्पुरुषात् ।
    """
    pass


@registry.register("5.4.72", text="पथो विभाषा ।")
def rule_5_4_72(ctx=None):
    """
    5.4.72: पथो विभाषा ।
    """
    pass


@registry.register("5.4.73", text="बहुव्रीहौ संख्येये डजबहुगणात् ।")
def rule_5_4_73(ctx=None):
    """
    5.4.73: बहुव्रीहौ संख्येये डजबहुगणात् ।
    """
    pass


@registry.register("5.4.74", text="ऋक्पूरप्धूःपथामानक्षे ।")
def rule_5_4_74(ctx=None):
    """
    5.4.74: ऋक्पूरप्धूःपथामानक्षे ।
    """
    pass


@registry.register("5.4.75", text="अच् प्रत्यन्ववपूर्वात् सामलोम्नः ।")
def rule_5_4_75(ctx=None):
    """
    5.4.75: अच् प्रत्यन्ववपूर्वात् सामलोम्नः ।
    """
    pass


@registry.register("5.4.76", text="अक्ष्णोऽदर्शनात् ।")
def rule_5_4_76(ctx=None):
    """
    5.4.76: अक्ष्णोऽदर्शनात् ।
    """
    pass


@registry.register("5.4.77", text="अचतुरविचतुरसुचतुरस्त्रीपुंसधेन्वनडुहर्सामवाङ्गनसाक्षिभ्रुवदारगवोर्वष्ठीवपदष्ठीवनक्तंदिवरत्रिंदिवाहर्दिवसरजसनिःश्रेयसपुरुषायुषद्व्यायुषत्र्यायुषर्ग्यजुषजातोक्षमहोक्षवृद्धोक्षोपशुनगोष्ठश्वाः")
def rule_5_4_77(ctx=None):
    """
    5.4.77: अचतुरविचतुरसुचतुरस्त्रीपुंसधेन्वनडुहर्सामवाङ्गनसाक्षिभ्रुवदारगवोर्वष्ठीवपदष्ठीवनक्तंदिवरत्रिंदिवाहर्दिवसरजसनिःश्रेयसपुरुषायुषद्व्यायुषत्र्यायुषर्ग्यजुषजातोक्षमहोक्षवृद्धोक्षोपशुनगोष्ठश्वाः
    """
    pass


@registry.register("5.4.78", text="ब्रह्महस्तिभ्याम् वर्चसः ।")
def rule_5_4_78(ctx=None):
    """
    5.4.78: ब्रह्महस्तिभ्याम् वर्चसः ।
    """
    pass


@registry.register("5.4.79", text="अवसमन्धेभ्यस्तमसः ।")
def rule_5_4_79(ctx=None):
    """
    5.4.79: अवसमन्धेभ्यस्तमसः ।
    """
    pass


@registry.register("5.4.80", text="श्वसो वसीयःश्रेयसः ।")
def rule_5_4_80(ctx=None):
    """
    5.4.80: श्वसो वसीयःश्रेयसः ।
    """
    pass


@registry.register("5.4.81", text="अन्ववतप्ताद्रहसः ।")
def rule_5_4_81(ctx=None):
    """
    5.4.81: अन्ववतप्ताद्रहसः ।
    """
    pass


@registry.register("5.4.82", text="प्रतेरुरसः सप्तमीस्थात् ।")
def rule_5_4_82(ctx=None):
    """
    5.4.82: प्रतेरुरसः सप्तमीस्थात् ।
    """
    pass


@registry.register("5.4.83", text="अनुगवमायामे ।")
def rule_5_4_83(ctx=None):
    """
    5.4.83: अनुगवमायामे ।
    """
    pass


@registry.register("5.4.84", text="द्विस्तावा त्रिस्तावा वेदिः ।")
def rule_5_4_84(ctx=None):
    """
    5.4.84: द्विस्तावा त्रिस्तावा वेदिः ।
    """
    pass


@registry.register("5.4.85", text="उपसर्गादध्वनः ।")
def rule_5_4_85(ctx=None):
    """
    5.4.85: उपसर्गादध्वनः ।
    """
    pass


@registry.register("5.4.86", text="तत्पुरुषस्याङ्गुलेः संख्याऽव्ययादेः ।")
def rule_5_4_86(ctx=None):
    """
    5.4.86: तत्पुरुषस्याङ्गुलेः संख्याऽव्ययादेः ।
    """
    pass


@registry.register("5.4.87", text="अहस्सर्वैकदेशसंख्यातपुण्याच्च रात्रेः ।")
def rule_5_4_87(ctx=None):
    """
    5.4.87: अहस्सर्वैकदेशसंख्यातपुण्याच्च रात्रेः ।
    """
    pass


@registry.register("5.4.88", text="अह्रोऽह्न एतेभ्यः ।")
def rule_5_4_88(ctx=None):
    """
    5.4.88: अह्रोऽह्न एतेभ्यः ।
    """
    pass


@registry.register("5.4.89", text="न संख्याऽऽदेः समाहारे ।")
def rule_5_4_89(ctx=None):
    """
    5.4.89: न संख्याऽऽदेः समाहारे ।
    """
    pass


@registry.register("5.4.90", text="उत्तमैकाभ्यां च ।")
def rule_5_4_90(ctx=None):
    """
    5.4.90: उत्तमैकाभ्यां च ।
    """
    pass


@registry.register("5.4.91", text="राजाऽहस्सखिभ्यष्टच् ।")
def rule_5_4_91(ctx=None):
    """
    5.4.91: राजाऽहस्सखिभ्यष्टच् ।
    """
    pass


@registry.register("5.4.92", text="गोरतद्धितलुकि ।")
def rule_5_4_92(ctx=None):
    """
    5.4.92: गोरतद्धितलुकि ।
    """
    pass


@registry.register("5.4.93", text="अग्राख्यायामुरसः ।")
def rule_5_4_93(ctx=None):
    """
    5.4.93: अग्राख्यायामुरसः ।
    """
    pass


@registry.register("5.4.94", text="अनोऽश्मायस्सरसाम् जातिसंज्ञयोः ।")
def rule_5_4_94(ctx=None):
    """
    5.4.94: अनोऽश्मायस्सरसाम् जातिसंज्ञयोः ।
    """
    pass


@registry.register("5.4.95", text="ग्रामकौटाभ्यां च तक्ष्णः ।")
def rule_5_4_95(ctx=None):
    """
    5.4.95: ग्रामकौटाभ्यां च तक्ष्णः ।
    """
    pass


@registry.register("5.4.96", text="अतेः शुनः ।")
def rule_5_4_96(ctx=None):
    """
    5.4.96: अतेः शुनः ।
    """
    pass


@registry.register("5.4.97", text="उपमानादप्राणिषु ।")
def rule_5_4_97(ctx=None):
    """
    5.4.97: उपमानादप्राणिषु ।
    """
    pass


@registry.register("5.4.98", text="उत्तरमृगपूर्वाच्च सक्नः ।")
def rule_5_4_98(ctx=None):
    """
    5.4.98: उत्तरमृगपूर्वाच्च सक्नः ।
    """
    pass


@registry.register("5.4.99", text="नावो द्विगोः ।")
def rule_5_4_99(ctx=None):
    """
    5.4.99: नावो द्विगोः ।
    """
    pass


@registry.register("5.4.100", text="अर्धाच्च ।")
def rule_5_4_100(ctx=None):
    """
    5.4.100: अर्धाच्च ।
    """
    pass


@registry.register("5.4.101", text="खार्याः प्राचाम् ।")
def rule_5_4_101(ctx=None):
    """
    5.4.101: खार्याः प्राचाम् ।
    """
    pass


@registry.register("5.4.102", text="द्वित्रिभ्यामञ्जलेः ।")
def rule_5_4_102(ctx=None):
    """
    5.4.102: द्वित्रिभ्यामञ्जलेः ।
    """
    pass


@registry.register("5.4.103", text="अनसन्तान्नपुंसकाच्छन्दसि ।")
def rule_5_4_103(ctx=None):
    """
    5.4.103: अनसन्तान्नपुंसकाच्छन्दसि ।
    """
    pass


@registry.register("5.4.104", text="ब्रह्मणो जानपदाख्यायाम् ।")
def rule_5_4_104(ctx=None):
    """
    5.4.104: ब्रह्मणो जानपदाख्यायाम् ।
    """
    pass


@registry.register("5.4.105", text="कुमहद्भ्यामन्यतरस्याम् ।")
def rule_5_4_105(ctx=None):
    """
    5.4.105: कुमहद्भ्यामन्यतरस्याम् ।
    """
    pass


@registry.register("5.4.106", text="द्वंद्वाच्चुदषहान्तात् समाहारे ।")
def rule_5_4_106(ctx=None):
    """
    5.4.106: द्वंद्वाच्चुदषहान्तात् समाहारे ।
    """
    pass


@registry.register("5.4.107", text="अव्ययीभावे शरत्प्रभृतिभ्यः ।")
def rule_5_4_107(ctx=None):
    """
    5.4.107: अव्ययीभावे शरत्प्रभृतिभ्यः ।
    """
    pass


@registry.register("5.4.108", text="अनश्च ।")
def rule_5_4_108(ctx=None):
    """
    5.4.108: अनश्च ।
    """
    pass


@registry.register("5.4.109", text="नपुंसकादन्यतरस्याम् ।")
def rule_5_4_109(ctx=None):
    """
    5.4.109: नपुंसकादन्यतरस्याम् ।
    """
    pass


@registry.register("5.4.110", text="नदीपौर्णमास्याग्रहायणीभ्यः ।")
def rule_5_4_110(ctx=None):
    """
    5.4.110: नदीपौर्णमास्याग्रहायणीभ्यः ।
    """
    pass


@registry.register("5.4.111", text="झयः ।")
def rule_5_4_111(ctx=None):
    """
    5.4.111: झयः ।
    """
    pass


@registry.register("5.4.112", text="गिरेश्च सेनकस्य ।")
def rule_5_4_112(ctx=None):
    """
    5.4.112: गिरेश्च सेनकस्य ।
    """
    pass


@registry.register("5.4.113", text="बहुव्रीहौ सक्थ्यक्ष्णोः स्वाङ्गात् षच् ।")
def rule_5_4_113(ctx=None):
    """
    5.4.113: बहुव्रीहौ सक्थ्यक्ष्णोः स्वाङ्गात् षच् ।
    """
    pass


@registry.register("5.4.114", text="अङ्गुलेर्दारुणि ।")
def rule_5_4_114(ctx=None):
    """
    5.4.114: अङ्गुलेर्दारुणि ।
    """
    pass


@registry.register("5.4.115", text="द्वित्रिभ्यां ष मूर्ध्नः ।")
def rule_5_4_115(ctx=None):
    """
    5.4.115: द्वित्रिभ्यां ष मूर्ध्नः ।
    """
    pass


@registry.register("5.4.116", text="अप् पूरणीप्रमाण्योः ।")
def rule_5_4_116(ctx=None):
    """
    5.4.116: अप् पूरणीप्रमाण्योः ।
    """
    pass


@registry.register("5.4.117", text="अन्तर्बहिर्त्यां च लोम्नः ।")
def rule_5_4_117(ctx=None):
    """
    5.4.117: अन्तर्बहिर्त्यां च लोम्नः ।
    """
    pass


@registry.register("5.4.118", text="अञ्न्नासिकायाः संज्ञायां नसं चास्थूलात् ।")
def rule_5_4_118(ctx=None):
    """
    5.4.118: अञ्न्नासिकायाः संज्ञायां नसं चास्थूलात् ।
    """
    pass


@registry.register("5.4.119", text="उपसर्गाच्च ।")
def rule_5_4_119(ctx=None):
    """
    5.4.119: उपसर्गाच्च ।
    """
    pass


@registry.register("5.4.120", text="सुप्रातसुश्वसुदिवशारिकुक्षचतुरश्रेणीपदाजपदप्रोष्ठपदाः ।")
def rule_5_4_120(ctx=None):
    """
    5.4.120: सुप्रातसुश्वसुदिवशारिकुक्षचतुरश्रेणीपदाजपदप्रोष्ठपदाः ।
    """
    pass


@registry.register("5.4.121", text="नञ्दुःसुभ्यो हलिसक्थ्योरन्यतरस्याम् ।")
def rule_5_4_121(ctx=None):
    """
    5.4.121: नञ्दुःसुभ्यो हलिसक्थ्योरन्यतरस्याम् ।
    """
    pass


@registry.register("5.4.122", text="नित्यमसिच् प्रजामेधयोः ।")
def rule_5_4_122(ctx=None):
    """
    5.4.122: नित्यमसिच् प्रजामेधयोः ।
    """
    pass


@registry.register("5.4.123", text="बहुप्रजाश्छन्दसि ।")
def rule_5_4_123(ctx=None):
    """
    5.4.123: बहुप्रजाश्छन्दसि ।
    """
    pass


@registry.register("5.4.124", text="धर्मादनिच् केवलात् ।")
def rule_5_4_124(ctx=None):
    """
    5.4.124: धर्मादनिच् केवलात् ।
    """
    pass


@registry.register("5.4.125", text="जम्भा सुहरिततृणसोमेभ्यः ।")
def rule_5_4_125(ctx=None):
    """
    5.4.125: जम्भा सुहरिततृणसोमेभ्यः ।
    """
    pass


@registry.register("5.4.126", text="दक्षिणेर्मा लुब्धयोगे ।")
def rule_5_4_126(ctx=None):
    """
    5.4.126: दक्षिणेर्मा लुब्धयोगे ।
    """
    pass


@registry.register("5.4.127", text="इच् कर्मव्यतिहारे ।")
def rule_5_4_127(ctx=None):
    """
    5.4.127: इच् कर्मव्यतिहारे ।
    """
    pass


@registry.register("5.4.128", text="द्विदण्डयादिभ्यश्च ।")
def rule_5_4_128(ctx=None):
    """
    5.4.128: द्विदण्डयादिभ्यश्च ।
    """
    pass


@registry.register("5.4.129", text="प्रसम्भ्यां जानुनोर्जुः ।")
def rule_5_4_129(ctx=None):
    """
    5.4.129: प्रसम्भ्यां जानुनोर्जुः ।
    """
    pass


@registry.register("5.4.130", text="ऊर्ध्वाद्विभाषा ।")
def rule_5_4_130(ctx=None):
    """
    5.4.130: ऊर्ध्वाद्विभाषा ।
    """
    pass


@registry.register("5.4.131", text="ऊधसोऽनङ् ।")
def rule_5_4_131(ctx=None):
    """
    5.4.131: ऊधसोऽनङ् ।
    """
    pass


@registry.register("5.4.132", text="धनुषश्च ।")
def rule_5_4_132(ctx=None):
    """
    5.4.132: धनुषश्च ।
    """
    pass


@registry.register("5.4.133", text="वा संज्ञायाम् ।")
def rule_5_4_133(ctx=None):
    """
    5.4.133: वा संज्ञायाम् ।
    """
    pass


@registry.register("5.4.134", text="जायाया निङ् ।")
def rule_5_4_134(ctx=None):
    """
    5.4.134: जायाया निङ् ।
    """
    pass


@registry.register("5.4.135", text="गन्धस्येदुत्पूतिसुसुरभिभ्यः ।")
def rule_5_4_135(ctx=None):
    """
    5.4.135: गन्धस्येदुत्पूतिसुसुरभिभ्यः ।
    """
    pass


@registry.register("5.4.136", text="अल्पाख्यायाम् ।")
def rule_5_4_136(ctx=None):
    """
    5.4.136: अल्पाख्यायाम् ।
    """
    pass


@registry.register("5.4.137", text="उपमानाच्च ।")
def rule_5_4_137(ctx=None):
    """
    5.4.137: उपमानाच्च ।
    """
    pass


@registry.register("5.4.138", text="पादस्य लोपोऽहस्त्यादिभ्यः ।")
def rule_5_4_138(ctx=None):
    """
    5.4.138: पादस्य लोपोऽहस्त्यादिभ्यः ।
    """
    pass


@registry.register("5.4.139", text="कुम्भपदीषु च ।")
def rule_5_4_139(ctx=None):
    """
    5.4.139: कुम्भपदीषु च ।
    """
    pass


@registry.register("5.4.140", text="संख्यासुपूर्वस्य ।")
def rule_5_4_140(ctx=None):
    """
    5.4.140: संख्यासुपूर्वस्य ।
    """
    pass


@registry.register("5.4.141", text="वयसि दन्तस्य दतृ ।")
def rule_5_4_141(ctx=None):
    """
    5.4.141: वयसि दन्तस्य दतृ ।
    """
    pass


@registry.register("5.4.142", text="छन्दसि च ।")
def rule_5_4_142(ctx=None):
    """
    5.4.142: छन्दसि च ।
    """
    pass


@registry.register("5.4.143", text="स्त्रियां संज्ञायाम् ।")
def rule_5_4_143(ctx=None):
    """
    5.4.143: स्त्रियां संज्ञायाम् ।
    """
    pass


@registry.register("5.4.144", text="विभाषा श्यावारोकाभ्याम् ।")
def rule_5_4_144(ctx=None):
    """
    5.4.144: विभाषा श्यावारोकाभ्याम् ।
    """
    pass


@registry.register("5.4.145", text="अग्रान्तशुद्धशुभ्रवृषवराहेभ्यश्च ।")
def rule_5_4_145(ctx=None):
    """
    5.4.145: अग्रान्तशुद्धशुभ्रवृषवराहेभ्यश्च ।
    """
    pass


@registry.register("5.4.146", text="ककुदस्यावस्थायां लोपः ।")
def rule_5_4_146(ctx=None):
    """
    5.4.146: ककुदस्यावस्थायां लोपः ।
    """
    pass


@registry.register("5.4.147", text="त्रिककुत् पर्वते ।")
def rule_5_4_147(ctx=None):
    """
    5.4.147: त्रिककुत् पर्वते ।
    """
    pass


@registry.register("5.4.148", text="उद्विभ्यां काकुदस्य ।")
def rule_5_4_148(ctx=None):
    """
    5.4.148: उद्विभ्यां काकुदस्य ।
    """
    pass


@registry.register("5.4.149", text="पूर्णाद्विभाषा ।")
def rule_5_4_149(ctx=None):
    """
    5.4.149: पूर्णाद्विभाषा ।
    """
    pass


@registry.register("5.4.150", text="सुहृद्दुहृदौ मित्रामित्रयोः ।")
def rule_5_4_150(ctx=None):
    """
    5.4.150: सुहृद्दुहृदौ मित्रामित्रयोः ।
    """
    pass


@registry.register("5.4.151", text="उरःप्रभृतिभ्यः कप् ।")
def rule_5_4_151(ctx=None):
    """
    5.4.151: उरःप्रभृतिभ्यः कप् ।
    """
    pass


@registry.register("5.4.152", text="इनः स्त्रियाम् ।")
def rule_5_4_152(ctx=None):
    """
    5.4.152: इनः स्त्रियाम् ।
    """
    pass


@registry.register("5.4.153", text="नद्युतश्च ।")
def rule_5_4_153(ctx=None):
    """
    5.4.153: नद्युतश्च ।
    """
    pass


@registry.register("5.4.154", text="शेषाद्विभाषा ।")
def rule_5_4_154(ctx=None):
    """
    5.4.154: शेषाद्विभाषा ।
    """
    pass


@registry.register("5.4.155", text="न संज्ञायाम् ।")
def rule_5_4_155(ctx=None):
    """
    5.4.155: न संज्ञायाम् ।
    """
    pass


@registry.register("5.4.156", text="ईयसश्च ।")
def rule_5_4_156(ctx=None):
    """
    5.4.156: ईयसश्च ।
    """
    pass


@registry.register("5.4.157", text="वन्दिते भ्रातुः ।")
def rule_5_4_157(ctx=None):
    """
    5.4.157: वन्दिते भ्रातुः ।
    """
    pass


@registry.register("5.4.158", text="ऋतश्छन्दसि ।")
def rule_5_4_158(ctx=None):
    """
    5.4.158: ऋतश्छन्दसि ।
    """
    pass


@registry.register("5.4.159", text="नाडीतन्त्र्योः स्वाङ्गे ।")
def rule_5_4_159(ctx=None):
    """
    5.4.159: नाडीतन्त्र्योः स्वाङ्गे ।
    """
    pass


@registry.register("5.4.160", text="निष्प्रवाणिश्च ।")
def rule_5_4_160(ctx=None):
    """
    5.4.160: निष्प्रवाणिश्च ।
    """
    pass
