# Auto-generated by scripts/scaffold_roots.py for Gana 2
from . import registry


@registry.register("2.1", root="अद", meaning="भक्षणे", gana="Adadi")
def root_2_1():
    """
    2.1 अद भक्षणे 
    """
    return "अद"


@registry.register("2.2", root="हन", meaning="हिंसागत्योः", gana="Adadi")
def root_2_2():
    """
    2.2 हन हिंसागत्योः 
    """
    return "हन"


@registry.register("2.3", root="द्विष", meaning="अप्रीतौ", gana="Adadi")
def root_2_3():
    """
    2.3 द्विष अप्रीतौ 
    """
    return "द्विष"


@registry.register("2.4", root="दुह", meaning="प्रपूरणे", gana="Adadi")
def root_2_4():
    """
    2.4 दुह प्रपूरणे 
    """
    return "दुह"


@registry.register("2.5", root="दिह", meaning="उपचये", gana="Adadi")
def root_2_5():
    """
    2.5 दिह उपचये 
    """
    return "दिह"


@registry.register("2.6", root="लिह", meaning="आस्वादने", gana="Adadi")
def root_2_6():
    """
    2.6 लिह आस्वादने 
    """
    return "लिह"


@registry.register("2.7", root="चक्षिङ्", meaning="व्यक्तायां वाचि", gana="Adadi")
def root_2_7():
    """
    2.7 चक्षिङ् व्यक्तायां वाचि 
    """
    return "चक्षिङ्"


@registry.register("2.8", root="ईर", meaning="गतौ कम्पने च", gana="Adadi")
def root_2_8():
    """
    2.8 ईर गतौ कम्पने च 
    """
    return "ईर"


@registry.register("2.9", root="ईड", meaning="स्तुतौ", gana="Adadi")
def root_2_9():
    """
    2.9 ईड स्तुतौ 
    """
    return "ईड"


@registry.register("2.10", root="ईश", meaning="ऐश्वर्ये", gana="Adadi")
def root_2_10():
    """
    2.10 ईश ऐश्वर्ये 
    """
    return "ईश"


@registry.register("2.11", root="आस", meaning="उपवेशने", gana="Adadi")
def root_2_11():
    """
    2.11 आस उपवेशने 
    """
    return "आस"


@registry.register("2.12", root="आङः", meaning="शासु इच्छायाम्", gana="Adadi")
def root_2_12():
    """
    2.12 आङः शासु इच्छायाम् 
    """
    return "आङः"


@registry.register("2.13", root="वस", meaning="आच्छादने", gana="Adadi")
def root_2_13():
    """
    2.13 वस आच्छादने 
    """
    return "वस"


@registry.register("2.14", root="कसि", meaning="गतिशासनयोः", gana="Adadi")
def root_2_14():
    """
    2.14 कसि गतिशासनयोः 
    """
    return "कसि"


@registry.register("2.15", root="कस", meaning="इत्येके", gana="Adadi")
def root_2_15():
    """
    2.15 कस इत्येके 
    """
    return "कस"


@registry.register("2.16", root="कश", meaning="इत्यन्ये इत्यपि", gana="Adadi")
def root_2_16():
    """
    2.16 कश इत्यन्ये इत्यपि 
    """
    return "कश"


@registry.register("2.17", root="णिसि", meaning="चुम्बने", gana="Adadi")
def root_2_17():
    """
    2.17 णिसि चुम्बने 
    """
    return "णिसि"


@registry.register("2.18", root="णिजि", meaning="शुद्धौ", gana="Adadi")
def root_2_18():
    """
    2.18 णिजि शुद्धौ 
    """
    return "णिजि"


@registry.register("2.19", root="शिजि", meaning="अव्यक्ते शब्दे", gana="Adadi")
def root_2_19():
    """
    2.19 शिजि अव्यक्ते शब्दे 
    """
    return "शिजि"


@registry.register("2.20", root="पिजि", meaning="वर्णे", gana="Adadi")
def root_2_20():
    """
    2.20 पिजि वर्णे 
    """
    return "पिजि"


@registry.register("2.21", root="पृजि", meaning="इत्येके", gana="Adadi")
def root_2_21():
    """
    2.21 पृजि इत्येके 
    """
    return "पृजि"


@registry.register("2.22", root="वृजी", meaning="वर्जने", gana="Adadi")
def root_2_22():
    """
    2.22 वृजी वर्जने 
    """
    return "वृजी"


@registry.register("2.23", root="वृजि", meaning="इत्येके", gana="Adadi")
def root_2_23():
    """
    2.23 वृजि इत्येके 
    """
    return "वृजि"


@registry.register("2.24", root="पृची", meaning="सम्पर्चने सम्पर्के", gana="Adadi")
def root_2_24():
    """
    2.24 पृची सम्पर्चने सम्पर्के 
    """
    return "पृची"


@registry.register("2.25", root="षूङ्", meaning="प्राणिगर्भविमोचने", gana="Adadi")
def root_2_25():
    """
    2.25 षूङ् प्राणिगर्भविमोचने 
    """
    return "षूङ्"


@registry.register("2.26", root="शीङ्", meaning="स्वप्ने", gana="Adadi")
def root_2_26():
    """
    2.26 शीङ् स्वप्ने 
    """
    return "शीङ्"


@registry.register("2.27", root="यु", meaning="मिश्रेणेऽभिश्रणे च", gana="Adadi")
def root_2_27():
    """
    2.27 यु मिश्रेणेऽभिश्रणे च 
    """
    return "यु"


@registry.register("2.28", root="रु", meaning="शब्दे", gana="Adadi")
def root_2_28():
    """
    2.28 रु शब्दे 
    """
    return "रु"


@registry.register("2.29", root="तु", meaning="तु गतिवृद्धिहिंसासु वृद्ध्यर्थः", gana="Adadi")
def root_2_29():
    """
    2.29 तु तु गतिवृद्धिहिंसासु वृद्ध्यर्थः 
    """
    return "तु"


@registry.register("2.30", root="णु", meaning="स्तुतौ", gana="Adadi")
def root_2_30():
    """
    2.30 णु स्तुतौ 
    """
    return "णु"


@registry.register("2.31", root="टुक्षु", meaning="शब्दे", gana="Adadi")
def root_2_31():
    """
    2.31 टुक्षु शब्दे 
    """
    return "टुक्षु"


@registry.register("2.32", root="क्ष्णु", meaning="तेजने", gana="Adadi")
def root_2_32():
    """
    2.32 क्ष्णु तेजने 
    """
    return "क्ष्णु"


@registry.register("2.33", root="ष्णु", meaning="प्रस्रवणे", gana="Adadi")
def root_2_33():
    """
    2.33 ष्णु प्रस्रवणे 
    """
    return "ष्णु"


@registry.register("2.34", root="ऊर्णुञ्", meaning="आच्छादने", gana="Adadi")
def root_2_34():
    """
    2.34 ऊर्णुञ् आच्छादने 
    """
    return "ऊर्णुञ्"


@registry.register("2.35", root="द्यु", meaning="अभिगमने", gana="Adadi")
def root_2_35():
    """
    2.35 द्यु अभिगमने 
    """
    return "द्यु"


@registry.register("2.36", root="षु", meaning="प्रसवैश्वर्ययोः", gana="Adadi")
def root_2_36():
    """
    2.36 षु प्रसवैश्वर्ययोः 
    """
    return "षु"


@registry.register("2.37", root="कु", meaning="शब्दे", gana="Adadi")
def root_2_37():
    """
    2.37 कु शब्दे 
    """
    return "कु"


@registry.register("2.38", root="ष्टुञ्", meaning="स्तुतौ", gana="Adadi")
def root_2_38():
    """
    2.38 ष्टुञ् स्तुतौ 
    """
    return "ष्टुञ्"


@registry.register("2.39", root="ब्रूञ्", meaning="ब्रूञ् व्यक्तायां वाचि", gana="Adadi")
def root_2_39():
    """
    2.39 ब्रूञ् ब्रूञ् व्यक्तायां वाचि 
    """
    return "ब्रूञ्"


@registry.register("2.40", root="इण्", meaning="गतौ", gana="Adadi")
def root_2_40():
    """
    2.40 इण् गतौ 
    """
    return "इण्"


@registry.register("2.41", root="इङ्", meaning="अध्ययने", gana="Adadi")
def root_2_41():
    """
    2.41 इङ् अध्ययने 
    """
    return "इङ्"


@registry.register("2.42", root="इक्", meaning="स्मरणे", gana="Adadi")
def root_2_42():
    """
    2.42 इक् स्मरणे 
    """
    return "इक्"


@registry.register("2.43", root="वी", meaning="गतिप्रजनकान्त्यसनखादनेषु", gana="Adadi")
def root_2_43():
    """
    2.43 वी गतिप्रजनकान्त्यसनखादनेषु 
    """
    return "वी"


@registry.register("2.44", root="या", meaning="प्रापणे", gana="Adadi")
def root_2_44():
    """
    2.44 या प्रापणे 
    """
    return "या"


@registry.register("2.45", root="वा", meaning="गतिगन्धनयोः", gana="Adadi")
def root_2_45():
    """
    2.45 वा गतिगन्धनयोः 
    """
    return "वा"


@registry.register("2.46", root="भा", meaning="दीप्तौ", gana="Adadi")
def root_2_46():
    """
    2.46 भा दीप्तौ 
    """
    return "भा"


@registry.register("2.47", root="ष्णा", meaning="शौचे", gana="Adadi")
def root_2_47():
    """
    2.47 ष्णा शौचे 
    """
    return "ष्णा"


@registry.register("2.48", root="श्रा", meaning="पाके", gana="Adadi")
def root_2_48():
    """
    2.48 श्रा पाके 
    """
    return "श्रा"


@registry.register("2.49", root="द्रा", meaning="कुत्सायां गतौ", gana="Adadi")
def root_2_49():
    """
    2.49 द्रा कुत्सायां गतौ 
    """
    return "द्रा"


@registry.register("2.50", root="प्सा", meaning="भक्षणे", gana="Adadi")
def root_2_50():
    """
    2.50 प्सा भक्षणे 
    """
    return "प्सा"


@registry.register("2.51", root="पा", meaning="रक्षणे", gana="Adadi")
def root_2_51():
    """
    2.51 पा रक्षणे 
    """
    return "पा"


@registry.register("2.52", root="रा", meaning="दाने", gana="Adadi")
def root_2_52():
    """
    2.52 रा दाने 
    """
    return "रा"


@registry.register("2.53", root="ला", meaning="आदाने दाने", gana="Adadi")
def root_2_53():
    """
    2.53 ला आदाने दाने 
    """
    return "ला"


@registry.register("2.54", root="दाप्", meaning="लवने", gana="Adadi")
def root_2_54():
    """
    2.54 दाप् लवने 
    """
    return "दाप्"


@registry.register("2.55", root="ख्या", meaning="प्रकथने", gana="Adadi")
def root_2_55():
    """
    2.55 ख्या प्रकथने 
    """
    return "ख्या"


@registry.register("2.56", root="प्रा", meaning="पूरणे", gana="Adadi")
def root_2_56():
    """
    2.56 प्रा पूरणे 
    """
    return "प्रा"


@registry.register("2.57", root="मा", meaning="माने", gana="Adadi")
def root_2_57():
    """
    2.57 मा माने 
    """
    return "मा"


@registry.register("2.58", root="वच", meaning="परिभाषणे", gana="Adadi")
def root_2_58():
    """
    2.58 वच परिभाषणे 
    """
    return "वच"


@registry.register("2.59", root="विद", meaning="ज्ञाने", gana="Adadi")
def root_2_59():
    """
    2.59 विद ज्ञाने 
    """
    return "विद"


@registry.register("2.60", root="अस", meaning="भुवि", gana="Adadi")
def root_2_60():
    """
    2.60 अस भुवि 
    """
    return "अस"


@registry.register("2.61", root="मृजू", meaning="मृजूष् शुद्धौ", gana="Adadi")
def root_2_61():
    """
    2.61 मृजू मृजूष् शुद्धौ 
    """
    return "मृजू"


@registry.register("2.62", root="रुदिर्", meaning="अश्रुविमोचने", gana="Adadi")
def root_2_62():
    """
    2.62 रुदिर् अश्रुविमोचने 
    """
    return "रुदिर्"


@registry.register("2.63", root="ञिष्वप", meaning="शये", gana="Adadi")
def root_2_63():
    """
    2.63 ञिष्वप शये 
    """
    return "ञिष्वप"


@registry.register("2.64", root="श्वस", meaning="प्राणने", gana="Adadi")
def root_2_64():
    """
    2.64 श्वस प्राणने 
    """
    return "श्वस"


@registry.register("2.65", root="अन", meaning="च", gana="Adadi")
def root_2_65():
    """
    2.65 अन च 
    """
    return "अन"


@registry.register("2.66", root="जक्ष", meaning="भक्ष्यहसनयोः", gana="Adadi")
def root_2_66():
    """
    2.66 जक्ष भक्ष्यहसनयोः 
    """
    return "जक्ष"


@registry.register("2.67", root="जागृ", meaning="निद्राक्षये", gana="Adadi")
def root_2_67():
    """
    2.67 जागृ निद्राक्षये 
    """
    return "जागृ"


@registry.register("2.68", root="दरिद्रा", meaning="दुर्गतौ", gana="Adadi")
def root_2_68():
    """
    2.68 दरिद्रा दुर्गतौ 
    """
    return "दरिद्रा"


@registry.register("2.69", root="चकासृ", meaning="दीप्तौ", gana="Adadi")
def root_2_69():
    """
    2.69 चकासृ दीप्तौ 
    """
    return "चकासृ"


@registry.register("2.70", root="शासु", meaning="अनुशिष्टौ", gana="Adadi")
def root_2_70():
    """
    2.70 शासु अनुशिष्टौ 
    """
    return "शासु"


@registry.register("2.71", root="दीधीङ्", meaning="दीप्तिदेवनयोः", gana="Adadi")
def root_2_71():
    """
    2.71 दीधीङ् दीप्तिदेवनयोः 
    """
    return "दीधीङ्"


@registry.register("2.72", root="वेवीङ्", meaning="वेतिना तुल्ये", gana="Adadi")
def root_2_72():
    """
    2.72 वेवीङ् वेतिना तुल्ये 
    """
    return "वेवीङ्"


@registry.register("2.74", root="षस्ति", meaning="सस्ति स्वप्ने", gana="Adadi")
def root_2_74():
    """
    2.74 षस्ति सस्ति स्वप्ने 
    """
    return "षस्ति"


@registry.register("2.75", root="वश", meaning="कान्तौ", gana="Adadi")
def root_2_75():
    """
    2.75 वश कान्तौ 
    """
    return "वश"


@registry.register("2.76", root="ह्नुङ्", meaning="अपनयने", gana="Adadi")
def root_2_76():
    """
    2.76 ह्नुङ् अपनयने 
    """
    return "ह्नुङ्"
