# Auto-generated by scripts/scaffold_roots.py for Gana 7
from . import registry


@registry.register("7.1", root="रुधिर्", meaning="आवरणे", gana="Rudhadi")
def root_7_1():
    """
    7.1 रुधिर् आवरणे 
    """
    return "रुधिर्"


@registry.register("7.2", root="भिदिर्", meaning="विदारणे", gana="Rudhadi")
def root_7_2():
    """
    7.2 भिदिर् विदारणे 
    """
    return "भिदिर्"


@registry.register("7.3", root="छिदिर्", meaning="द्वैधीकरणे", gana="Rudhadi")
def root_7_3():
    """
    7.3 छिदिर् द्वैधीकरणे 
    """
    return "छिदिर्"


@registry.register("7.4", root="रिचिर्", meaning="विरेचने", gana="Rudhadi")
def root_7_4():
    """
    7.4 रिचिर् विरेचने 
    """
    return "रिचिर्"


@registry.register("7.5", root="विचिर्", meaning="पृथग्भावे", gana="Rudhadi")
def root_7_5():
    """
    7.5 विचिर् पृथग्भावे 
    """
    return "विचिर्"


@registry.register("7.6", root="क्षुदिर्", meaning="सम्प्रेषणे", gana="Rudhadi")
def root_7_6():
    """
    7.6 क्षुदिर् सम्प्रेषणे 
    """
    return "क्षुदिर्"


@registry.register("7.7", root="युजिर्", meaning="योगे", gana="Rudhadi")
def root_7_7():
    """
    7.7 युजिर् योगे 
    """
    return "युजिर्"


@registry.register("7.8", root="उछृदिर्", meaning="दीप्तिदेवनयोः", gana="Rudhadi")
def root_7_8():
    """
    7.8 उछृदिर् दीप्तिदेवनयोः 
    """
    return "उछृदिर्"


@registry.register("7.9", root="उतृदिर्", meaning="हिंसानादरयोः", gana="Rudhadi")
def root_7_9():
    """
    7.9 उतृदिर् हिंसानादरयोः 
    """
    return "उतृदिर्"


@registry.register("7.10", root="कृती", meaning="वेष्टने", gana="Rudhadi")
def root_7_10():
    """
    7.10 कृती वेष्टने 
    """
    return "कृती"


@registry.register("7.11", root="ञिऽइन्धी", meaning="दीप्तौ", gana="Rudhadi")
def root_7_11():
    """
    7.11 ञिऽइन्धी दीप्तौ 
    """
    return "ञिऽइन्धी"


@registry.register("7.12", root="खिद", meaning="दैन्ये", gana="Rudhadi")
def root_7_12():
    """
    7.12 खिद दैन्ये 
    """
    return "खिद"


@registry.register("7.13", root="विद", meaning="विचारणे", gana="Rudhadi")
def root_7_13():
    """
    7.13 विद विचारणे 
    """
    return "विद"


@registry.register("7.14", root="शिषॢ", meaning="विशेषणे", gana="Rudhadi")
def root_7_14():
    """
    7.14 शिषॢ विशेषणे 
    """
    return "शिषॢ"


@registry.register("7.15", root="पिषॢ", meaning="सञ्चूर्णने", gana="Rudhadi")
def root_7_15():
    """
    7.15 पिषॢ सञ्चूर्णने 
    """
    return "पिषॢ"


@registry.register("7.16", root="भञ्जो", meaning="आमर्दने", gana="Rudhadi")
def root_7_16():
    """
    7.16 भञ्जो आमर्दने 
    """
    return "भञ्जो"


@registry.register("7.17", root="भुज", meaning="पालनाभ्यवहारयोः", gana="Rudhadi")
def root_7_17():
    """
    7.17 भुज पालनाभ्यवहारयोः 
    """
    return "भुज"


@registry.register("7.18", root="तृह", meaning="हिंसायाम्", gana="Rudhadi")
def root_7_18():
    """
    7.18 तृह हिंसायाम् 
    """
    return "तृह"


@registry.register("7.19", root="हिसि", meaning="हिंसायाम्", gana="Rudhadi")
def root_7_19():
    """
    7.19 हिसि हिंसायाम् 
    """
    return "हिसि"


@registry.register("7.20", root="उन्दी", meaning="क्लेदने", gana="Rudhadi")
def root_7_20():
    """
    7.20 उन्दी क्लेदने 
    """
    return "उन्दी"


@registry.register("7.21", root="अञ्जू", meaning="व्यक्तिम्रक्षणकान्तिगतिषु व्यक्तिमर्षणकान्तिगतिषु", gana="Rudhadi")
def root_7_21():
    """
    7.21 अञ्जू व्यक्तिम्रक्षणकान्तिगतिषु व्यक्तिमर्षणकान्तिगतिषु 
    """
    return "अञ्जू"


@registry.register("7.22", root="तञ्चू", meaning="सङ्कोचने", gana="Rudhadi")
def root_7_22():
    """
    7.22 तञ्चू सङ्कोचने 
    """
    return "तञ्चू"


@registry.register("7.23", root="ओविजी", meaning="भयचलनयोः", gana="Rudhadi")
def root_7_23():
    """
    7.23 ओविजी भयचलनयोः 
    """
    return "ओविजी"


@registry.register("7.24", root="वृजी", meaning="वर्जने", gana="Rudhadi")
def root_7_24():
    """
    7.24 वृजी वर्जने 
    """
    return "वृजी"


@registry.register("7.25", root="पृची", meaning="सम्पर्के", gana="Rudhadi")
def root_7_25():
    """
    7.25 पृची सम्पर्के 
    """
    return "पृची"
